@@ -20,8 +20,6 @@
 #ifndef ANGLEMEASURE_HPP_
 #define ANGLEMEASURE_HPP_
 
-#include "config.h"
-
 #include <QFont>
 #include "VecMath.hpp"
 #include "StelModule.hpp"
@@ -113,6 +111,7 @@ private slots:
 private:
 	QFont font;
 	bool flagShowAngleMeasure;
+	bool withDecimalDegree;
 	LinearFader lineVisible;
 	LinearFader messageFader;
 	QTimer* messageTimer;
@@ -171,7 +170,7 @@ private:
 class AngleMeasureStelPluginInterface : public QObject, public StelPluginInterface
 {
 	Q_OBJECT
-	Q_PLUGIN_METADATA(IID "stellarium.StelGuiPluginInterface/1.0")
+	Q_PLUGIN_METADATA(IID StelPluginInterface_iid)
 	Q_INTERFACES(StelPluginInterface)
 public:
 	virtual StelModule* getStelModule() const;
