@@ -127,14 +127,10 @@ void EquationOfTime::draw(StelCore *core)
 
 	if (getFlagMsFormat())
 	{
-		double seconds = std::abs(round((time - (int)time)*60));
-		QString messageSecondsValue;
-		if (seconds<10.)
-			messageSecondsValue = QString("0%1").arg(QString::number(seconds, 'f', 0));
-		else
-			messageSecondsValue = QString("%1").arg(QString::number(seconds, 'f', 0));
+		int seconds = qRound((time - (int)time)*60);
+		QString messageSecondsValue = QString("%1").arg(qAbs(seconds), 2, 10, QLatin1Char('0'));
 
-		timeText = QString("%1: %2%3%4%5").arg(messageEquation, QString::number((int)time), messageEquationMinutes, messageSecondsValue, messageEquationSeconds);
+		timeText = QString("%1: %2%3%4%5%6").arg(messageEquation, (time<0? QString(QLatin1Char('-')):QString()), QString::number((int)qAbs(time)), messageEquationMinutes, messageSecondsValue, messageEquationSeconds);
 	}
 	else
 		timeText = QString("%1: %2%3").arg(messageEquation, QString::number(time, 'f', 2), messageEquationMinutes);
@@ -221,7 +217,7 @@ double EquationOfTime::getSolutionEquationOfTime(const double JDay) const
 	StelCore* core = StelApp::getInstance().getCore();
 
 	double tau = (JDay - 2451545.0)/365250.0;
-	double sunMeanLongitude = 280.4664567 + tau*(360007.6892779 + tau*(0.03032028 + tau*(1/49931 - tau*(1/15300 - tau/2000000))));
+	double sunMeanLongitude = 280.4664567 + tau*(360007.6892779 + tau*(0.03032028 + tau*(1./49931. - tau*(1./15300. - tau/2000000.))));
 
 	// reduce the angle
 	sunMeanLongitude = std::fmod(sunMeanLongitude, 360.);
@@ -239,7 +235,7 @@ double EquationOfTime::getSolutionEquationOfTime(const double JDay) const
 
 	double equation = 4*(sunMeanLongitude - 0.0057183 - alpha + get_nutation_longitude(JDay)*cos(get_mean_ecliptical_obliquity(JDay)));
 	// The equation of time is always smaller 20 minutes in absolute value
-	if (std::abs(equation)>20)
+	if (qAbs(equation)>20)
 	{
 		// If absolute value of the equation of time appears to be too large, add 24 hours (1440 minutes) to or subtract it from our result
 		if (equation>0.)
