@@ -16,7 +16,6 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#include "config.h"
 
 #include "Exoplanet.hpp"
 #include "Exoplanets.hpp"
@@ -96,10 +95,10 @@ Exoplanet::Exoplanet(const QVariantMap& map)
 			p.inclination = exoplanetMap.value("inclination", -1.f).toFloat();
 			p.angleDistance = exoplanetMap.value("angleDistance", -1.f).toFloat();
 			p.discovered = exoplanetMap.value("discovered", 0).toInt();
-			p.hclass = exoplanetMap.value("hclass", "").toString();
-			if (!p.hclass.isEmpty())
-				PHEPCount++;
-			p.MSTemp = exoplanetMap.value("MSTemp", -1).toInt();
+			p.pclass = exoplanetMap.value("pclass", "").toString();			
+			if (!p.pclass.isEmpty())
+				PHEPCount++;			
+			p.EqTemp = exoplanetMap.value("EqTemp", -1).toInt();
 			p.ESI = exoplanetMap.value("ESI", -1).toInt();
 			exoplanets.append(p);
 		}
@@ -140,8 +139,8 @@ QVariantMap Exoplanet::getMap(void)
 		if (p.eccentricity > -1.f) explMap["eccentricity"] = p.eccentricity;
 		if (p.angleDistance > -1.f) explMap["angleDistance"] = p.angleDistance;
 		if (p.discovered > 0) explMap["discovered"] = p.discovered;
-		if (!p.hclass.isEmpty()) explMap["hclass"] = p.hclass;
-		if (p.MSTemp > 0) explMap["MSTemp"] = p.MSTemp;
+		if (!p.pclass.isEmpty()) explMap["pclass"] = p.pclass;		
+		if (p.EqTemp > 0) explMap["EqTemp"] = p.EqTemp;
 		if (p.ESI > 0) explMap["ESI"] = p.ESI;
 		exoplanetList << explMap;
 	}
@@ -236,9 +235,9 @@ QString Exoplanet::getInfoString(const StelCore* core, const InfoStringGroup& fl
 			QString inclinationLabel = QString("<td style=\"padding: 0 2px 0 0;\">%1 (%2)</td>").arg(q_("Inclination")).arg(QChar(0x00B0));
 			QString angleDistanceLabel = QString("<td style=\"padding: 0 2px 0 0;\">%1 (\")</td>").arg(q_("Angle Distance"));
 			QString discoveredLabel = QString("<td style=\"padding: 0 2px 0 0;\">%1</td>").arg(q_("Discovered year"));
-			QString hClassLabel = QString("<td style=\"padding: 0 2px 0 0;\">%1</td>").arg(q_("Habitable class"));
-			//TRANSLATORS: Full phrase is "Mean Surface Temperature"
-			QString meanSurfaceTempLabel = QString("<td style=\"padding: 0 2px 0 0;\">%1 (%2C)</td>").arg(q_("Mean surface temp.")).arg(QChar(0x00B0));
+			QString pClassLabel = QString("<td style=\"padding: 0 2px 0 0;\">%1</td>").arg(q_("Planetary class"));			
+			//TRANSLATORS: Full phrase is "Equilibrium Temperature"
+			QString equilibriumTempLabel = QString("<td style=\"padding: 0 2px 0 0;\">%1 (%2C)</td>").arg(q_("Equilibrium temp.")).arg(QChar(0x00B0));
 			//TRANSLATORS: ESI = Earth Similarity Index
 			QString ESILabel = QString("<td style=\"padding: 0 2px 0 0;\">%1</td>").arg(q_("ESI"));
 			foreach(const exoplanetData &p, exoplanets)
@@ -315,21 +314,21 @@ QString Exoplanet::getInfoString(const StelCore* core, const InfoStringGroup& fl
 				{
 					discoveredLabel.append("<td style=\"padding:0 2px;\">&mdash;</td>");
 				}
-				if (!p.hclass.isEmpty())
+				if (!p.pclass.isEmpty())
 				{
-					hClassLabel.append("<td style=\"padding:0 2px;\">").append(p.hclass).append("</td>");
+					pClassLabel.append("<td style=\"padding:0 2px;\">").append(getPlanetaryClassI18n(p.pclass)).append("</td>");
 				}
 				else
 				{
-					hClassLabel.append("<td style=\"padding:0 2px;\">&mdash;</td>");
-				}
-				if (p.MSTemp > 0)
+					pClassLabel.append("<td style=\"padding:0 2px;\">&mdash;</td>");
+				}				
+				if (p.EqTemp > 0)
 				{
-					meanSurfaceTempLabel.append("<td style=\"padding:0 2px;\">").append(QString::number(p.MSTemp - 273.15, 'f', 2)).append("</td>");
+					equilibriumTempLabel.append("<td style=\"padding:0 2px;\">").append(QString::number(p.EqTemp - 273.15, 'f', 2)).append("</td>");
 				}
 				else
 				{
-					meanSurfaceTempLabel.append("<td style=\"padding:0 2px;\">&mdash;</td>");
+					equilibriumTempLabel.append("<td style=\"padding:0 2px;\">&mdash;</td>");
 				}
 				if (p.ESI > 0)
 				{
@@ -352,8 +351,8 @@ QString Exoplanet::getInfoString(const StelCore* core, const InfoStringGroup& fl
 			oss << "<tr>" << discoveredLabel << "</tr>";
 			if (hasHabitableExoplanets)
 			{
-				oss << "<tr>" << hClassLabel << "</tr>";
-				oss << "<tr>" << meanSurfaceTempLabel << "</tr>";
+				oss << "<tr>" << pClassLabel << "</tr>";				
+				oss << "<tr>" << equilibriumTempLabel << "</tr>";
 				oss << "<tr>" << ESILabel << "</tr>";
 			}
 			oss << "</table>";
@@ -364,6 +363,24 @@ QString Exoplanet::getInfoString(const StelCore* core, const InfoStringGroup& fl
 	return str;
 }
 
+QString Exoplanet::getPlanetaryClassI18n(QString ptype) const
+{
+	QString result = "";
+	QRegExp dataRx("^(\\w)-(\\w+)\\s(\\w+)$");
+	if (dataRx.exactMatch(ptype))
+	{
+		QString spectral = dataRx.capturedTexts().at(1).trimmed();
+		QString zone = dataRx.capturedTexts().at(2).trimmed();
+		QString size = dataRx.capturedTexts().at(3).trimmed();
+
+		result = QString("%1-%2 %3")
+				.arg(spectral)
+				.arg(q_(zone))
+				.arg(q_(size));
+	}
+	return result;
+}
+
 Vec3f Exoplanet::getInfoColor(void) const
 {
 	return Vec3f(1.0, 1.0, 1.0);
@@ -473,7 +490,7 @@ void Exoplanet::draw(StelCore* core, StelPainter *painter)
 
 		if (labelsFader.getInterstate()<=0.f && !distributionMode && (mag+1.f)<mlimit && smgr->getFlagLabels())
 		{
-			painter->drawText(XYZ, designation, 0, shift, shift, false);
+			painter->drawText(XYZ, getNameI18n(), 0, shift, shift, false);
 		}
 	}
 }
