@@ -41,8 +41,8 @@ typedef struct
 	float inclination;	//! Exoplanet orbit inclination
 	float angleDistance;	//! Exoplanet angle distance
 	int discovered;		//! Exoplanet discovered year
-	QString hclass;		//! Exoplanet habitable class
-	int MSTemp;		//! Exoplanet mean surface temperature (Kelvin)
+	QString pclass;		//! Exoplanet classification from host star spectral type (F, G, K, M), habitable zone (hot, warm, cold) and size (miniterran, subterran, terran, superterran, jovian, neptunian)	
+	int EqTemp;		//! Exoplanet equilibrium temperature in kelvins (K) assuming a 0.3 bond albedo (Earth = 255 K).
 	int ESI;		//! Exoplanet Earth Similarity Index
 } exoplanetData;
 
@@ -108,6 +108,9 @@ public:
 	}
 
 private:
+
+	QString getPlanetaryClassI18n(QString ptype) const;
+
 	bool initialized;
 
 	Vec3d XYZ;                         // holds J2000 position	
