@@ -47,7 +47,7 @@ $dbuser	= "exoplanet";
 $dbpass	= "exoplanet";
 
 $UA = LWP::UserAgent->new(keep_alive => 1, timeout => 360);
-$UA->agent("Mozilla/5.0 (Stellarium Exoplanets Catalog Updater 2.1; http://stellarium.org/)");
+$UA->agent("Mozilla/5.0 (Stellarium Exoplanets Catalog Updater 2.7; http://stellarium.org/)");
 $request = HTTP::Request->new('GET', $URL);
 $responce = $UA->request($request);
 
@@ -75,8 +75,8 @@ close HCSV;
 for ($i=1;$i<scalar(@habitable);$i++) {
 	$status  = $csvdata->parse($habitable[$i]);
 	@hdata = $csvdata->fields();
-	%hs = (%hs, $hdata[0], 1);
-	%hp = (%hp, $hdata[0]." ".$hdata[1], $habitable[$i]);
+	%hs = (%hs, $hdata[1], 1);
+	%hp = (%hp, $hdata[1]." ".$hdata[2], $habitable[$i]);
 }
 
 open (CSV, "<$CSV");
@@ -248,17 +248,19 @@ for ($i=1;$i<scalar(@catalog);$i++) {
 		}
 		
 		$hclass = '';
+		$hptype = '';
 		$mstemp = -1;
+		$eqtemp = -1;
 		$esi    = -1;
 		
 		$key = $starName." ".$pname;
 		if (exists($hp{$key})) {
 			$status  = $csvdata->parse($hp{$key});
-			($hsname,$hpname,$hclass,$mstemp,$esi) = $csvdata->fields();
+			($hsn,$hsname,$hpname,$hptype,$eqtemp,$esi) = $csvdata->fields();
 		}
 		
 		# insert planet data
-		$sth = $dbh->do(q{INSERT INTO planets (sid,pname,pmass,pradius,pperiod,psemiaxis,pecc,pinc,padistance,discovered,hclass,mstemp,esi) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)}, undef, $starID, $pname, $pmass, $pradius, $pperiod, $paxis, $pecc, $pincl, $angdist, $discovered, $hclass, $mstemp, $esi);
+		$sth = $dbh->do(q{INSERT INTO planets (sid,pname,pmass,pradius,pperiod,psemiaxis,pecc,pinc,padistance,discovered,hptype,eqtemp,esi) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)}, undef, $starID, $pname, $pmass, $pradius, $pperiod, $paxis, $pecc, $pincl, $angdist, $discovered, $hptype, $eqtemp, $esi);
 	}
 #	else
 #	{
@@ -295,6 +297,10 @@ while (@stars = $sth->fetchrow_array()) {
 	$sefftemp	= $stars[10];
 	$hasHabitPl	= $stars[11];
 	
+	if ($sname eq "Kapteyn's") {
+		$sname .= " Star"; # cosmetic fix for translation support
+	}
+	
 	$out  = "\t\t\"".$sname."\":\n";
 	$out .= "\t\t{\n";
 	$out .= "\t\t\t\"exoplanets\":\n";
@@ -319,8 +325,8 @@ while (@stars = $sth->fetchrow_array()) {
 		$pinc		= $planets[8];
 		$angdist	= $planets[9];
 		$discovered	= $planets[10];
-		$habitclass	= $planets[11];
-		$meanstemp	= $planets[12];
+		$hpltype	= $planets[11];
+		$eqktemp	= $planets[12];
 		$esindex	= $planets[13];
 	
 		$out .= "\t\t\t{\n";
@@ -348,11 +354,11 @@ while (@stars = $sth->fetchrow_array()) {
 		if ($discovered ne '') {
 			$out .= "\t\t\t\t\"discovered\": ".$discovered.",\n";
 		}
-		if ($habitclass ne '') {
-			$out .= "\t\t\t\t\"hclass\": \"".$habitclass."\",\n";
+		if ($hpltype ne '') {
+			$out .= "\t\t\t\t\"pclass\": \"".$hpltype."\",\n";
 		}
-		if ($meanstemp > 0) {
-			$out .= "\t\t\t\t\"MSTemp\": ".$meanstemp.",\n";
+		if ($eqktemp > 0) {
+			$out .= "\t\t\t\t\"EqTemp\": ".$eqktemp.",\n";
 		}
 		if ($esindex > 0) {
 			$out .= "\t\t\t\t\"ESI\": ".$esindex.",\n";
