@@ -342,10 +342,12 @@ void OcularDialog::createDialogContent()
 	ui->telescopeListView->setModel(telescopeTableModel);
 	ui->lensListView->setModel(lensTableModel);
 
+#ifdef Q_OS_WIN
 	//Kinetic scrolling for tablet pc and pc
 	QList<QWidget *> addscroll;
 	addscroll << ui->textBrowser << ui->telescopeListView << ui->ccdListView << ui->ocularListView << ui->lensListView;
 	installKineticScrolling(addscroll);
+#endif
 	
 	//Now the rest of the actions.
 	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
@@ -355,6 +357,7 @@ void OcularDialog::createDialogContent()
 	connect(ui->checkBoxControlPanel, SIGNAL(clicked(bool)), plugin, SLOT(enableGuiPanel(bool)));
 	connect(ui->checkBoxDecimalDegrees, SIGNAL(clicked(bool)), plugin, SLOT(setFlagDecimalDegrees(bool)));
 	connect(ui->checkBoxInitialFOV, SIGNAL(clicked(bool)), plugin, SLOT(setFlagInitFovUsage(bool)));
+	connect(ui->checkBoxUseFlipForCCD, SIGNAL(clicked(bool)), plugin, SLOT(setFlagUseFlipForCCD(bool)));
 	
 	// The add & delete buttons
 	connect(ui->addCCD, SIGNAL(clicked()), this, SLOT(insertNewCCD()));
@@ -461,6 +464,8 @@ void OcularDialog::createDialogContent()
 					telescopeMapper, SLOT(setCurrentModelIndex(QModelIndex)));
 	ui->telescopeListView->setCurrentIndex(telescopeTableModel->index(0, 1));
 
+	connect(ui->binocularsCheckBox, SIGNAL(toggled(bool)), this, SLOT(setLabelsDescriptionText(bool)));
+
 	// set the initial state
 	QSettings *settings = Oculars::appSettings();
 	if (settings->value("require_selection_to_zoom", 1.0).toBool()) {
@@ -484,11 +489,31 @@ void OcularDialog::createDialogContent()
 	{
 		ui->checkBoxInitialFOV->setChecked(true);
 	}
+	if (settings->value("use_ccd_flip", true).toBool())
+	{
+		ui->checkBoxUseFlipForCCD->setChecked(true);
+	}
 
 	//Initialize the style
 	updateStyle();
 }
 
+void OcularDialog::setLabelsDescriptionText(bool state)
+{
+	if (state)
+	{
+		// TRANSLATORS: tFOV for binoculars (tFOV = True Field of View)
+		ui->labelFOV->setText(q_("tFOV:"));
+		// TRANSLATORS: Magnification factor for binoculars
+		ui->labelFL->setText(q_("Magnification factor:"));
+	}
+	else
+	{
+		ui->labelFOV->setText(q_("aFOV:"));
+		ui->labelFL->setText(q_("Focal length:"));
+	}
+}
+
 void OcularDialog::initAboutText()
 {
 	//BM: Most of the text for now is the original contents of the About widget.
