@@ -59,6 +59,7 @@ public:
 		RaDec,
 		HourAngle,
 		Ecliptic,
+		EclipticJ2000,
 		AltAzi,
 		Galactic
 	};
@@ -189,7 +190,7 @@ private:
 class PointerCoordinatesStelPluginInterface : public QObject, public StelPluginInterface
 {
 	Q_OBJECT
-	Q_PLUGIN_METADATA(IID "stellarium.StelGuiPluginInterface/1.0")
+	Q_PLUGIN_METADATA(IID StelPluginInterface_iid)
 	Q_INTERFACES(StelPluginInterface)
 public:
 	virtual StelModule* getStelModule() const;
