@@ -464,6 +464,9 @@ QStringList Satellites::listMatchingObjects(const QString& objPrefix, int maxNbI
 QStringList Satellites::listAllObjects(bool inEnglish) const
 {
 	QStringList result;
+	if (!hintFader || StelApp::getInstance().getCore()->getCurrentLocation().planetName != earth->getEnglishName() || !isValidRangeDates())
+		return result;
+
 	if (inEnglish)
 	{
 		foreach(const SatelliteP& sat, satellites)
@@ -505,34 +508,59 @@ void Satellites::restoreDefaultSettings()
 	// delete all existing Satellite settings...
 	conf->remove("");
 
-	conf->setValue("show_satellite_hints", false);
-	conf->setValue("show_satellite_labels", true);
+	conf->setValue("show_satellite_hints", true);
+	conf->setValue("show_satellite_labels", false);
 	conf->setValue("updates_enabled", true);
 	conf->setValue("auto_add_enabled", true);
 	conf->setValue("auto_remove_enabled", true);
 	conf->setValue("hint_color", "0.0,0.4,0.6");
 	conf->setValue("hint_font_size", 10);
 	conf->setValue("update_frequency_hours", 72);
-	conf->setValue("orbit_line_flag", true);
+	conf->setValue("orbit_line_flag", false);
 	conf->setValue("orbit_line_segments", 90);
 	conf->setValue("orbit_fade_segments", 5);
 	conf->setValue("orbit_segment_duration", 20);
-	conf->setValue("realistic_mode_enabled", false);
+	conf->setValue("realistic_mode_enabled", true);
 	
 	conf->endGroup(); // saveTleSources() opens it for itself
 	
 	// TLE update sources
 	QStringList urls;
-	urls << "1,http://celestrak.com/NORAD/elements/visual.txt" // Auto-add ON!
-	     << "http://celestrak.com/NORAD/elements/tle-new.txt"
-	     << "http://celestrak.com/NORAD/elements/science.txt"
-	     << "http://celestrak.com/NORAD/elements/noaa.txt"
-	     << "http://celestrak.com/NORAD/elements/goes.txt"
-	     << "http://celestrak.com/NORAD/elements/amateur.txt"
-	     << "http://celestrak.com/NORAD/elements/gps-ops.txt"
-	     << "http://celestrak.com/NORAD/elements/galileo.txt"
-	     << "http://celestrak.com/NORAD/elements/iridium.txt"
-	     << "http://celestrak.com/NORAD/elements/geo.txt";
+	urls << "1,http://www.celestrak.com/NORAD/elements/visual.txt" // Auto-add ON!
+	     << "http://www.celestrak.com/NORAD/elements/tle-new.txt"
+	     << "1,http://www.celestrak.com/NORAD/elements/science.txt"
+	     << "http://www.celestrak.com/NORAD/elements/noaa.txt"
+	     << "http://www.celestrak.com/NORAD/elements/goes.txt"
+	     << "1,http://www.celestrak.com/NORAD/elements/amateur.txt"
+	     << "1,http://www.celestrak.com/NORAD/elements/gps-ops.txt"
+	     << "1,http://www.celestrak.com/NORAD/elements/galileo.txt"
+	     << "1,http://www.celestrak.com/NORAD/elements/iridium.txt"
+	     << "http://www.celestrak.com/NORAD/elements/geo.txt"
+	     << "1,http://www.celestrak.com/NORAD/elements/stations.txt"
+	     << "http://www.celestrak.com/NORAD/elements/weather.txt"
+	     << "http://www.celestrak.com/NORAD/elements/resource.txt"
+	     << "http://www.celestrak.com/NORAD/elements/sarsat.txt"
+	     << "http://www.celestrak.com/NORAD/elements/dmc.txt"
+	     << "http://www.celestrak.com/NORAD/elements/tdrss.txt"
+	     << "http://www.celestrak.com/NORAD/elements/argos.txt"
+	     << "http://www.celestrak.com/NORAD/elements/intelsat.txt"
+	     << "http://www.celestrak.com/NORAD/elements/gorizont.txt"
+	     << "http://www.celestrak.com/NORAD/elements/raduga.txt"
+	     << "http://www.celestrak.com/NORAD/elements/molniya.txt"
+	     << "http://www.celestrak.com/NORAD/elements/orbcomm.txt"
+	     << "http://www.celestrak.com/NORAD/elements/globalstar.txt"
+	     << "http://www.celestrak.com/NORAD/elements/x-comm.txt"
+	     << "http://www.celestrak.com/NORAD/elements/other-comm.txt"
+	     << "1,http://www.celestrak.com/NORAD/elements/glo-ops.txt"
+	     << "http://www.celestrak.com/NORAD/elements/beidou.txt"
+	     << "http://www.celestrak.com/NORAD/elements/sbas.txt"
+	     << "http://www.celestrak.com/NORAD/elements/nnss.txt"
+	     << "http://www.celestrak.com/NORAD/elements/engineering.txt"
+	     << "http://www.celestrak.com/NORAD/elements/education.txt"
+	     << "http://www.celestrak.com/NORAD/elements/geodetic.txt"
+	     << "http://www.celestrak.com/NORAD/elements/radar.txt"
+	     << "http://www.celestrak.com/NORAD/elements/cubesat.txt"
+	     << "http://www.celestrak.com/NORAD/elements/other.txt";
 	saveTleSources(urls);
 }
 
@@ -558,7 +586,7 @@ void Satellites::restoreDefaultCatalog()
 		// the json file has been manually removed, that an update is schreduled in a timely
 		// manner
 		StelApp::getInstance().getSettings()->remove("Satellites/last_update");
-		lastUpdate = QDateTime::fromString("2001-05-25T12:00:00", Qt::ISODate);
+		lastUpdate = QDateTime::fromString("2015-05-01T12:00:00", Qt::ISODate);
 
 	}
 }
@@ -637,8 +665,8 @@ void Satellites::loadSettings()
 	updateFrequencyHours = conf->value("update_frequency_hours", 72).toInt();
 	// last update default is the first Towell Day.  <3 DA
 	lastUpdate = QDateTime::fromString(conf->value("last_update", "2001-05-25T12:00:00").toString(), Qt::ISODate);
-	setFlagHints(conf->value("show_satellite_hints", false).toBool());
-	Satellite::showLabels = conf->value("show_satellite_labels", true).toBool();
+	setFlagHints(conf->value("show_satellite_hints", true).toBool());
+	Satellite::showLabels = conf->value("show_satellite_labels", false).toBool();
 	updatesEnabled = conf->value("updates_enabled", true).toBool();
 	autoAddEnabled = conf->value("auto_add_enabled", true).toBool();
 	autoRemoveEnabled = conf->value("auto_remove_enabled", true).toBool();
@@ -647,13 +675,13 @@ void Satellites::loadSettings()
 	labelFont.setPixelSize(conf->value("hint_font_size", 10).toInt());
 
 	// orbit drawing params
-	Satellite::orbitLinesFlag = conf->value("orbit_line_flag", true).toBool();
+	Satellite::orbitLinesFlag = conf->value("orbit_line_flag", false).toBool();
 	Satellite::orbitLineSegments = conf->value("orbit_line_segments", 90).toInt();
 	Satellite::orbitLineFadeSegments = conf->value("orbit_fade_segments", 5).toInt();
 	Satellite::orbitLineSegmentDuration = conf->value("orbit_segment_duration", 20).toInt();
 
 	// realistic mode
-	setFlagRelisticMode(conf->value("realistic_mode_enabled", false).toBool());
+	setFlagRelisticMode(conf->value("realistic_mode_enabled", true).toBool());
 
 	conf->endGroup();
 }
@@ -1418,6 +1446,14 @@ void Satellites::updateSatellites(TleDataHash& newTleSets)
 				           << "is missing in the update lists.";
 			missingCount++;
 		}
+		// All satellites, who has invalid orbit should be removed.
+		if (!sat->orbitValid)
+		{
+			toBeRemoved.append(sat->id);
+			qWarning() << "Satellite" << sat->id << sat->name
+				   << "has invalid orbit and will be removed.";
+			missingCount++;
+		}
 	}
 	
 	// Only those not in the loaded collection have remained
@@ -1689,8 +1725,18 @@ void Satellites::translations()
 	N_("non-operational");
 	// TRANSLATORS: Satellite group: Satellites belonging to the GPS constellation (the Global Positioning System)
 	N_("gps");
+	// TRANSLATORS: Satellite group: Satellites belonging to the GLONASS constellation (GLObal NAvigation Satellite System)
+	N_("glonass");
+	// TRANSLATORS: Satellite group: Satellites belonging to the Galileo constellation (global navigation satellite system by the European Union)
+	N_("galileo");
 	// TRANSLATORS: Satellite group: Satellites belonging to the Iridium constellation (Iridium is a proper name)
 	N_("iridium");
+	// TRANSLATORS: Satellite group: Space stations
+	N_("stations");
+	// TRANSLATORS: Satellite group: Education satellites
+	N_("education");
+	// TRANSLATORS: Satellite group: Satellites belonging to the space observatories
+	N_("observatory");
 	
 	/* For copy/paste:
 	// TRANSLATORS: Satellite group: 
@@ -1704,5 +1750,7 @@ void Satellites::translations()
 	N_("The Hubble Space Telescope");
 	// TRANSLATORS: Satellite description.
 	N_("The International Space Station");
+	// TRANSLATORS: Satellite description.
+	N_("China's first space station");
 #endif
 }
