@@ -58,10 +58,12 @@ void SolarSystemManagerWindow::createDialogContent()
 {
 	ui->setupUi(dialog);
 
+#ifdef Q_OS_WIN
 	//Kinetic scrolling for tablet pc and pc
 	QList<QWidget *> addscroll;
 	addscroll << ui->listWidgetObjects;
 	installKineticScrolling(addscroll);
+#endif
 
 	//Signals
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()),
@@ -76,6 +78,8 @@ void SolarSystemManagerWindow::createDialogContent()
 	connect(ssoManager, SIGNAL(solarSystemChanged()), this, SLOT(populateSolarSystemList()));
 	connect(ui->pushButtonReset, SIGNAL(clicked()), ssoManager, SLOT(resetSolarSystemToDefault()));
 
+	connect(ui->listWidgetObjects, SIGNAL(currentRowChanged(int)), this, SLOT(repaintSolarSystemList()));
+
 	updateTexts();
 
 	Q_ASSERT(mpcImportWindow);
@@ -86,6 +90,13 @@ void SolarSystemManagerWindow::createDialogContent()
 	populateSolarSystemList();
 }
 
+void SolarSystemManagerWindow::repaintSolarSystemList()
+{
+	// Enable force repaint listEvents to avoiding artifacts
+	// Seems bug in Qt5. Details: https://bugs.launchpad.net/stellarium/+bug/1350669
+	ui->listWidgetObjects->repaint();
+}
+
 void SolarSystemManagerWindow::updateTexts()
 {
 	//Solar System tab
