@@ -235,6 +235,7 @@ TelescopeTCP::TelescopeTCP(const QString &name, const QString &params, Equinox e
 	
 	interpolatedPosition.reset();
 	
+	connect(tcpSocket, SIGNAL(connected()), this, SLOT(socketConnected()));
 	connect(tcpSocket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(socketFailed(QAbstractSocket::SocketError)));
 }
 
@@ -272,7 +273,7 @@ void TelescopeTCP::telescopeGoto(const Vec3d &j2000Pos)
 		const double ra_signed = atan2(position[1], position[0]);
 		//Workaround for the discrepancy in precision between Windows/Linux/PPC Macs and Intel Macs:
 		const double ra = (ra_signed >= 0) ? ra_signed : (ra_signed + 2.0 * M_PI);
-		const double dec = atan2(position[2], sqrt(position[0]*position[0]+position[1]*position[1]));
+		const double dec = atan2(position[2], std::sqrt(position[0]*position[0]+position[1]*position[1]));
 		unsigned int ra_int = (unsigned int)floor(0.5 + ra*(((unsigned int)0x80000000)/M_PI));
 		int dec_int = (int)floor(0.5 + dec*(((unsigned int)0x80000000)/M_PI));
 		// length of packet:
@@ -515,6 +516,12 @@ void TelescopeTCP::performCommunication()
 	}
 }
 
+void TelescopeTCP::socketConnected(void)
+{
+	qDebug() << "TelescopeTCP(" << name <<"): turning off Nagle algorithm.";
+	tcpSocket->setSocketOption(QAbstractSocket::LowDelayOption, 1);
+}
+
 //TODO: More informative error messages?
 void TelescopeTCP::socketFailed(QAbstractSocket::SocketError)
 {
