@@ -43,6 +43,7 @@
 #include "LandscapeMgr.hpp"
 #include "GridLinesMgr.hpp"
 #include "MilkyWay.hpp"
+#include "ZodiacalLight.hpp"
 #include "StelLocation.hpp"
 #include "StelMainView.hpp"
 #include "StelSkyCultureMgr.hpp"
@@ -372,6 +373,11 @@ void TextUserInterface::init()
 					 SLOT(setColorGalacticEquatorLine(Vec3f)),
 					 gridLinesMgr->getColorGalacticEquatorLine(),
 					 m5, m5_19);
+	TuiNode* m5_21 = new TuiNodeColor(N_("Opposition/conjunction longitude line"),
+					 gridLinesMgr,
+					 SLOT(setColorLongitudeLine(Vec3f)),
+					 gridLinesMgr->getColorLongitudeLine(),
+					 m5, m5_20);
 
 	m5_1->setNextNode(m5_2);
 	m5_2->setNextNode(m5_3);
@@ -392,7 +398,8 @@ void TextUserInterface::init()
 	m5_17->setNextNode(m5_18);
 	m5_18->setNextNode(m5_19);
 	m5_19->setNextNode(m5_20);
-	m5_20->setNextNode(m5_1);
+	m5_20->setNextNode(m5_21);
+	m5_21->setNextNode(m5_1);
 	m5_1->loopToTheLast();
 	m5->setChildNode(m5_1);
 
@@ -423,19 +430,25 @@ void TextUserInterface::init()
 	                                 GETSTELMODULE(MilkyWay)->getIntensity(),
 	                                 0, 10.0, 0.1, 
 	                                 m6, m6_4);
-	TuiNode* m6_6 = new TuiNode(N_("Nebula label frequency:"), m6, m6_5);
-	TuiNode* m6_7 = new TuiNodeFloat(N_("Zoom duration:"),
+	TuiNode* m6_6 = new TuiNodeDouble(N_("Zodiacal light intensity:"),
+					 GETSTELMODULE(ZodiacalLight),
+					 SLOT(setIntensity(double)),
+					 GETSTELMODULE(ZodiacalLight)->getIntensity(),
+					 0, 10.0, 0.1,
+					 m6, m6_5);
+	TuiNode* m6_7 = new TuiNode(N_("Nebula label frequency:"), m6, m6_6);
+	TuiNode* m6_8 = new TuiNodeFloat(N_("Zoom duration:"),
 	                                 movementMgr,
 	                                 SLOT(setAutoMoveDuration(float)), 
 	                                 movementMgr->getAutoMoveDuration(),
 	                                 0, 20.0, 0.1,
-	                                 m6, m6_6);
-	TuiNode* m6_8 = new TuiNode(N_("Cursor timeout:"), m6, m6_7);
-	TuiNode* m6_9 = new TuiNodeBool(N_("Setting landscape sets location"),
+					 m6, m6_7);
+	TuiNode* m6_9 = new TuiNode(N_("Cursor timeout:"), m6, m6_8);
+	TuiNode* m6_10 = new TuiNodeBool(N_("Setting landscape sets location"),
 	                                landscapeMgr,
 	                                SLOT(setFlagLandscapeSetsLocation(bool)), 
 	                                landscapeMgr->getFlagLandscapeSetsLocation(), 
-	                                m6, m6_8);
+					m6, m6_9);
 	m6_1->setNextNode(m6_2);
 	m6_2->setNextNode(m6_3);
 	m6_3->setNextNode(m6_4);
@@ -444,7 +457,8 @@ void TextUserInterface::init()
 	m6_6->setNextNode(m6_7);
 	m6_7->setNextNode(m6_8);
 	m6_8->setNextNode(m6_9);
-	m6_9->setNextNode(m6_1);
+	m6_9->setNextNode(m6_10);
+	m6_10->setNextNode(m6_1);
 	m6_1->loopToTheLast();
 	m6->setChildNode(m6_1);
 
@@ -506,6 +520,7 @@ void TextUserInterface::loadConfiguration(void)
 	tuiDateTime = conf->value("tui/flag_show_tui_datetime", false).toBool();
 	tuiObjInfo = conf->value("tui/flag_show_tui_short_obj_info", false).toBool();
 	tuiGravityUi = conf->value("tui/flag_show_gravity_ui", false).toBool();
+	color = StelUtils::strToVec3f(conf->value("tui/tui_font_color", "0.3,1,0.3").toString());
 }
 
 /*************************************************************************
@@ -564,7 +579,7 @@ void TextUserInterface::draw(StelCore* core)
 
 		StelPainter painter(core->getProjection(StelCore::FrameJ2000));
 		painter.setFont(font);
-		painter.setColor(0.3,1,0.3);
+		painter.setColor(color[0],color[1],color[2]);
 		painter.drawText(text_x, text_y, tuiText, 0, 0, 0, !tuiGravityUi);
 	}
 
@@ -583,7 +598,7 @@ void TextUserInterface::draw(StelCore* core)
 
 		StelPainter painter(core->getProjection(StelCore::FrameAltAz));
 		painter.setFont(font);
-		painter.setColor(0.3,1,0.3);
+		painter.setColor(color[0],color[1],color[2]);
 		painter.drawText(text_x, text_y, newDate, 0, 0, 0, !tuiGravityUi);
 	}
 
@@ -611,7 +626,7 @@ void TextUserInterface::draw(StelCore* core)
 
 		StelPainter painter(core->getProjection(StelCore::FrameJ2000));
 		painter.setFont(font);
-		painter.setColor(0.3,1,0.3);
+		painter.setColor(color[0],color[1],color[2]);
 		painter.drawText(text_x, text_y, objInfo, 0, 0, 0, !tuiGravityUi);
 	}
 }
@@ -801,6 +816,7 @@ void TextUserInterface::saveDefaultSettings(void)
 	conf->setValue("color/planet_orbits_color", colToConf(ssmgr->getOrbitsColor()));
 	conf->setValue("color/object_trails_color", colToConf(ssmgr->getTrailsColor()));
 	conf->setValue("color/meridian_color", colToConf(glmgr->getColorMeridianLine()));
+	conf->setValue("color/longitude_color", colToConf(glmgr->getColorLongitudeLine()));
 	conf->setValue("color/azimuthal_color", colToConf(glmgr->getColorAzimuthalGrid()));
 	conf->setValue("color/equator_color", colToConf(glmgr->getColorEquatorGrid()));
 	conf->setValue("color/equatorial_J2000_color", colToConf(glmgr->getColorEquatorJ2000Grid()));
