@@ -27,6 +27,7 @@
 #include <iostream>
 
 #include <QGuiApplication>
+#include <QStandardPaths>
 #include <QDir>
 
 #include <stdio.h>
@@ -148,25 +149,11 @@ void CLIProcessor::parseCLIArgsPostConfig(const QStringList& argList, QSettings*
 		confSettings->setValue("video/fullscreen", true);
 	else if (fullScreen==0)
 		confSettings->setValue("video/fullscreen", false);
-	if (!landscapeId.isEmpty()) confSettings->setValue("init_location/landscape_name", landscapeId);
-	if (!homePlanet.isEmpty()) confSettings->setValue("init_location/home_planet", homePlanet);
-	if (altitude!=-1) confSettings->setValue("init_location/altitude", altitude);
-	if (!longitude.isEmpty())
-	{
-		QRegExp longLatRx("[\\-+]?\\d+d\\d+\\'\\d+(\\.\\d+)?\"");
-		if (longLatRx.exactMatch(longitude))
-			confSettings->setValue("init_location/longitude", longitude);
-		else
-			qWarning() << "WARNING: --longitude argument has unrecognised format";
-	}
-	if (!latitude.isEmpty())
-	{
-		QRegExp longLatRx("[\\-+]?\\d+d\\d+\\'\\d+(\\.\\d+)?\"");
-		if (longLatRx.exactMatch(latitude))
-			confSettings->setValue("init_location/latitude", latitude);
-		else
-			qWarning() << "WARNING: --latitude argument has unrecognised format";
-	}
+	if (!landscapeId.isEmpty()) confSettings->setValue("location_run_once/landscape_name", landscapeId);
+	if (!homePlanet.isEmpty()) confSettings->setValue("location_run_once/home_planet", homePlanet);
+	if (altitude!=-1) confSettings->setValue("location_run_once/altitude", altitude);
+	if (!longitude.isEmpty()) confSettings->setValue("location_run_once/longitude", StelUtils::getDecAngle(longitude)); // Store longitude in radian
+	if (!latitude.isEmpty()) confSettings->setValue("location_run_once/latitude", StelUtils::getDecAngle(latitude)); // Store latitude in radian
 
 	if (!skyDate.isEmpty() || !skyTime.isEmpty())
 	{
@@ -246,6 +233,24 @@ void CLIProcessor::parseCLIArgsPostConfig(const QStringList& argList, QSettings*
 				qWarning() << "WARNING: problem while setting screenshot from config file setting: " << e.what();
 			}
 		}
+		else
+		{
+			QString screenshotDirSuffix = "/Stellarium";
+			if (!QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).isEmpty())
+				screenshotDir = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation)[0].append(screenshotDirSuffix);
+			else
+				screenshotDir = StelFileMgr::getUserDir().append(screenshotDirSuffix);
+
+			try
+			{
+				StelFileMgr::setScreenshotDir(screenshotDir);
+				confSettings->setValue("main/screenshot_dir", screenshotDir);
+			}
+			catch (std::runtime_error &e)
+			{
+				qDebug("Error: cannot create screenshot directory: %s", e.what());
+			}
+		}
 	}
 }
 
@@ -283,7 +288,7 @@ QVariant CLIProcessor::argsGetOptionWithArg(const QStringList& args, QString sho
 		QString argStr;
 
 		// form -n=arg
-		if ((shortOpt!="" && args.at(i).left(shortOpt.length()+1)==shortOpt+"="))
+		if ((!shortOpt.isEmpty() && args.at(i).left(shortOpt.length()+1)==shortOpt+"="))
 		{
 			match=true;
 			argStr=args.at(i).right(args.at(i).length() - shortOpt.length() - 1);
@@ -295,7 +300,7 @@ QVariant CLIProcessor::argsGetOptionWithArg(const QStringList& args, QString sho
 			argStr=args.at(i).right(args.at(i).length() - longOpt.length() - 1);
 		}
 		// forms -n arg and --number arg
-		else if ((shortOpt!="" && args.at(i)==shortOpt) || args.at(i)==longOpt)
+		else if ((!shortOpt.isEmpty() && args.at(i)==shortOpt) || args.at(i)==longOpt)
 		{
 			if (i+1>=lastOptIdx)
 			{
