@@ -20,8 +20,6 @@
 #ifndef _STELACTIONMGR_HPP_
 #define _STELACTIONMGR_HPP_
 
-#include "config.h"
-
 #include <QObject>
 #include <QKeySequence>
 #include <QList>
@@ -42,8 +40,9 @@ public:
 		, target(NULL)
 		, property(NULL)
 	#ifndef USE_QUICKVIEW
-		, qAction(NULL) {}
+		, qAction(NULL)
 	#endif
+	{}
 
 	StelAction(const QString& actionId,
 	           const QString& groupId,
