@@ -28,6 +28,7 @@
 #include "LandscapeMgr.hpp"
 #include "GridLinesMgr.hpp"
 #include "MilkyWay.hpp"
+#include "ZodiacalLight.hpp"
 #include "MeteorMgr.hpp"
 #include "LabelMgr.hpp"
 #include "StarMgr.hpp"
@@ -75,16 +76,7 @@
 #include <QDir>
 #include <QCoreApplication>
 #include <QScreen>
-
-Q_IMPORT_PLUGIN(StelStandardGuiPluginInterface)
-
-#ifdef USE_STATIC_PLUGIN_VIRGO
-Q_IMPORT_PLUGIN(VirGOStelPluginInterface)
-#endif
-
-#ifdef USE_STATIC_PLUGIN_SVMT
-Q_IMPORT_PLUGIN(SVMTStelPluginInterface)
-#endif
+#include <QDateTime>
 
 #ifdef USE_STATIC_PLUGIN_HELLOSTELMODULE
 Q_IMPORT_PLUGIN(HelloStelModuleStelPluginInterface)
@@ -98,6 +90,10 @@ Q_IMPORT_PLUGIN(SimpleDrawLineStelPluginInterface)
 Q_IMPORT_PLUGIN(AngleMeasureStelPluginInterface)
 #endif
 
+#ifdef USE_STATIC_PLUGIN_ARCHAEOLINES
+Q_IMPORT_PLUGIN(ArchaeoLinesStelPluginInterface)
+#endif
+
 #ifdef USE_STATIC_PLUGIN_COMPASSMARKS
 Q_IMPORT_PLUGIN(CompassMarksStelPluginInterface)
 #endif
@@ -174,20 +170,22 @@ Q_IMPORT_PLUGIN(PointerCoordinatesStelPluginInterface)
 Q_IMPORT_PLUGIN(ObservabilityStelPluginInterface)
 #endif
 
+#ifdef USE_STATIC_PLUGIN_SCENERY3D
+Q_IMPORT_PLUGIN(Scenery3dStelPluginInterface)
+#endif
+
 // Initialize static variables
 StelApp* StelApp::singleton = NULL;
-QTime* StelApp::qtime = NULL;
+qint64 StelApp::startMSecs = 0;
 
 void StelApp::initStatic()
 {
-	StelApp::qtime = new QTime();
-	StelApp::qtime->start();
+	StelApp::startMSecs = QDateTime::currentMSecsSinceEpoch();
 }
 
 void StelApp::deinitStatic()
 {
-	delete StelApp::qtime;
-	StelApp::qtime = NULL;
+	StelApp::startMSecs = 0;
 }
 
 /*************************************************************************
@@ -219,6 +217,7 @@ StelApp::StelApp(QObject* parent)
 	, baseFontSize(13)
 	, renderBuffer(NULL)
 	, viewportEffect(NULL)
+	, flagShowDecimalDegrees(false)
 {
 	// Stat variables
 	nbDownloadedFiles=0;
@@ -427,6 +426,11 @@ void StelApp::init(QSettings* conf)
 	milky_way->init();
 	getModuleMgr().registerModule(milky_way);
 
+	// Init zodiacal light
+	ZodiacalLight* zodiacal_light = new ZodiacalLight();
+	zodiacal_light->init();
+	getModuleMgr().registerModule(zodiacal_light);
+
 	// Init sky image manager
 	skyImageMgr = new StelSkyLayerMgr();
 	skyImageMgr->init();
@@ -480,6 +484,8 @@ void StelApp::init(QSettings* conf)
 	// Init actions.
 	actionMgr->addAction("actionShow_Night_Mode", N_("Display Options"), N_("Night mode"), this, "nightMode");
 
+	setFlagShowDecimalDegrees(confSettings->value("gui/flag_show_decimal_degrees", false).toBool());
+	
 	initialized = true;
 }
 
@@ -733,6 +739,12 @@ void StelApp::setVisionModeNight(bool b)
 	}
 }
 
+
+void StelApp::setFlagShowDecimalDegrees(bool b)
+{
+	flagShowDecimalDegrees = b;
+}
+
 // Update translations and font for sky everywhere in the program
 void StelApp::updateI18n()
 {
@@ -751,7 +763,7 @@ void StelApp::updateSkyCulture()
 // Return the time since when stellarium is running in second.
 double StelApp::getTotalRunTime()
 {
-	return (double)(StelApp::qtime->elapsed())/1000.;
+	return (double)(QDateTime::currentMSecsSinceEpoch() - StelApp::startMSecs)/1000.;
 }
 
 
