@@ -111,14 +111,21 @@ void StelCore::init()
 {
 	QSettings* conf = StelApp::getInstance().getSettings();
 
-	defaultLocationID = conf->value("init_location/location", "auto").toString();
+	if (conf->childGroups().contains("location_run_once"))
+		defaultLocationID = "stellarium_cli";
+	else
+		defaultLocationID = conf->value("init_location/location", "auto").toString();
 	bool ok;
 	StelLocationMgr* locationMgr = &StelApp::getInstance().getLocationMgr();
-	StelLocation location;
+	StelLocation location=locationMgr->getLastResortLocation(); // first location: Paris. Required if no IP connection on first launch!
 	if (defaultLocationID == "auto")
 	{
 		locationMgr->locationFromIP();
 	}
+	else if (defaultLocationID == "stellarium_cli")
+	{
+		location = locationMgr->locationFromCLI();
+	}
 	else
 	{
 		location = locationMgr->locationForString(defaultLocationID);
@@ -176,8 +183,7 @@ void StelCore::init()
 	skyDrawer = new StelSkyDrawer(this);
 	skyDrawer->init();
 
-	QString tmpstr = conf->value("projection/type", "ProjectionStereographic").toString();
-	setCurrentProjectionTypeKey(tmpstr);
+	setCurrentProjectionTypeKey(getDefaultProjectionTypeKey());
 
 	// Register all the core actions.
 	QString timeGroup = N_("Date and Time");
@@ -229,6 +235,11 @@ void StelCore::init()
 	
 }
 
+QString StelCore::getDefaultProjectionTypeKey() const
+{
+	QSettings* conf = StelApp::getInstance().getSettings();
+	return conf->value("projection/type", "ProjectionStereographic").toString();
+}
 
 // Get the shared instance of StelGeodesicGrid.
 // The returned instance is garanteed to allow for at least maxLevel levels
@@ -408,7 +419,7 @@ void StelCore::preDraw()
 {
 	// Init openGL viewing with fov, screen size and clip planes
 	currentProjectorParams.zNear = 0.000001;
-	currentProjectorParams.zFar = 50.;
+	currentProjectorParams.zFar = 500.;
 
 	skyDrawer->preDraw();
 
@@ -562,7 +573,7 @@ void StelCore::lookAtJ2000(const Vec3d& pos, const Vec3d& aup)
 
 Vec3d StelCore::altAzToEquinoxEqu(const Vec3d& v, RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return matAltAzToEquinoxEqu*v;
 	Vec3d r(v);
 	skyDrawer->getRefraction().backward(r);
@@ -572,7 +583,7 @@ Vec3d StelCore::altAzToEquinoxEqu(const Vec3d& v, RefractionMode refMode) const
 
 Vec3d StelCore::equinoxEquToAltAz(const Vec3d& v, RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return matEquinoxEquToAltAz*v;
 	Vec3d r(v);
 	r.transfo4d(matEquinoxEquToAltAz);
@@ -582,7 +593,7 @@ Vec3d StelCore::equinoxEquToAltAz(const Vec3d& v, RefractionMode refMode) const
 
 Vec3d StelCore::altAzToJ2000(const Vec3d& v, RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return matEquinoxEquToJ2000*matAltAzToEquinoxEqu*v;
 	Vec3d r(v);
 	skyDrawer->getRefraction().backward(r);
@@ -592,7 +603,7 @@ Vec3d StelCore::altAzToJ2000(const Vec3d& v, RefractionMode refMode) const
 
 Vec3d StelCore::j2000ToAltAz(const Vec3d& v, RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return matJ2000ToAltAz*v;
 	Vec3d r(v);
 	r.transfo4d(matJ2000ToAltAz);
@@ -623,7 +634,7 @@ Vec3d StelCore::j2000ToGalactic(const Vec3d& v) const
 //! Transform vector from heliocentric ecliptic coordinate to altazimuthal
 Vec3d StelCore::heliocentricEclipticToAltAz(const Vec3d& v, RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return matHeliocentricEclipticToAltAz*v;
 	Vec3d r(v);
 	r.transfo4d(matHeliocentricEclipticToAltAz);
@@ -646,7 +657,7 @@ Vec3d StelCore::heliocentricEclipticToEarthPosEquinoxEqu(const Vec3d& v) const
 
 StelProjector::ModelViewTranformP StelCore::getHeliocentricEclipticModelViewTransform(RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return StelProjector::ModelViewTranformP(new StelProjector::Mat4dTransform(matAltAzModelView*matHeliocentricEclipticToAltAz));
 	Refraction* refr = new Refraction(skyDrawer->getRefraction());
 	// The pretransform matrix will convert from input coordinates to AltAz needed by the refraction function.
@@ -658,7 +669,7 @@ StelProjector::ModelViewTranformP StelCore::getHeliocentricEclipticModelViewTran
 //! Get the modelview matrix for observer-centric ecliptic (Vsop87) drawing
 StelProjector::ModelViewTranformP StelCore::getObservercentricEclipticModelViewTransform(RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return StelProjector::ModelViewTranformP(new StelProjector::Mat4dTransform(matAltAzModelView*matJ2000ToAltAz*matVsop87ToJ2000));
 	Refraction* refr = new Refraction(skyDrawer->getRefraction());
 	// The pretransform matrix will convert from input coordinates to AltAz needed by the refraction function.
@@ -670,7 +681,7 @@ StelProjector::ModelViewTranformP StelCore::getObservercentricEclipticModelViewT
 //! Get the modelview matrix for observer-centric equatorial at equinox drawing
 StelProjector::ModelViewTranformP StelCore::getEquinoxEquModelViewTransform(RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return StelProjector::ModelViewTranformP(new StelProjector::Mat4dTransform(matAltAzModelView*matEquinoxEquToAltAz));
 	Refraction* refr = new Refraction(skyDrawer->getRefraction());
 	// The pretransform matrix will convert from input coordinates to AltAz needed by the refraction function.
@@ -682,7 +693,7 @@ StelProjector::ModelViewTranformP StelCore::getEquinoxEquModelViewTransform(Refr
 //! Get the modelview matrix for observer-centric altazimuthal drawing
 StelProjector::ModelViewTranformP StelCore::getAltAzModelViewTransform(RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 	{
 		// Catch problem with improperly initialized matAltAzModelView
 		Q_ASSERT(matAltAzModelView[0]==matAltAzModelView[0]);
@@ -697,7 +708,7 @@ StelProjector::ModelViewTranformP StelCore::getAltAzModelViewTransform(Refractio
 //! Get the modelview matrix for observer-centric J2000 equatorial drawing
 StelProjector::ModelViewTranformP StelCore::getJ2000ModelViewTransform(RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return StelProjector::ModelViewTranformP(new StelProjector::Mat4dTransform(matAltAzModelView*matEquinoxEquToAltAz*matJ2000ToEquinoxEqu));
 	Refraction* refr = new Refraction(skyDrawer->getRefraction());
 	// The pretransform matrix will convert from input coordinates to AltAz needed by the refraction function.
@@ -709,7 +720,7 @@ StelProjector::ModelViewTranformP StelCore::getJ2000ModelViewTransform(Refractio
 //! Get the modelview matrix for observer-centric Galactic equatorial drawing
 StelProjector::ModelViewTranformP StelCore::getGalacticModelViewTransform(RefractionMode refMode) const
 {
-	if (refMode==RefractionOff || skyDrawer==false || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
+	if (refMode==RefractionOff || skyDrawer==NULL || (refMode==RefractionAuto && skyDrawer->getFlagHasAtmosphere()==false))
 		return StelProjector::ModelViewTranformP(new StelProjector::Mat4dTransform(matAltAzModelView*matEquinoxEquToAltAz*matJ2000ToEquinoxEqu*matGalacticToJ2000));
 	Refraction* refr = new Refraction(skyDrawer->getRefraction());
 	// The pretransform matrix will convert from input coordinates to AltAz needed by the refraction function.
@@ -773,16 +784,25 @@ void StelCore::returnToHome()
 	// Using returnToDefaultLocation() and getCurrentLocation() introduce issue, because for flying
 	// between planets using SpaceShip and second method give does not exist data
 	StelLocationMgr& locationMgr = StelApp::getInstance().getLocationMgr();
-	StelLocation loc = locationMgr.locationForString(defaultLocationID);
+	StelLocation loc;
+	if (defaultLocationID == "auto")
+	{
+		locationMgr.locationFromIP();
+		loc = locationMgr.getLastResortLocation();
+	}
+	else
+		loc = locationMgr.locationForString(defaultLocationID);
+
 	if (loc.isValid())
 		moveObserverTo(loc, 0.);
 
 	PlanetP p = GETSTELMODULE(SolarSystem)->searchByEnglishName(loc.planetName);
+	QSettings* conf = StelApp::getInstance().getSettings();
 
 	LandscapeMgr* landscapeMgr = GETSTELMODULE(LandscapeMgr);
 	landscapeMgr->setCurrentLandscapeID(landscapeMgr->getDefaultLandscapeID());
-	landscapeMgr->setFlagAtmosphere(p->hasAtmosphere());
-	landscapeMgr->setFlagFog(p->hasAtmosphere());
+	landscapeMgr->setFlagAtmosphere(p->hasAtmosphere() && conf->value("landscape/flag_atmosphere", true).toBool());
+	landscapeMgr->setFlagFog(p->hasAtmosphere() && conf->value("landscape/flag_fog", true).toBool());
 
 	GETSTELMODULE(StelObjectMgr)->unSelect();
 
@@ -1448,16 +1468,22 @@ double StelCore::getDeltaT(double jDay) const
 			// Islam, Sadiq & Qureshi (2008 + revisited 2013) algorithm for DeltaT (6 polynomials)
 			ndot = -26.0; // n.dot = -26.0 "/cy/cy
 			DeltaT = StelUtils::getDeltaTByIslamSadiqQureshi(jDay);
+			dontUseMoon = true; // Seems this solutions doesn't use value of secular acceleration of the Moon
+			break;
+		case KhalidSultanaZaidi:
+			// M. Khalid, Mariam Sultana and Faheem Zaidi polinomial approximation of time period 1620-2013 (2014)
+			ndot = -26.0; // n.dot = -26.0 "/cy/cy
+			DeltaT = StelUtils::getDeltaTByKhalidSultanaZaidi(jDay);
+			dontUseMoon = true; // Seems this solutions doesn't use value of secular acceleration of the Moon
 			break;
 		case Custom:
 			// User defined coefficients for quadratic equation for DeltaT
 			ndot = getDeltaTCustomNDot(); // n.dot = custom value "/cy/cy
 			int year, month, day;
 			Vec3f coeff = getDeltaTCustomEquationCoefficients();
-			StelUtils::getDateFromJulianDay(jDay, &year, &month, &day);
-			double yeardec=year+((month-1)*30.5+day/31*30.5)/366;
-			double u = (yeardec-getDeltaTCustomYear())/100;
-			DeltaT = coeff[0] + coeff[1]*u + coeff[2]*std::pow(u,2);
+			StelUtils::getDateFromJulianDay(jDay, &year, &month, &day);			
+			double u = (StelUtils::getDecYear(year,month,day)-getDeltaTCustomYear())/100;
+			DeltaT = coeff[0] + u*(coeff[1] + u*coeff[2]);
 			break;
 	}
 
@@ -1582,6 +1608,9 @@ QString StelCore::getCurrentDeltaTAlgorithmDescription(void) const
 		case IslamSadiqQureshi:
 			description = q_("This solution by S. Islam, M. Sadiq and M. S. Qureshi, based on Meeus & Simons (2000), was published in article <em>Error Minimization of Polynomial Approximation of DeltaT</em> (%1) and revisited by Sana Islam in 2013.").arg("<a href='http://www.ias.ac.in/jaa/dec2008/JAA610.pdf'>2008</a>").append(getCurrentDeltaTAlgorithmValidRange(jd, &marker));
 			break;
+		case KhalidSultanaZaidi:
+			description = q_("This polynomial approximation with 0.6 seconds of accuracy by M. Khalid, Mariam Sultana and Faheem Zaidi was published in <em>Delta T: Polynomial Approximation of Time Period 1620-2013</em> (%1).").arg("<a href='http://dx.doi.org/10.1155/2014/480964'>2014</a>").append(getCurrentDeltaTAlgorithmValidRange(jd, &marker));
+			break;
 		case Custom:
 			description = q_("This is a quadratic formula for calculation of %1T with coefficients defined by the user.").arg(QChar(0x0394));
 			break;
@@ -1723,6 +1752,11 @@ QString StelCore::getCurrentDeltaTAlgorithmValidRange(double jDay, QString *mark
 			finish	= 2007;
 			validRangeAppendix = q_("with zero values outside this range");
 			break;
+		case KhalidSultanaZaidi:
+			start	= 1620;
+			finish	= 2013;
+			validRangeAppendix = q_("with zero values outside this range");
+			break;
 		case Custom:
 			// Valid range unknown
 			break;
