@@ -36,7 +36,7 @@
 StelMovementMgr::StelMovementMgr(StelCore* acore)
 	: currentFov(60.)
 	, initFov(60.)
-	, minFov(0.0001)
+	, minFov(0.001389)
 	, maxFov(100.)
 	, initConstellationIntensity(0.45)
 	, core(acore)
@@ -102,7 +102,9 @@ void StelMovementMgr::init()
 	flagAutoZoomOutResetsDirection = conf->value("navigation/auto_zoom_out_resets_direction", true).toBool();
 	flagEnableMouseNavigation = conf->value("navigation/flag_enable_mouse_navigation",true).toBool();
 
-	minFov = 0.0001;
+	minFov = 0.001389; // minimal FOV = 5"
+	// GZ: This value should be configurable! Zooming in too much is useless for archaeoastronomy.
+	minFov = conf->value("navigation/min_fov",minFov).toDouble();
 	maxFov = 100.;
 	initFov = conf->value("navigation/init_fov",60.f).toFloat();
 	currentFov = initFov;
@@ -208,10 +210,19 @@ bool StelMovementMgr::handleMouseMoves(int x, int y, Qt::MouseButtons)
 	return false;
 }
 
+double StelMovementMgr::getCallOrder(StelModuleActionName actionName) const
+{
+	// GZ: allow a few plugins to intercept keys!
+	if (actionName == StelModule::ActionHandleKeys)
+		return 5;
+	return 0;
+}
+
+
 
 void StelMovementMgr::handleKeys(QKeyEvent* event)
 {
-	if (event->type() == QEvent::KeyPress)
+        if (event->type() == QEvent::KeyPress)
 	{
 		// Direction and zoom deplacements
 		switch (event->key())
@@ -321,8 +332,10 @@ void StelMovementMgr::addTimeDragPoint(int x, int y)
 
 bool StelMovementMgr::handlePinch(qreal scale, bool started)
 {
+#ifdef Q_OS_WIN
 	if (flagEnableMouseNavigation == false)
 		return true;
+#endif
 
 	static double previousFov = 0;
 	if (started)
@@ -796,7 +809,7 @@ void StelMovementMgr::moveToJ2000(const Vec3d& aim, float moveDuration, int zoom
 	move.aim=aim;
 	move.aim.normalize();
 	move.aim*=2.;
-	move.start=viewDirectionJ2000;
+	move.start=viewDirectionJ2000;	
 	move.start.normalize();
 	move.speed=1.f/(moveDuration*1000);
 	move.coef=0.;
