@@ -67,6 +67,8 @@ public:
 	virtual void handleMouseWheel(class QWheelEvent* event);
 	//! Handle mouse click events.
 	virtual void handleMouseClicks(class QMouseEvent* event);
+	// GZ: allow some keypress interaction by plugins.
+	virtual double getCallOrder(StelModuleActionName actionName) const;
 	//! Handle pinch gesture.
 	virtual bool handlePinch(qreal scale, bool started);
 
@@ -131,7 +133,7 @@ public slots:
 	//! Set whether keys can control zoom
 	void setFlagEnableZoomKeys(bool b) {flagEnableZoomKeys=b;}
 
-	//! Get whether keys can control move
+	//! Get whether keys can control movement
 	bool getFlagEnableMoveKeys() const {return flagEnableMoveKeys;}
 	//! Set whether keys can control movement
 	void setFlagEnableMoveKeys(bool b) {flagEnableMoveKeys=b;}
