@@ -45,9 +45,10 @@ public:
 	//! Define the drawing mode when drawing polygons
 	enum SphericalPolygonDrawMode
 	{
-		SphericalPolygonDrawModeFill=0,			//!< Draw the interior of the polygon
-		SphericalPolygonDrawModeBoundary=1,		//!< Draw the boundary of the polygon
-		SphericalPolygonDrawModeTextureFill=2	//!< Draw the interior of the polygon filled with the current texture
+		SphericalPolygonDrawModeFill=0,				//!< Draw the interior of the polygon
+		SphericalPolygonDrawModeBoundary=1,			//!< Draw the boundary of the polygon
+		SphericalPolygonDrawModeTextureFill=2,			//!< Draw the interior of the polygon filled with the current texture
+		SphericalPolygonDrawModeTextureFillColormodulated=3	//!< Draw the interior of the polygon filled with the current texture multiplied by vertex colors
 	};
 
 	//! Define the drawing mode when drawing vertex
@@ -70,7 +71,8 @@ public:
 	void setProjector(const StelProjectorP& p);
 
 	//! Fill with black around the viewport.
-	void drawViewportShape();
+	void drawViewportShape(void);
+	void drawViewportShape(const GLfloat innerRadius);
 
 	//! Draw the string at the given position and angle with the given font.
 	//! If the gravity label flag is set, uses drawTextGravity180.
@@ -83,9 +85,9 @@ public:
 	//! @param noGravity don't take into account the fact that the text should be written with gravity.
 	//! @param v direction vector of object to draw. GZ20120826: Will draw only if this is in the visible hemisphere.
 	void drawText(float x, float y, const QString& str, float angleDeg=0.f,
-			  float xshift=0.f, float yshift=0.f, const bool noGravity=true);
-	void drawText(const Vec3d& v, const QString& str, const float angleDeg=0.f,
-			  const float xshift=0.f, const float yshift=0.f, const bool noGravity=true);
+              float xshift=0.f, float yshift=0.f, bool noGravity=true);
+	void drawText(const Vec3d& v, const QString& str, float angleDeg=0.f,
+              float xshift=0.f, float yshift=0.f, bool noGravity=true);
 
 	//! Draw the given SphericalRegion.
 	//! @param region The SphericalRegion to draw.
@@ -97,13 +99,14 @@ public:
 
 	void drawGreatCircleArcs(const StelVertexArray& va, const SphericalCap* clippingCap=NULL);
 
-	void drawSphericalTriangles(const StelVertexArray& va, const bool textured, const SphericalCap* clippingCap=NULL, const bool doSubDivide=true, const double maxSqDistortion=5.);
+	void drawSphericalTriangles(const StelVertexArray& va, bool textured, bool colored, const SphericalCap* clippingCap=NULL, bool doSubDivide=true, double maxSqDistortion=5.);
 
 	//! Draw a small circle arc between points start and stop with rotation point in rotCenter.
 	//! The angle between start and stop must be < 180 deg.
 	//! The algorithm ensures that the line will look smooth, even for non linear distortion.
 	//! Each time the small circle crosses the edge of the viewport, the viewportEdgeIntersectCallback is called with the
 	//! screen 2d position, direction of the currently drawn arc toward the inside of the viewport.
+	//! Example: A latitude circle has 0/0/sin(latitude) as rotCenter.
 	//! If rotCenter is equal to 0,0,0, the method draws a great circle.
 	void drawSmallCircleArc(const Vec3d& start, const Vec3d& stop, const Vec3d& rotCenter, void (*viewportEdgeIntersectCallback)(const Vec3d& screenPos, const Vec3d& direction, void* userData)=NULL, void* userData=NULL);
 
@@ -116,7 +119,7 @@ public:
 	void drawGreatCircleArc(const Vec3d& start, const Vec3d& stop, const SphericalCap* clippingCap=NULL, void (*viewportEdgeIntersectCallback)(const Vec3d& screenPos, const Vec3d& direction, void* userData)=NULL, void* userData=NULL);
 
 	//! Draw a simple circle, 2d viewport coordinates in pixel
-	void drawCircle(const float x, const float y, float r);
+	void drawCircle(float x, float y, float r);
 
 	//! Draw a square using the current texture at the given projected 2d position.
 	//! This method is not thread safe.
@@ -124,11 +127,11 @@ public:
 	//! @param y y position in the viewport in pixel.
 	//! @param radius the half size of a square side in pixel.
 	//! @param v direction vector of object to draw. GZ20120826: Will draw only if this is in the visible hemisphere.
-	void drawSprite2dMode(const float x, const float y, float radius);
-	void drawSprite2dMode(const Vec3d& v, const float radius);
+	void drawSprite2dMode(float x, float y, float radius);
+	void drawSprite2dMode(const Vec3d& v, float radius);
 
 	//! Same as drawSprite2dMode but don't scale according to display device scaling. 
-	void drawSprite2dModeNoDeviceScale(const float x, const float y, const float radius);
+	void drawSprite2dModeNoDeviceScale(float x, float y, float radius);
 	
 	//! Draw a rotated square using the current texture at the given projected 2d position.
 	//! This method is not thread safe.
@@ -141,14 +144,14 @@ public:
 	//! Draw a GL_POINT at the given position.
 	//! @param x x position in the viewport in pixels.
 	//! @param y y position in the viewport in pixels.
-	void drawPoint2d(const float x, const float y);
+	void drawPoint2d(float x, float y);
 
 	//! Draw a line between the 2 points.
 	//! @param x1 x position of point 1 in the viewport in pixels.
 	//! @param y1 y position of point 1 in the viewport in pixels.
 	//! @param x2 x position of point 2 in the viewport in pixels.
 	//! @param y2 y position of point 2 in the viewport in pixels.
-	void drawLine2d(const float x1, const float y1, const float x2, const float y2);
+	void drawLine2d(float x1, float y1, float x2, float y2);
 
 	//! Draw a rectangle using the current texture at the given projected 2d position.
 	//! This method is not thread safe.
@@ -157,7 +160,7 @@ public:
 	//! @param width width in pixel.
 	//! @param height height in pixel.
 	//! @param textured whether the current texture should be used for painting.
-	void drawRect2d(const float x, const float y, const float width, const float height, const bool textured=true);
+	void drawRect2d(float x, float y, float width, float height, bool textured=true);
 
 	//! Re-implementation of gluSphere : glu is overridden for non-standard projection.
 	//! @param radius
@@ -165,7 +168,7 @@ public:
 	//! @param slices: number of vertical segments ("meridian zones")
 	//! @param stacks: number of horizontal segments ("latitude zones")
 	//! @param orientInside: 1 to have normals point inside, e.g. for landscape horizons
-	//! @param flipTexture: if texture should be mapped to inside of shere, e.g. landscape horizons.
+	//! @param flipTexture: if texture should be mapped to inside of sphere, e.g. landscape horizons.
 	//! @param topAngle GZ: new parameter. An opening angle [radians] at top of the sphere. Useful if there is an empty
 	//!        region around the top pole, like for a spherical equirectangular horizon panorama (@class SphericalLandscape).
 	//!        Example: your horizon line (pano photo) goes up to 26 degrees altitude (highest mountains/trees):
@@ -174,15 +177,26 @@ public:
 	//!        region around the bottom pole, like for a spherical equirectangular horizon panorama (SphericalLandscape class).
 	//!        Example: your light pollution image (pano photo) goes down to just -5 degrees altitude (lowest street lamps below you):
 	//!        bottomAngle = 95 degrees = 95*M_PI/180.0f
-	void sSphere(const float radius, const float oneMinusOblateness, const int slices, const int stacks, const int orientInside = 0, const bool flipTexture = false,
-				 const float topAngle=0.0f, const float bottomAngle=M_PI);
+	void sSphere(float radius, float oneMinusOblateness, int slices, int stacks, int orientInside = 0, bool flipTexture = false,
+                 float topAngle=0.0f, float bottomAngle=M_PI);
 
 	//! Generate a StelVertexArray for a sphere.
-	static StelVertexArray computeSphereNoLight(const float radius, const float oneMinusOblateness, const int slices, const int stacks,
-												const int orientInside = 0, const bool flipTexture = false);
+	//! @param radius
+	//! @param oneMinusOblateness
+	//! @param slices: number of vertical segments ("meridian zones")
+	//! @param stacks: number of horizontal segments ("latitude zones")
+	//! @param orientInside: 1 to have normals point inside, e.g. for Milky Way, Zodiacal Light, etc.
+	//! @param flipTexture: if texture should be mapped to inside of sphere, e.g. Milky Way.
+	//! @param topAngle GZ: new parameter. An opening angle [radians] at top of the sphere. Useful if there is an empty
+	//!        region around the top pole, like North Galactic Pole.
+	//! @param bottomAngle GZ: new parameter. An opening angle [radians] at bottom of the sphere. Useful if there is an empty
+	//!        region around the bottom pole, like South Galactic Pole.
+	static StelVertexArray computeSphereNoLight(float radius, float oneMinusOblateness, int slices, int stacks,
+                            int orientInside = 0, bool flipTexture = false,
+                            float topAngle=0.0f, float bottomAngle=M_PI);
 
 	//! Re-implementation of gluCylinder : glu is overridden for non-standard projection.
-	void sCylinder(const float radius, const float height, const int slices, const int orientInside = 0);
+	void sCylinder(float radius, float height, int slices, int orientInside = 0);
 
 	//! Draw a disk with a special texturing mode having texture center at center of disk.
 	//! The disk is made up of concentric circles with increasing refinement.
@@ -195,7 +209,7 @@ public:
 	static void computeFanDisk(float radius, int innerFanSlices, int level, QVector<double>& vertexArr, QVector<float>& texCoordArr);
 
 	//! Draw a fisheye texture in a sphere.
-	void sSphereMap(const float radius, const int slices, const int stacks, const float textureFov = 2.f*M_PI, const int orientInside = 0);
+	void sSphereMap(float radius, int slices, int stacks, float textureFov = 2.f*M_PI, int orientInside = 0);
 
 	//! Set the font to use for subsequent text drawing.
 	void setFont(const QFont& font);
@@ -218,34 +232,34 @@ public:
 	static void deinitGLShaders();
 
 	//! Set whether texturing is enabled.
-	void enableTexture2d(const bool b);
+	void enableTexture2d(bool b);
 
 	// Thoses methods should eventually be replaced by a single setVertexArray
 	//! use instead of glVertexPointer
-	void setVertexPointer(const int size, const int type, const void* pointer) {
+	void setVertexPointer(int size, int type, const void* pointer) {
 		vertexArray.size = size; vertexArray.type = type; vertexArray.pointer = pointer;
 	}
 
 	//! use instead of glTexCoordPointer
-	void setTexCoordPointer(const int size, const int type, const void* pointer)
+	void setTexCoordPointer(int size, int type, const void* pointer)
 	{
 		texCoordArray.size = size; texCoordArray.type = type; texCoordArray.pointer = pointer;
 	}
 
 	//! use instead of glColorPointer
-	void setColorPointer(const int size, const int type, const void* pointer)
+	void setColorPointer(int size, int type, const void* pointer)
 	{
 		colorArray.size = size; colorArray.type = type; colorArray.pointer = pointer;
 	}
 
 	//! use instead of glNormalPointer
-	void setNormalPointer(const int type, const void* pointer)
+	void setNormalPointer(int type, const void* pointer)
 	{
 		normalArray.size = 3; normalArray.type = type; normalArray.pointer = pointer;
 	}
 
 	//! use instead of glEnableClient
-	void enableClientStates(const bool vertex, const bool texture=false, const bool color=false, const bool normal=false);
+	void enableClientStates(bool vertex, bool texture=false, bool color=false, bool normal=false);
 
 	//! convenience method that enable and set all the given arrays.
 	//! It is equivalent to calling enableClientState and set the array pointer for each arrays.
@@ -257,11 +271,11 @@ public:
 	//! If @param indices is NULL, this operation will consume @param count values from the enabled arrays, starting at @param offset.
 	//! Else it will consume @param count elements of @param indices, starting at @param offset, which are used to index into the
 	//! enabled arrays.
-	void drawFromArray(const DrawingMode mode, const int count, const int offset=0, const bool doProj=true, const unsigned short *indices=NULL);
+	void drawFromArray(DrawingMode mode, int count, int offset=0, bool doProj=true, const unsigned short *indices=NULL);
 
 	//! Draws the primitives defined in the StelVertexArray.
 	//! @param checkDiscontinuity will check and suppress discontinuities if necessary.
-	void drawStelVertexArray(const StelVertexArray& arr, const bool checkDiscontinuity=true);
+	void drawStelVertexArray(const StelVertexArray& arr, bool checkDiscontinuity=true);
 
 	//! Link an opengl program and show a message in case of error or warnings.
 	//! @return true if the link was successful.
@@ -304,11 +318,14 @@ private:
 	//! @param vertices a pointer to an array of 3 vertices.
 	//! @param edgeFlags a pointer to an array of 3 flags indicating whether the next segment is an edge.
 	//! @param texturePos a pointer to an array of 3 texture coordinates, or NULL if the triangle should not be textured.
+	//! @param colors a pointer to an array of 3 colors, or NULL if the triangle should not be vertex-colored. If texture and color coords are present, texture is modulated by vertex colors. (e.g. extinction)
 	void projectSphericalTriangle(const SphericalCap* clippingCap, const Vec3d* vertices, QVarLengthArray<Vec3f, 4096>* outVertices,
-			const Vec2f* texturePos=NULL, QVarLengthArray<Vec2f, 4096>* outTexturePos=NULL, const double maxSqDistortion=5., const int nbI=0,
-			const bool checkDisc1=true, const bool checkDisc2=true, const bool checkDisc3=true) const;
+			const Vec2f* texturePos=NULL, QVarLengthArray<Vec2f, 4096>* outTexturePos=NULL,
+			const Vec3f* colors=NULL, QVarLengthArray<Vec3f, 4096>* outColors=NULL,
+            double maxSqDistortion=5., int nbI=0,
+            bool checkDisc1=true, bool checkDisc2=true, bool checkDisc3=true) const;
 
-	void drawTextGravity180(float x, float y, const QString& str, const float xshift = 0, const float yshift = 0);
+	void drawTextGravity180(float x, float y, const QString& str, float xshift = 0, float yshift = 0);
 
 	// Used by the method below
 	static QVector<Vec2f> smallCircleVertexArray;
