@@ -23,6 +23,7 @@
 
 #include "StelUtils.hpp"
 #include "VecMath.hpp"
+#include <QBuffer>
 #include <QString>
 #include <QStringList>
 #include <QTextStream>
@@ -239,24 +240,24 @@ void radToDecDeg(double rad, bool &sign, double &deg)
 	deg = rad*180./M_PI;
 }
 
-QString radToDecDegStr(const double angle, const bool useD, const bool useC)
+QString radToDecDegStr(const double angle, const int precision, const bool useD, const bool useC)
 {
 	QChar degsign('d');
-	QString str;
+	QString str;	
 	if (!useD)
 	{
-		degsign = 0x00B0;
+		degsign = 0x00B0;		
 	}
 	bool sign;
 	double deg;
 	StelUtils::radToDecDeg(angle, sign, deg);
-	str = QString("%1%2%3").arg((sign?"+":"-"), QString::number(deg, 'f', 4), degsign);
+	str = QString("%1%2%3").arg((sign?"+":"-"), QString::number(deg, 'f', precision), degsign);
 	if (useC)
 	{
 		if (!sign)
 			deg = 360. - deg;
 
-		str = QString("+%1%2").arg(QString::number(deg, 'f', 4), degsign);
+		str = QString("+%1%2").arg(QString::number(deg, 'f', precision), degsign);
 	}
 
 	return str;
@@ -311,15 +312,15 @@ QString radToHmsStr(const double angle, const bool decimal)
 	QString carry;
 	if (decimal)
 	{
-		width=4;
-		precision=1;
-		carry="60.0";
+		width=5;
+		precision=2;
+		carry="60.00";
 	}
 	else
 	{
-		width=2;
-		precision=0;
-		carry="60";
+		width=4;
+		precision=1;
+		carry="60.0";
 	}
 
 	// handle carry case (when seconds are rounded up)
@@ -474,6 +475,36 @@ Vec3f strToVec3f(const QString& s)
 	return strToVec3f(s.split(","));
 }
 
+Vec4d strToVec4d(const QStringList &s)
+{
+	if(s.size()<4)
+		return Vec4d(0.0,0.0,0.0,0.0);
+
+	return Vec4d(s[0].toDouble(), s[1].toDouble(), s[2].toDouble(), s[3].toDouble());
+}
+
+Vec4d strToVec4d(const QString& str)
+{
+	return strToVec4d(str.split(","));
+}
+
+QString vec3fToStr(const Vec3f &v)
+{
+	return QString("%1,%2,%3")
+		.arg(v[0],0,'f',6)
+		.arg(v[1],0,'f',6)
+		.arg(v[2],0,'f',6);
+}
+
+QString vec4dToStr(const Vec4d &v)
+{
+	return QString("%1,%2,%3,%4")
+		.arg(v[0],0,'f',10)
+		.arg(v[1],0,'f',10)
+		.arg(v[2],0,'f',10)
+		.arg(v[3],0,'f',10);
+}
+
 // Converts a Vec3f to HTML color notation.
 QString vec3fToHtmlColor(const Vec3f& v)
 {
@@ -546,18 +577,17 @@ void rectToSphe(double *lng, double *lat, const Vec3f& v)
 	*lng = atan2(v[1],v[0]);
 }
 
-// GZ: some additions. I need those just for quick conversions for text display.
-void ctRadec2Ecl(const double raRad, const double decRad, const double eclRad, double *lambdaRad, double *betaRad)
+void equToEcl(const double raRad, const double decRad, const double eclRad, double *lambdaRad, double *betaRad)
 {
 	*lambdaRad=std::atan2(std::sin(raRad)*std::cos(eclRad)+std::tan(decRad)*std::sin(eclRad), std::cos(raRad));
 	*betaRad=std::asin(std::sin(decRad)*std::cos(eclRad)-std::cos(decRad)*std::sin(eclRad)*std::sin(raRad));
 }
-// GZ: done
 
 double getDecAngle(const QString& str)
 {
 	QRegExp re1("^\\s*([\\+\\-])?\\s*(\\d+)\\s*([hHDd\xBA])\\s*(\\d+)\\s*['Mm]\\s*(\\d+(\\.\\d+)?)\\s*[\"Ss]\\s*([NSEWnsew])?\\s*$"); // DMS/HMS
 	QRegExp re2("^\\s*([\\+\\-])?\\s*(\\d+(\\.\\d+)?).?([NSEWnsew])?\\s*$"); // Decimal
+	QRegExp re3("([+-]?[\\d.]+)°(?:([\\d.]+)')?(?:([\\d.]+)\")?"); // DMS like +121°33'38.28"
 
 	if (re1.exactMatch(str))
 	{
@@ -586,6 +616,16 @@ double getDecAngle(const QString& str)
 			deg *= -1.;
 		return (deg * 2 * M_PI / 360.);
 	}
+	else if (re3.exactMatch(str))
+	{
+		float deg = re3.capturedTexts()[1].toFloat();
+		float min = re3.capturedTexts()[2].isEmpty()? 0 : re3.capturedTexts()[2].toFloat();
+		float sec = re3.capturedTexts()[3].isEmpty()? 0 : re3.capturedTexts()[3].toFloat();
+		float r = qAbs(deg) + min / 60 + sec / 3600;
+		if (deg<0)
+			r *= -1.;
+		return (r * 2 * M_PI / 360.);
+	}
 
 	qDebug() << "getDecAngle failed to parse angle string:" << str;
 	return -0.0;
@@ -730,7 +770,7 @@ QString julianDayToISO8601String(const double jd)
 }
 
 // Format the date per the fmt.
-QString localeDateString(const int year, const int month, const int day, const int dayOfWeek, const QString fmt)
+QString localeDateString(const int year, const int month, const int day, const int dayOfWeek, const QString &fmt)
 {
 	/* we have to handle the year zero, and the years before qdatetime can represent. */
 	const QLatin1Char quote('\'');
@@ -1238,8 +1278,8 @@ double calculateSiderealPeriod(const double SemiMajorAxis)
 QString hoursToHmsStr(const double hours)
 {
 	int h = (int)hours;
-	int m = (int)((std::abs(hours)-std::abs(double(h)))*60);
-	float s = (((std::abs(hours)-std::abs(double(h)))*60)-m)*60;
+	int m = (int)((qAbs(hours)-qAbs(double(h)))*60);
+	float s = (((qAbs(hours)-qAbs(double(h)))*60)-m)*60;
 
 	return QString("%1h%2m%3s").arg(h).arg(m).arg(QString::number(s, 'f', 1));
 }
@@ -1265,10 +1305,8 @@ double getDeltaTByEspenakMeeus(const double jDay)
 	// "Five Millennium Canon of Solar Eclipses" [Espenak and Meeus, 2006]
 	// A summary is described here:
 	// http://eclipse.gsfc.nasa.gov/SEhelp/deltatpoly2004.html
-	// GZ: I replaced the std::pow() calls by Horner's scheme with reversed factors, it's more accurate and efficient.
-	//     Old code left for readability, but can also be deleted.
 
-	double y = year+((month-1)*30.5+day/31*30.5)/366;
+	double y = year+((month-1)*30.5+day/31.*30.5)/366;
 
 	// set the default value for Delta T
 	double u = (y-1820)/100.;
@@ -1342,7 +1380,7 @@ double getDeltaTByEspenakMeeus(const double jDay)
 	{
 		double t = y - 1975;
 		//r = (45.45 + 1.067*t - std::pow(t,2)/260 - std::pow(t,3) / 718);
-		r = ((-t/718.0 +1/260.0)*t + 1.067)*t +45.45;
+		r = ((-t/718.0 -1/260.0)*t + 1.067)*t +45.45;
 	}
 	else if (y < 2005)
 	{
@@ -1370,14 +1408,14 @@ double getDeltaTByEspenakMeeus(const double jDay)
 double getDeltaTBySchoch(const double jDay)
 {
 	double u=(jDay-2378496.0)/36525.0; // (1800-jan-0.5)
-	return -36.28 + 36.28*std::pow(u,2);
+	return -36.28 + 36.28*u*u;
 }
 
 // Implementation of algorithm by Clemence (1948) for DeltaT computation
 double getDeltaTByClemence(const double jDay)
 {
 	double u=(jDay-2415020.0)/36525.0; // (1900-jan-0.5)
-	return +8.72 + 26.75*u + 11.22*std::pow(u,2);
+	return +8.72 + 26.75*u + 11.22*u*u;
 }
 
 // Implementation of algorithm by IAU (1952) for DeltaT computation
@@ -1438,7 +1476,7 @@ double getDeltaTBySchmadelZech1979(const double jDay)
 double getDeltaTByMorrisonStephenson1982(const double jDay)
 {
 	double u=(jDay-2382148.0)/36525.0; // (1810-jan-0.5)
-	return -15.0+32.50*std::pow(u,2);
+	return -15.0+32.50*u*u;
 }
 
 // Implementation of algorithm by Stephenson & Morrison (1984) for DeltaT computation
@@ -1448,8 +1486,7 @@ double getDeltaTByStephensonMorrison1984(const double jDay)
 	double deltaT = 0.;
 	getDateFromJulianDay(jDay, &year, &month, &day);
 
-	double yeardec=year+((month-1)*30.5+day/31*30.5)/366;
-	double u = (yeardec-1800)/100;
+	double u = (getDecYear(year, month, day)-1800)/100;
 
 	if (-391 < year && year <= 948)
 		deltaT = (44.3*u +320.0)*u +1360.0;
@@ -1474,7 +1511,7 @@ double getDeltaTByStephensonHoulden(const double jDay)
 	double deltaT = 0.;
 	getDateFromJulianDay(jDay, &year, &month, &day);
 
-	double yeardec=year+((month-1)*30.5+day/31*30.5)/366;
+	double yeardec=getDecYear(year, month, day);
 
 	if (year <= 948)
 	{
@@ -1532,7 +1569,7 @@ double getDeltaTByChaprontTouze(const double jDay)
 
 // Implementation of algorithm by JPL Horizons for DeltaT computation
 double getDeltaTByJPLHorizons(const double jDay)
-{ // GZ: TODO: FIXME! It does not make sense to have zeros after 1620 in a JPL Horizons compatible implementation!
+{ // FIXME: It does not make sense to have zeros after 1620 in a JPL Horizons compatible implementation!
 	int year, month, day;
 	double u;
 	double deltaT = 0.;
@@ -1564,7 +1601,7 @@ double getDeltaTByReijs(const double jDay)
 {
 	double OffSetYear = (2385800.0 - jDay)/365.25;
 
-	return ((1.8 * std::pow(OffSetYear,2)/200 + 1443*3.76/(2*M_PI)*(std::cos(2*M_PI*OffSetYear/1443)-1))*365.25)/1000;
+	return ((1.8 * OffSetYear*OffSetYear/200 + 1443*3.76/(2*M_PI)*(std::cos(2*M_PI*OffSetYear/1443)-1))*365.25)/1000;
 }
 
 // Implementation of algorithm by Chapront, Chapront-Touze & Francou (1997) & Meeus (1998) for DeltaT computation
@@ -1598,7 +1635,7 @@ double getDeltaTByChaprontMeeus(const double jDay)
 	//        deltaT= (((((((( 58353.42*u19 -232424.66)*u19 +372919.88)*u19 - 303191.19)*u19 + 124906.15)*u19 - 18756.33)*u19 - 2637.80)*u19 + 815.20)*u19 + 87.24)*u19 - 2.44;
 	else if (year <2000)
 	{
-		double yeardec=year+((month-1)*30.5+day/31*30.5)/366;
+		double yeardec=getDecYear(year, month, day);
 		int pos=(year-1620)/2; // this is a deliberate integer division! 2->1, 3->1, 4->2, 5->2 etc.
 		deltaT= MeeusDeltaTTable[pos]+ (yeardec-(2*pos+1620))*0.5  *(MeeusDeltaTTable[pos+1]-MeeusDeltaTTable[pos]);
 		deltaT /= 10.0;
@@ -1716,16 +1753,16 @@ double getDeltaTByMeeusSimons(const double jDay)
 }
 
 // Implementation of algorithm by Reingold & Dershowitz (Cal. Calc. 1997, 2001, 2007, Cal. Tab. 2002) for DeltaT computation.
-// GZ: Created as yet another multi-segment polynomial fit through the table in Meeus: Astronomical Algorithms (1991).
-// GZ: Note that only the Third edition (2007) adds the 1700-1799 term.
-// GZ: More efficient reimplementation with stricter adherence to the source.
+// Created as yet another multi-segment polynomial fit through the table in Meeus: Astronomical Algorithms (1991).
+// Note that only the Third edition (2007) adds the 1700-1799 term.
+// More efficient reimplementation with stricter adherence to the source.
 double getDeltaTByReingoldDershowitz(const double jDay)
 {
 	int year, month, day;	
 	getDateFromJulianDay(jDay, &year, &month, &day);
-	// GZ: R&D don't use a float-fraction year, but explicitly only the integer year! And R&D use a proleptic Gregorian year before 1582.
-	// GZ: We cannot do that, but the difference is negligible.
-	// GZ: FIXME: why are displayed values so far off the computed values? It seems currently broken!
+	// R&D don't use a float-fraction year, but explicitly only the integer year! And R&D use a proleptic Gregorian year before 1582.
+	// We cannot do that, but the difference is negligible.
+	// FIXME: why are displayed values so far off the computed values? It seems currently broken!
 	double deltaT=0.0; // If it returns 0, there is a bug!
 
 	if ((year >= 2019) || (year < 1620))
@@ -1837,16 +1874,67 @@ double getDeltaTByIslamSadiqQureshi(const double jDay)
 	return deltaT;
 }
 
+// Implementation of polinomial approximation of time period 1620-2013 for DeltaT by M. Khalid, Mariam Sultana and Faheem Zaidi (2014).
+double getDeltaTByKhalidSultanaZaidi(const double jDay)
+{
+	int year, month, day;
+	getDateFromJulianDay(jDay, &year, &month, &day);
+	double k, a0, a1, a2, a3, a4;
+	if (year>=1620 && year<=1672)
+	{
+		k = 3.670; a0 = 76.541; a1 = -253.532; a2 = 695.901; a3 = -1256.982; a4 = 627.152;
+	}
+	else if (year>=1673 && year<=1729)
+	{
+		k = 3.120; a0 = 10.872; a1 = -40.744; a2 = 236.890; a3 = -351.537; a4 = 36.612;
+	}
+	else if (year>=1730 && year<=1797)
+	{
+		k = 2.495; a0 = 13.480; a1 = 13.075; a2 = 8.635; a3 = -3.307; a4 = -128.294;
+	}
+	else if (year>=1798 && year<=1843)
+	{
+		k = 1.925; a0 = 12.584; a1 = 1.929; a2 = 60.896; a3 = -1432.216; a4 = 3129.071;
+	}
+	else if (year>=1844 && year<=1877)
+	{
+		k = 1.525; a0 = 6.364; a1 = 11.004; a2 = 407.776; a3 = -4168.394; a4 = 7561.686;
+	}
+	else if (year>=1878 && year<=1904)
+	{
+		k = 1.220; a0 = -5.058; a1 = -1.701; a2 = -46.403; a3 = -866.171; a4 = 5917.585;
+	}
+	else if (year>=1905 && year<=1945)
+	{
+		k = 0.880; a0 = 13.392; a1 = 128.592; a2 = -279.165; a3 = -1282.050; a4 = 4039.490;
+	}
+	else if (year>=1946 && year<=1989)
+	{
+		k = 0.455; a0 = 30.782; a1 = 34.348; a2 = 46.452; a3 = 1295.550; a4 = -3210.913;
+	}
+	else if (year>=1990 && year<=2013)
+	{
+		k = 0.115; a0 = 55.281; a1 = 91.248; a2 = 87.202; a3 = -3092.565; a4 = 8255.422;
+	}
+	else
+	{
+		k = 0.0; a0 = 0.0; a1 = 0.0; a2 = 0.0; a3 = 0.0; a4 = 0.0;
+	}
+
+	double u = k + (year - 2000)/100;
+
+	return (((a4*u + a3)*u + a2)*u + a1)*u + a0;
+}
+
 double getMoonSecularAcceleration(const double jDay, const double nd)
 {
 	int year, month, day;
 	getDateFromJulianDay(jDay, &year, &month, &day);
 
-	double yeardec=year+((month-1)*30.5+day/31*30.5)/366.0;
-	double t = (yeardec-1955.5)/100.0;
+	double t = (getDecYear(year, month, day)-1955.5)/100.0;
 	// n.dot for secular acceleration of the Moon in ELP2000-82B
 	// have value -23.8946 "/cy/cy
-	return -0.91072 * (-23.8946 + std::abs(nd))*t*t;
+	return -0.91072 * (-23.8946 + qAbs(nd))*t*t;
 }
 
 double getDeltaTStandardError(const double jDay)
@@ -1854,7 +1942,6 @@ double getDeltaTStandardError(const double jDay)
 	int year, month, day;
 	getDateFromJulianDay(jDay, &year, &month, &day);
 
-	//double yeardec=year+((month-1)*30.5+day/31*30.5)/366;
 	double sigma = -1.;
 
 	if (-1000 <= year && year <= 1600)
@@ -1945,7 +2032,7 @@ float* ComputeCosSinRho(const int segments)
 //! Compute cosines and sines around part of a circle (from top to bottom) which is split in "segments" parts.
 //! Values are stored in the global static array cos_sin_rho.
 //! Used for the sin/cos values along a meridian.
-//! GZ: allow leaving away pole caps. The array now contains values for the region minAngle+segments*phi
+//! This allows leaving away pole caps. The array now contains values for the region minAngle+segments*phi
 //! @param dRho a difference angle between the stops
 //! @param segments number of segments
 //! @param minAngle start angle inside the half-circle. maxAngle=minAngle+segments*phi
@@ -1965,41 +2052,126 @@ float *ComputeCosSinRhoZone(const float dRho, const int segments, const float mi
 	return cos_sin_rho;
 }
 
+double getDecYear(const int year, const int month, const int day)
+{
+	return year+((month-1)*30.5+day/31.*30.5)/366;
+}
+
 //! Uncompress gzip or zlib compressed data.
 QByteArray uncompress(const QByteArray& data)
 {
 	if (data.size() <= 4)
 		return QByteArray();
-	static const int CHUNK = 1024;
-	QByteArray buffer(CHUNK, 0);
+
+	//needed for const-correctness, no deep copy performed
+	QByteArray dataNonConst(data);
+	QBuffer buf(&dataNonConst);
+	buf.open(QIODevice::ReadOnly);
+
+	return uncompress(buf);
+}
+
+//! Uncompress (gzip/zlib) data from this QIODevice, which must be open and readable.
+//! @param device The device to read from, must already be opened with an OpenMode supporting reading
+//! @param maxBytes The max. amount of bytes to read from the device, or -1 to read until EOF.  Note that it
+//! always stops when inflate() returns Z_STREAM_END. Positive values can be used for interleaving compressed data
+//! with other data.
+QByteArray uncompress(QIODevice& device, qint64 maxBytes)
+{
+	// this is a basic zlib decompression routine, similar to:
+	// http://zlib.net/zlib_how.html
+
+	// buffer size 256k, zlib recommended size
+	static const int CHUNK = 262144;
+	QByteArray readBuffer(CHUNK, 0);
+	QByteArray inflateBuffer(CHUNK, 0);
 	QByteArray out;
+
+	// zlib stream
 	z_stream strm;
 	strm.zalloc = Z_NULL;
 	strm.zfree = Z_NULL;
 	strm.opaque = Z_NULL;
-	strm.avail_in = data.size();
-	strm.next_in = (Bytef*)(data.data());
+	strm.avail_in = Z_NULL;
+	strm.next_in = Z_NULL;
 
+	// the amount of bytes already read from the device
+	qint64 bytesRead = 0;
+
+	// initialize zlib
 	// 15 + 32 for gzip automatic header detection.
 	int ret = inflateInit2(&strm, 15 +  32);
-	if (ret != Z_OK) return QByteArray();
+	if (ret != Z_OK)
+	{
+		qWarning()<<"zlib init error ("<<ret<<"), can't uncompress";
+		if(strm.msg)
+			qWarning()<<"zlib message: "<<QString(strm.msg);
+		return QByteArray();
+	}
 
+	//zlib double loop - one for reading from file, one for inflating
 	do
 	{
-		strm.avail_out = CHUNK;
-		strm.next_out = (Bytef*)(buffer.data());
-		ret = inflate(&strm, Z_NO_FLUSH);
-		Q_ASSERT(ret != Z_STREAM_ERROR);
-		if (ret < 0)
+		qint64 bytesToRead = CHUNK;
+		if(maxBytes>=0)
 		{
-			out.clear();
-			break;
+			//check if we reach the desired limit with the next read
+			bytesToRead = qMin((qint64)CHUNK,maxBytes-bytesRead);
 		}
-		out.append(buffer.data(), CHUNK - strm.avail_out);
-	}
-	while (strm.avail_out == 0);
 
-    inflateEnd(&strm);
+		if(bytesToRead==0)
+			break;
+
+		//perform read from device
+		qint64 read = device.read(readBuffer.data(), bytesToRead);
+		if (read<0)
+		{
+			qWarning()<<"Error while reading from device";
+			inflateEnd(&strm);
+			return QByteArray();
+		}
+
+		bytesRead += read;
+		strm.next_in = reinterpret_cast<Bytef*>(readBuffer.data());
+		strm.avail_in = read;
+
+		if(read==0)
+			break;
+
+		//inflate loop
+		do
+		{
+			strm.avail_out = CHUNK;
+			strm.next_out = reinterpret_cast<Bytef*>(inflateBuffer.data());
+			ret = inflate(&strm,Z_NO_FLUSH);
+			Q_ASSERT(ret != Z_STREAM_ERROR); // must never happen, indicates a programming error
+
+			if(ret < 0 || ret == Z_NEED_DICT)
+			{
+				qWarning()<<"zlib inflate error ("<<ret<<"), can't uncompress";
+				if(strm.msg)
+					qWarning()<<"zlib message: "<<QString(strm.msg);
+				inflateEnd(&strm);
+				return QByteArray();
+			}
+
+			out.append(inflateBuffer.constData(), CHUNK - strm.avail_out);
+
+		}while(strm.avail_out == 0); //if zlib has more data for us, repeat
+
+	}while(ret!=Z_STREAM_END);
+
+	// close zlib
+	inflateEnd(&strm);
+
+	if(ret!=Z_STREAM_END)
+	{
+		qWarning()<<"Premature end of compressed stream";
+		if(strm.msg)
+			qWarning()<<"zlib message: "<<QString(strm.msg);
+		return QByteArray();
+	}
+
 	return out;
 }
 
