@@ -20,8 +20,7 @@
 #ifndef _STELUTILS_HPP_
 #define _STELUTILS_HPP_
 
-#include "config.h"
-
+#include <cmath>
 #include "VecMath.hpp"
 
 #include <QVariantMap>
@@ -36,6 +35,8 @@
 // speed of light (km/sec)
 #define SPEED_OF_LIGHT 299792.458
 
+#define stelpow10f(x) std::exp((x) * 2.3025850930f)
+
 //! @namespace StelUtils contains general purpose utility functions.
 namespace StelUtils
 {
@@ -85,9 +86,10 @@ namespace StelUtils
 
 	//! Convert an angle in radian to a decimal degree string.
 	//! @param angle input angle in radian
+	//! @param precision
 	//! @param useD Define if letter "d" must be used instead of deg sign
 	//! @param useC Define if function should use 0-360 degrees
-	QString radToDecDegStr(const double angle, const bool useD=false, const bool useC=false);
+	QString radToDecDegStr(const double angle, const int precision = 4, const bool useD=false, const bool useC=false);
 
 	//! Convert an angle in radian to a hms formatted string.
 	//! If the second, minute part is == 0, it is not output
@@ -132,7 +134,17 @@ namespace StelUtils
 	//! @return The corresponding vector
 	//! @deprecated Use the >> operator from Vec3f class
 	Vec3f strToVec3f(const QStringList& s);
+	//! Reads a Vec3f from a string, separated by commas. Example: 1.0,2.0,3.0
 	Vec3f strToVec3f(const QString& s);
+	//! Like StelUtils::strToVec3f, but with 4 components and with double precision
+	Vec4d strToVec4d(const QStringList& s);
+	//! Like StelUtils::strToVec3f, but with 4 components and with double precision
+	Vec4d strToVec4d(const QString& s);
+
+	//! Converts a Vec3f to a string in the same format that can be read by strToVec3f
+	QString vec3fToStr(const Vec3f& v);
+	//! Converts a Vec4d to a string in the same format that can be read by strToVec4d
+	QString vec4dToStr(const Vec4d& v);
 
 	//! Converts a Vec3f to HTML color notation.
 	//! @param v The vector
@@ -152,7 +164,7 @@ namespace StelUtils
 	//! Convert from spherical coordinates to Rectangular direction.
 	//! @param lng longitude in radian
 	//! @param lat latitude in radian
-	//! @param v the resulting 3D unti vector
+	//! @param v the resulting 3D unit vector
 	void spheToRect(const float lng, const float lat, Vec3f& v);
 
 	//! Convert from spherical coordinates to Rectangular direction.
@@ -173,10 +185,8 @@ namespace StelUtils
 	//! @param v the input 3D vector
 	void rectToSphe(float *lng, float *lat, const Vec3f& v);
 
-	// GZ: some additions. I need those just for quick conversions for text display.
 	//! Coordinate Transformation from equatorial to ecliptical
-	void ctRadec2Ecl(const double raRad, const double decRad, const double eclRad, double *lambdaRad, double *betaRad);
-	// GZ: done
+	void equToEcl(const double raRad, const double decRad, const double eclRad, double *lambdaRad, double *betaRad);
 
 	//! Convert a string longitude, latitude, RA or Declination angle
 	//! to radians.
@@ -233,7 +243,7 @@ namespace StelUtils
 	//! (see QDateTime::toString()). Uses the @b system locale, not
 	//! the one set in Stellarium.
 	//! @return QString representing the formatted date
-	QString localeDateString(const int year, const int month, const int day, const int dayOfWeek, const QString fmt);
+	QString localeDateString(const int year, const int month, const int day, const int dayOfWeek, const QString &fmt);
 
 	//! Format the date and day-of-week per the @b system locale's
 	//! QLocale::ShortFormat.
@@ -575,6 +585,15 @@ namespace StelUtils
 	//! @return Delta-T in seconds
 	double getDeltaTByIslamSadiqQureshi(const double jDay);
 
+	//! Get Delta-T estimation for a given date.
+	//! Implementation of polinomial approximation of time period 1620-2013 for DeltaT by M. Khalid, Mariam Sultana and Faheem Zaidi (2014).
+	//! Source: Delta T: Polynomial Approximation of Time Period 1620-2013
+	//! Journal of Astrophysics, Vol. 2014, Article ID 480964
+	//! http://dx.doi.org/10.1155/2014/480964
+	//! @param jDay the date and time expressed as a julian day
+	//! @return Delta-T in seconds
+	double getDeltaTByKhalidSultanaZaidi(const double jDay);
+
 	//! Get Secular Acceleration estimation for a given year.
 	//! Method described is here: http://eclipse.gsfc.nasa.gov/SEcat5/secular.html
 	//! For adapting from -26 to -25.858, use -0.91072 * (-25.858 + 26.0) = -0.12932224
@@ -591,7 +610,8 @@ namespace StelUtils
 	double getDeltaTStandardError(const double jDay);
 
 	//! Sign function from http://stackoverflow.com/questions/1903954/is-there-a-standard-sign-function-signum-sgn-in-c-c
-	template <typename T> int sign(T val) {
+	template <typename T> int sign(T val)
+	{
 		return (T(0) < val) - (val < T(0));
 	}
 	
@@ -610,14 +630,37 @@ namespace StelUtils
 	//! Compute cosines and sines around part of a circle (from top to bottom) which is split in "segments" parts.
 	//! Values are stored in the global static array cos_sin_rho.
 	//! Used for the sin/cos values along a meridian.
-	//! GZ: allow leaving away pole caps. The array now contains values for the region minAngle+segments*phi
+	//! This allows leaving away pole caps. The array now contains values for the region minAngle+segments*phi
 	//! @param dRho a difference angle between the stops
 	//! @param segments number of segments
 	//! @param minAngle start angle inside the half-circle. maxAngle=minAngle+segments*phi
 	float* ComputeCosSinRhoZone(const float dRho, const int segments, const float minAngle);
 
+	//! Compute date in decimal year format
+	//! @param year
+	//! @param month
+	//! @param day
+	//! @return decimal year
+	double getDecYear(const int year, const int month, const int day);
+
 	//! Uncompress gzip or zlib compressed data.
 	QByteArray uncompress(const QByteArray& data);
+
+	//! Uncompress (gzip/zlib) data from this QIODevice, which must be open and readable.
+	//! @param device The device to read from, must already be opened with an OpenMode supporting reading
+	//! @param maxBytes The max. amount of bytes to read from the device, or -1 to read until EOF.  Note that it
+	//! always stops when inflate() returns Z_STREAM_END. Positive values can be used for interleaving compressed data
+	//! with other data.
+	QByteArray uncompress(QIODevice &device, qint64 maxBytes=-1);
+
+#ifdef _MSC_BUILD
+	inline double trunc(double x)
+	{
+		return (x < 0 ? std::ceil(x) : std::floor(x));
+	}
+#else
+	inline double trunc(double x) { return ::trunc(x); }
+#endif
 }
 
 #endif // _STELUTILS_HPP_
