@@ -1,6 +1,7 @@
 /*
  * Stellarium
  * Copyright (C) 2010 Bogdan Marinov
+ * Copyright (C) 2014 Georg Zotti (Tails)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,6 +27,7 @@
 
 #include "StelTexture.hpp"
 #include "StelTextureMgr.hpp"
+#include "StelToneReproducer.hpp"
 #include "StelTranslator.hpp"
 #include "StelUtils.hpp"
 #include "StelFileMgr.hpp"
@@ -40,20 +42,30 @@
 #define COMET_TAIL_SLICES 16 // segments around the perimeter
 #define COMET_TAIL_STACKS 16 // cuts along the rotational axis
 
+// These are to avoid having index arrays for each comet when all are equal.
+bool Comet::createTailIndices=true;
+bool Comet::createTailTextureCoords=true;
+StelTextureSP Comet::comaTexture;
+StelTextureSP Comet::tailTexture;
+QVector<float> Comet::tailTexCoordArr; // computed only once for all Comets.
+QVector<unsigned short> Comet::tailIndices; // computed only once for all Comets.
+
 Comet::Comet(const QString& englishName,
-		 int flagLighting,
-		 double radius,
-		 double oblateness,
-		 Vec3f color,
-		 float albedo,
-		 const QString& atexMapName,
-		 posFuncType coordFunc,
-		 void* auserDataPtr,
-		 OsculatingFunctType *osculatingFunc,
-		 bool acloseOrbit,
-		 bool hidden,
-		 const QString& pTypeStr,
-		 float dustTailWidthFact, float dustTailLengthFact, float dustTailBrightnessFact)
+	     int flagLighting,
+	     double radius,
+	     double oblateness,
+	     Vec3f color,
+	     float albedo,
+	     const QString& atexMapName,
+	     posFuncType coordFunc,
+	     void* auserDataPtr,
+	     OsculatingFunctType *osculatingFunc,
+	     bool acloseOrbit,
+	     bool hidden,
+	     const QString& pTypeStr,
+	     float dustTailWidthFact,
+	     float dustTailLengthFact,
+	     float dustTailBrightnessFact)
 	: Planet (englishName,
 		  flagLighting,
 		  radius,
@@ -71,6 +83,7 @@ Comet::Comet(const QString& englishName,
 		  true, //halo
 		  pTypeStr),
 	  tailActive(false),
+	  tailBright(false),
 	  dustTailWidthFactor(dustTailWidthFact),
 	  dustTailLengthFactor(dustTailLengthFact),
 	  dustTailBrightnessFactor(dustTailBrightnessFact)
@@ -87,9 +100,12 @@ Comet::Comet(const QString& englishName,
 	rotLocalToParent = Mat4d::identity();
 	texMap = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/"+texMapName, StelTexture::StelTextureParams(true, GL_LINEAR, GL_REPEAT));
 
+	tailFactors[0]=-1.0f; tailFactors[1]=-1.0f; // mark "invalid"
 	gastailVertexArr.clear();
 	dusttailVertexArr.clear();
 	comaVertexArr.clear();
+	gastailColorArr.clear();
+	dusttailColorArr.clear();
 
 	//Comet specific members
 	absoluteMagnitude = 0;
@@ -124,6 +140,11 @@ void Comet::setAbsoluteMagnitudeAndSlope(const double magnitude, const double sl
 	slopeParameter = slope;
 }
 
+void Comet::translateName(const StelTranslator &translator)
+{
+	nameI18 = translator.qtranslate(englishName);
+}
+
 QString Comet::getInfoString(const StelCore *core, const InfoStringGroup &flags) const
 {
 	//Mostly copied from Planet::getInfoString():
@@ -133,7 +154,7 @@ QString Comet::getInfoString(const StelCore *core, const InfoStringGroup &flags)
 	if (flags&Name)
 	{
 		oss << "<h2>";
-		oss << q_(englishName);  // UI translation can differ from sky translation
+		oss << getNameI18n();  // UI translation can differ from sky translation
 		oss.setRealNumberNotation(QTextStream::FixedNotation);
 		oss.setRealNumberPrecision(1);
 		if (sphereScale != 1.f)
@@ -141,9 +162,15 @@ QString Comet::getInfoString(const StelCore *core, const InfoStringGroup &flags)
 		oss << "</h2>";
 	}
 
-	if (flags&ObjectType)
+	if (flags&ObjectType && getPlanetType()!=isUNDEFINED)
 	{
-		oss << q_("Type: <b>%1</b>").arg(q_(getPlanetTypeString())) << "<br />";
+		QString cometType = qc_("non-periodic", "type of comet");
+		if (semiMajorAxis>0.0)
+		{
+			// Parabolic and hyperbolic comets doesn't have semi-major axis of the orbit. We have comet with elliptic orbit.
+			cometType = qc_("periodic", "type of comet");
+		}
+		oss << q_("Type: <b>%1</b> (%2)").arg(q_(getPlanetTypeString())).arg(cometType) << "<br />";
 	}
 
 	if (flags&Magnitude)
@@ -206,14 +233,24 @@ QString Comet::getInfoString(const StelCore *core, const InfoStringGroup &flags)
 	}
 	if (flags&Extra)
 	{
+		// If semi-major axis not zero then calculate and display orbital period for comet in days
+		double siderealPeriod = getSiderealPeriod();
+		if (siderealPeriod>0)
+		{
+			// TRANSLATORS: Sidereal (orbital) period for comets in Julian years (symbol: a)
+			oss << q_("Sidereal period: %1 a").arg(QString::number(siderealPeriod/365.25, 'f', 3)) << "<br>";
+		}
+
 		// GZ: Add speed. I don't know where else to place that bit of information.
 		// xgettext:no-c-format
 		oss << QString(q_("Speed: %1 km/s"))
 			   .arg(((CometOrbit*)userDataPtr)->getVelocity().length()*AU/86400.0, 0, 'f', 3);
 		oss << "<br>";
+
 	}
 
-	if (flags&Size)
+
+	if ((flags&Size) && (tailFactors[0]>0.0f))
 	{
 		// GZ: Add estimates for coma diameter and tail length.
 		// xgettext:no-c-format
@@ -226,14 +263,6 @@ QString Comet::getInfoString(const StelCore *core, const InfoStringGroup &flags)
 		oss << "<br>";
 	}
 
-	// If semi-major axis not zero then calculate and display orbital period for comet in days
-	double siderealPeriod = getSiderealPeriod();
-	if ((flags&Extra) && (siderealPeriod>0))
-	{
-		// TRANSLATORS: Sidereal (orbital) period for solar system bodies in days and in Julian years (symbol: a)
-		oss << q_("Sidereal period: %1 days (%2 a)").arg(QString::number(siderealPeriod, 'f', 2)).arg(QString::number(siderealPeriod/365.25, 'f', 3)) << "<br>";
-	}
-
 	postProcessInfoString(str, flags);
 
 	return str;
@@ -281,19 +310,27 @@ float Comet::getVMagnitude(const StelCore* core) const
 	return apparentMagnitude;
 }
 
-// Compute the position in the parent Planet coordinate system
-// Actually call the provided function to compute the ecliptical position, and buildup the tails!
-void Comet::computePosition(const double date)
+void Comet::update(int deltaTime)
 {
-	Planet::computePosition(date);
-	//GZ: I think we can make deltaJD adaptive, depending on distance to sun! For some reason though, this leads to a crash!
-	//deltaJD=StelCore::JD_SECOND * qMax(1.0, qMin(eclipticPos.length(), 20.0));
+	Planet::update(deltaTime);
+
+	// The rest used to be in computePosition(), but is better in update(). Unfortunately we need date (JD).
+	StelCore* core=StelApp::getInstance().getCore();
+	double date=core->getJDay();
+
+	// The CometOrbit is in fact available in userDataPtr!
+	CometOrbit* orbit=(CometOrbit*)userDataPtr;
+	Q_ASSERT(orbit);
+	if (!orbit->objectDateValid(core->getJDay())) return; // don't do anything if out of useful date range. This allows having hundreds of comet elements.
+
+
+	//GZ: I think we can make deltaJDtail adaptive, depending on distance to sun! For some reason though, this leads to a crash!
+	//deltaJDtail=StelCore::JD_SECOND * qMax(1.0, qMin(eclipticPos.length(), 20.0));
 
 	if (fabs(lastJDtail-date)>deltaJDtail)
 	{
 		lastJDtail=date;
 
-		// GZ: Moved from draw() :-)
 		// The CometOrbit is in fact available in userDataPtr!
 		CometOrbit* orbit=(CometOrbit*)userDataPtr;
 		Q_ASSERT(orbit);
@@ -301,11 +338,10 @@ void Comet::computePosition(const double date)
 
 		if (orbit->getUpdateTails()){
 			// Compute lengths and orientations from orbit object, but only if required.
-			// This part moved from draw() to keep draw() free from too much computation.
 			tailFactors=getComaDiameterAndTailLengthAU();
 
 			// Note that we use a diameter larger than what the formula returns. A scale factor of 1.2 is ad-hoc/empirical (GZ), but may look better.
-			computeComa(1.0f*tailFactors[0]);
+			computeComa(1.0f*tailFactors[0]); // TBD: APPARENTLY NO SCALING? REMOVE 1.0 and note above.
 
 			tailActive = (tailFactors[1] > tailFactors[0]); // Inhibit tails drawing if too short. Would be nice to include geometric projection angle, but this is too costly.
 
@@ -318,10 +354,10 @@ void Comet::computePosition(const double date)
 
 				// Find valid parameters to create paraboloid vertex arrays: dustTail, gasTail.
 				computeParabola(gasparameter, gasTailEndRadius, -0.5f*gasparameter, gastailVertexArr,  tailTexCoordArr, tailIndices);
-				// This was for a rotated straight parabola:
-				//computeParabola(dustparameter, 2.0f*tailFactors[0], -0.5f*dustparameter, dusttailVertexArr, dusttailTexCoordArr, dusttailIndices);
+				//gastailColorArr.fill(Vec3f(0.3,0.3,0.3), gastailVertexArr.length());
 				// Now we make a skewed parabola. Skew factor (xOffset, last arg) is rather ad-hoc/empirical. TBD later: Find physically correct solution.
 				computeParabola(dustparameter, dustTailWidthFactor*gasTailEndRadius, -0.5f*dustparameter, dusttailVertexArr, tailTexCoordArr, tailIndices, 25.0f*orbit->getVelocity().length());
+				//dusttailColorArr.fill(Vec3f(0.3,0.3,0.3), dusttailVertexArr.length());
 
 
 				// 2014-08 for 0.13.1 Moved from drawTail() to save lots of computation per frame (There *are* folks downloading all 730 MPC current comet elements...)
@@ -336,7 +372,7 @@ void Comet::computePosition(const double date)
 				// In addition, we let the dust tail already start with a light tilt.
 				dustTailRot=gasTailRot * Mat4d::zrotation(atan2(velocity[1], velocity[0]) + M_PI) * Mat4d::yrotation(5.0f*velocity.length());
 
-				// TODO: If we want to be even faster, rotate vertex arrays here and not in drawTail()!
+				// Rotate vertex arrays:
 				Vec3d* gasVertices=(Vec3d*) (gastailVertexArr.data());
 				Vec3d* dustVertices=(Vec3d*) (dusttailVertexArr.data());
 				for (int i=0; i<COMET_TAIL_SLICES*COMET_TAIL_STACKS+1; ++i)
@@ -345,34 +381,109 @@ void Comet::computePosition(const double date)
 					dustVertices[i].transfo4d(dustTailRot);
 				}
 			}
-
 			orbit->setUpdateTails(false); // don't update until position has been recalculated elsewhere
 		}
-		// Note: we can make deltaJDtail adaptive, depending on distance to sun!
-		//deltaJDtail=5.0*StelCore::JD_MINUTE * qMax(0.01, qMin(eclipticPos.length(), 20.0));
 	}
+
+	// And also update magnitude and tail brightness/extinction here.
+	const bool withAtmosphere=(core->getSkyDrawer()->getFlagHasAtmosphere());
+
+	StelToneReproducer* eye = core->getToneReproducer();
+	float lum = core->getSkyDrawer()->surfacebrightnessToLuminance(getVMagnitude(core)+13.0f); // How to calibrate?
+	// Get the luminance scaled between 0 and 1
+	float aLum =eye->adaptLuminanceScaled(lum);
+
+
+	// To make comet more apparent in overviews, take field of view into account:
+	const float fov=core->getProjection(core->getAltAzModelViewTransform())->getFov();
+	if (fov>20)
+		aLum*= (fov/20.0f);
+
+	// Now inhibit tail drawing if still too dim.
+	if (aLum<0.002f)
+	{
+		// Far too dim: don't even show tail...
+		tailBright=false;
+		return;
+	} else
+		tailBright=true;
+
+	// Separate factors, but avoid overly bright tails. I limit to about 0.7 for overlapping both tails which should not exceed full-white.
+	float gasMagFactor=qMin(0.9f*aLum, 0.7f);
+	float dustMagFactor=qMin(dustTailBrightnessFactor*aLum, 0.7f);
+
+	Vec3f gasColor(0.15f*gasMagFactor,0.35f*gasMagFactor,0.6f*gasMagFactor); // Orig color 0.15/0.15/0.6
+	Vec3f dustColor(dustMagFactor, dustMagFactor,0.6f*dustMagFactor);
+
+	if (withAtmosphere)
+	{
+		Extinction extinction=core->getSkyDrawer()->getExtinction();
+
+		// Not only correct the color values for extinction, but for twilight conditions, also make tail end less visible.
+		// I consider sky brightness over 1cd/m^2 as reason to shorten tail.
+		// Below this brightness, the tail brightness loss by this method is insignificant:
+		// Just counting through the vertices might make a spiral apperance. Maybe even better than stackwise? Let's see...
+		const float avgAtmLum=GETSTELMODULE(LandscapeMgr)->getAtmosphereAverageLuminance();
+		const float brightnessDecreasePerVertexFromHead=1.0f/(COMET_TAIL_SLICES*COMET_TAIL_STACKS)  * avgAtmLum;
+		float brightnessPerVertexFromHead=1.0f;
+
+		gastailColorArr.clear();
+		dusttailColorArr.clear();
+		for (int i=0; i<gastailVertexArr.size(); ++i)
+		{
+			// Gastail extinction:
+			Vec3d vertAltAz=core->j2000ToAltAz(gastailVertexArr.at(i), StelCore::RefractionOn);
+			vertAltAz.normalize();
+			Q_ASSERT(fabs(vertAltAz.lengthSquared()-1.0) < 0.001);
+			float oneMag=0.0f;
+			extinction.forward(vertAltAz, &oneMag);
+			float extinctionFactor=std::pow(0.4f, oneMag); // drop of one magnitude: factor 2.5 or 40%
+			gastailColorArr.append(gasColor*extinctionFactor* brightnessPerVertexFromHead);
+
+			// dusttail extinction:
+			vertAltAz=core->j2000ToAltAz(dusttailVertexArr.at(i), StelCore::RefractionOn);
+			vertAltAz.normalize();
+			Q_ASSERT(fabs(vertAltAz.lengthSquared()-1.0) < 0.001);
+			oneMag=0.0f;
+			extinction.forward(vertAltAz, &oneMag);
+			extinctionFactor=std::pow(0.4f, oneMag); // drop of one magnitude: factor 2.5 or 40%
+			dusttailColorArr.append(dustColor*extinctionFactor * brightnessPerVertexFromHead);
+
+			brightnessPerVertexFromHead-=brightnessDecreasePerVertexFromHead;
+		}
+	}
+	else // no atmosphere: set all vertices to same brightness.
+	{
+		gastailColorArr.fill(gasColor,   gastailVertexArr.length());
+		dusttailColorArr.fill(dustColor, dusttailVertexArr.length());
+	}
+	//qDebug() << "Comet " << getEnglishName() <<  "JD: " << date << "gasR" << gasColor[0] << " dustR" << dustColor[0];
 }
 
 
-// Draw the Comet and all the related infos : name, circle etc... GZ: Taken from Planet.cpp 2013-11-05 and extended
+// Draw the Comet and all the related infos: name, circle etc... GZ: Taken from Planet.cpp 2013-11-05 and extended
 void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont)
 {
 	if (hidden)
 		return;
+
 	if (getEnglishName() == core->getCurrentLocation().planetName)
-	{ // GZ: Maybe even don't do that? E.g., draw tail while riding the comet? Decide later.
+	{ // Maybe even don't do that? E.g., draw tail while riding the comet? Decide later.
 		return;
 	}
 
-	// GZ: If comet is too faint to be seen, don't bother rendering. (oops, should have been here in 2014-01... ;-)
-	if ((getVMagnitude(core)-2.0f) > core->getSkyDrawer()->getLimitMagnitude())
+	// This test seemed necessary for reasonable fps in case too many comet elements are loaded.
+	// Problematic: Early-out here of course disables the wanted hint circles for dim comets.
+	// The line makes hints for comets 5 magnitudes below sky limiting magnitude visible.
+	// If comet is too faint to be seen, don't bother rendering. (Massive speedup if people have hundreds of comet elements!)
+	if ((getVMagnitude(core)-5.0f) > core->getSkyDrawer()->getLimitMagnitude())
 	{
 		return;
 	}
 	// The CometOrbit is in fact available in userDataPtr!
 	CometOrbit* orbit=(CometOrbit*)userDataPtr;
 	Q_ASSERT(orbit);
-	if (!orbit->objectDateValid(core->getJDay())) return; // don't draw at all out of useful date range. This allows having hundreds of comet elements.
+	if (!orbit->objectDateValid(core->getJDay())) return; // don't draw at all if out of useful date range. This allows having hundreds of comet elements.
 
 	Mat4d mat = Mat4d::translation(eclipticPos) * rotLocalToParent;
 	// This removed totally the Planet shaking bug!!!
@@ -408,8 +519,16 @@ void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont
 
 		draw3dModel(core,transfo,screenSz);
 	}
-	// tails should also be drawn if comet core is off-screen...
-	if (tailActive)
+
+	// If comet is too faint to be seen, don't bother rendering. (Massive speedup if people have hundreds of comets!)
+	// This test moved here so that hints are still drawn.
+	if ((getVMagnitude(core)-3.0f) > core->getSkyDrawer()->getLimitMagnitude())
+	{
+		return;
+	}
+
+	// but tails should also be drawn if comet core is off-screen...
+	if (tailActive && tailBright)
 	{
 		drawTail(core,transfo,true);  // gas tail
 		drawTail(core,transfo,false); // dust tail
@@ -420,48 +539,25 @@ void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont
 }
 
 void Comet::drawTail(StelCore* core, StelProjector::ModelViewTranformP transfo, bool gas)
-{
+{	
 	StelPainter* sPainter = new StelPainter(core->getProjection(transfo));
 	glEnable(GL_BLEND);
 	glBlendFunc(GL_ONE, GL_ONE);
 	glDisable(GL_CULL_FACE);
 
-	// GZ: If we use getVMagnitudeWithExtinction(), a head extincted in the horizon mist can completely hide an otherwise frighteningly long tail.
-	// we must use unextincted mag, but mix/dim with atmosphere/sky brightness.
-	// In addition, light falloff is a bit reduced for better visibility. Power basis should be 0.4, we use 0.6.
-	float magFactor=std::pow(0.6f , getVMagnitude(core));
-	if (core->getSkyDrawer()->getFlagHasAtmosphere())
-	{
-		// Mix with sky brightness and light pollution: This is very ad-hoc, if someone finds a better solution, please go ahead!
-		// Light pollution:
-		float bortleIndexFactor=0.1f * (11 - core->getSkyDrawer()->getBortleScaleIndex());
-		magFactor*= bortleIndexFactor*bortleIndexFactor; // GZ-Guesstimate for light pollution influence
-		// sky brightness: This is about 10 for twilight where bright comet tails should already be visible. Dark night is close to 0.
-		float avgAtmLum=GETSTELMODULE(LandscapeMgr)->getAtmosphereAverageLuminance();
-		float atmLumFactor=(15.0f-avgAtmLum)/15.0f;  if (atmLumFactor<0.05f) atmLumFactor=0.05f;    //atmLumFactor=std::sqrt(atmLumFactor);
-		magFactor*=atmLumFactor*atmLumFactor;
-	}
-	magFactor*=(gas? 0.9 : dustTailBrightnessFactor); // TBD: empirical adjustment for texture brightness.
-	magFactor=qMin(magFactor, 1.05f); // Limit excessively bright display.
-
 	tailTexture->bind();
 
 	if (gas) {
-		sPainter->setColor(0.15f*magFactor,0.15f*magFactor,0.6f*magFactor);
-		sPainter->setArrays((Vec3d*)gastailVertexArr.constData(), (Vec2f*)tailTexCoordArr.constData());
+		sPainter->setArrays((Vec3d*)gastailVertexArr.constData(), (Vec2f*)tailTexCoordArr.constData(), (Vec3f*)gastailColorArr.constData());
 		sPainter->drawFromArray(StelPainter::Triangles, tailIndices.size(), 0, true, tailIndices.constData());
 
 	} else {
-		sPainter->setColor(magFactor, magFactor,0.6f*magFactor);
-		sPainter->setArrays((Vec3d*)dusttailVertexArr.constData(), (Vec2f*)tailTexCoordArr.constData());
+		sPainter->setArrays((Vec3d*)dusttailVertexArr.constData(), (Vec2f*)tailTexCoordArr.constData(), (Vec3f*)dusttailColorArr.constData());
 		sPainter->drawFromArray(StelPainter::Triangles, tailIndices.size(), 0, true, tailIndices.constData());
 	}
 	glDisable(GL_BLEND);
 
-
-
-	if (sPainter)
-		delete sPainter;
+	delete sPainter;
 	sPainter=NULL;
 }
 
@@ -478,23 +574,19 @@ void Comet::drawComa(StelCore* core, StelProjector::ModelViewTranformP transfo)
 	glBlendFunc(GL_ONE, GL_ONE);
 	glDisable(GL_CULL_FACE);
 
-	// GZ: For the coma, we can use extinction via atmosphere.
-	// In addition, light falloff is a bit reduced for better visibility. Power basis should be 0.4, we use 0.6.
-	float minSkyMag=core->getSkyDrawer()->getLimitMagnitude();
-	float mag100pct=minSkyMag-6.0f; // should be 5, but let us draw it a bit brighter.
-	float magDrop=getVMagnitudeWithExtinction(core)-mag100pct;
-	float magFactor=std::pow(0.6f , magDrop);
-	magFactor=qMin(magFactor, 2.0f); // Limit excessively bright display.
-
+	StelToneReproducer* eye = core->getToneReproducer();
+	float lum = core->getSkyDrawer()->surfacebrightnessToLuminance(getVMagnitudeWithExtinction(core)+11.0f); // How to calibrate?
+	// Get the luminance scaled between 0 and 1
+	float aLum =eye->adaptLuminanceScaled(lum);
+	float magFactor=qMin(qMax(aLum, 0.25f), 2.0f);
 	comaTexture->bind();
-	sPainter->setColor(magFactor,magFactor,0.6f*magFactor);
+	sPainter->setColor(0.3f*magFactor,0.7*magFactor,magFactor);
 	sPainter->setArrays((Vec3d*)comaVertexArr.constData(), (Vec2f*)comaTexCoordArr.constData());
 	sPainter->drawFromArray(StelPainter::Triangles, comaVertexArr.size()/3);
 
 	glDisable(GL_BLEND);
 
-	if (sPainter)
-		delete sPainter;
+	delete sPainter;
 	sPainter=NULL;
 }
 
@@ -521,11 +613,11 @@ void Comet::computeComa(const float diameter)
 // Parabola equation: z=x²/2p.
 // xOffset for the dust tail, this may introduce a bend. Units are x per sqrt(z).
 void Comet::computeParabola(const float parameter, const float radius, const float zshift,
-			    QVector<double>& vertexArr, QVector<float>& texCoordArr, QVector<unsigned short> &indices, const float xOffset) {
+			    QVector<Vec3d>& vertexArr, QVector<float>& texCoordArr, QVector<unsigned short> &indices, const float xOffset) {
 
-	// GZ: keep the array and replace contents. However, using replace() is only slightly faster.
-	if (vertexArr.length() < (3*(COMET_TAIL_SLICES*COMET_TAIL_STACKS+1)))
-		vertexArr.resize(3*(COMET_TAIL_SLICES*COMET_TAIL_STACKS+1));
+	// keep the array and replace contents. However, using replace() is only slightly faster.
+	if (vertexArr.length() < ((COMET_TAIL_SLICES*COMET_TAIL_STACKS+1)))
+		vertexArr.resize((COMET_TAIL_SLICES*COMET_TAIL_STACKS+1));
 	if (createTailIndices) indices.clear();
 	if (createTailTextureCoords) texCoordArr.clear();
 	int i;
@@ -541,8 +633,8 @@ void Comet::computeParabola(const float parameter, const float radius, const flo
 		ya[i]=cos(i*da);
 	}
 	
-	vertexArr.replace(0, 0.0); vertexArr.replace(1, 0.0); vertexArr.replace(2, zshift);
-	int vertexArrIndex=3;
+	vertexArr.replace(0, Vec3d(0.0, 0.0, zshift));
+	int vertexArrIndex=1;
 	if (createTailTextureCoords) texCoordArr << 0.5f << 0.5f;
 	// define the indices lying on circles, starting at 1: odd rings have 1/slices+1/2slices, even-numbered rings straight 1/slices
 	// inner ring#1
@@ -553,9 +645,7 @@ void Comet::computeParabola(const float parameter, const float radius, const flo
 		for (i=ring & 1; i<2*COMET_TAIL_SLICES; i+=2) { // i.e., ring1 has shifted vertices, ring2 has even ones.
 			x=xa[i]*radius*ring/COMET_TAIL_STACKS;
 			y=ya[i]*radius*ring/COMET_TAIL_STACKS;
-			vertexArr.replace(vertexArrIndex++, x+xShift);
-			vertexArr.replace(vertexArrIndex++, y);
-			vertexArr.replace(vertexArrIndex++, z);
+			vertexArr.replace(vertexArrIndex++, Vec3d(x+xShift, y, z));
 			if (createTailTextureCoords) texCoordArr << 0.5+ 0.5*x/radius << 0.5+0.5*y/radius;
 		}
 	}
@@ -590,11 +680,3 @@ void Comet::computeParabola(const float parameter, const float radius, const flo
 	createTailIndices=false;
 	createTailTextureCoords=false;
 }
-
-// These are to avoid having index arrays for each comet when all are equal.
-bool Comet::createTailIndices=true;
-bool Comet::createTailTextureCoords=true;
-StelTextureSP Comet::comaTexture;
-StelTextureSP Comet::tailTexture;
-QVector<float> Comet::tailTexCoordArr; // computed only once FOR ALL COMETS!
-QVector<unsigned short> Comet::tailIndices; // computed only once FOR ALL COMETS!
