@@ -32,6 +32,7 @@
 	2013-12: GZ: New algorithms for position computation following Paul Heafner: Fundamental Ephemeris Computations (Willmann-Bell 1999).
 	2014-01: GZ: Parabolic tails appropriately scaled/rotated. Much is currently empirical, leaving room for physics-based improvements.
 	2014-08: GZ: speedup in case hundreds of comets are loaded.
+	2014-11: GZ: tail extinction, better brightness balance.
   */
 class Comet : public Planet
 {
@@ -76,6 +77,11 @@ public:
 	//virtual QString getType() const {return "Comet";}
 	//! \todo Find better sources for the g,k system
 	virtual float getVMagnitude(const StelCore* core) const;
+	//! sets the nameI18 property with the appropriate translation.
+	//! Function overriden to handle the problem with name conflicts.
+	virtual void translateName(const StelTranslator& trans);
+	virtual QString getEnglishName(void) const {return englishName;}
+	virtual QString getNameI18n(void) const {return nameI18;}
 
 	//! \brief sets absolute magnitude and slope parameter.
 	//! These are the parameters in the IAU's two-parameter magnitude system
@@ -91,11 +97,15 @@ public:
 	virtual double getSiderealPeriod() const;
 
 	//! GZ: override from Planet: extend with tail details.
-	virtual void computePosition(const double date);
+	//virtual void computePosition(const double date);
 
 	//! re-implementation of Planet's draw()
 	virtual void draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont);
 
+	// re-implementation of Planet's update() to prepare tails (extinction etc). @param deltaTime: ms (since last call)
+	// TODO: computePosition can be removed and things added here!
+	virtual void update(int deltaTime);
+
 private:
 	//! @returns estimates for (Coma diameter [AU], gas tail length [AU]).
 	//! Using the formula from Guide found by the GSoC2012 initiative at http://www.projectpluto.com/update7b.htm#comet_tail_formula
@@ -117,7 +127,7 @@ private:
 	//! @param colorArr vertex colors (if not textured) r0, g0, b0, r1, g1, b1, ...
 	//! @param indices into the former arrays (zero-starting), triplets forming triangles: t0,0, t0,1, t0,2, t1,0, t1,1, t1,2, ...
 	//! @param xOffset for the dust tail, this may introduce a bend. Units are x per sqrt(z).
-	void computeParabola(const float parameter, const float topradius, const float zshift, QVector<double>& vertexArr, QVector<float>& texCoordArr, QVector<unsigned short>& indices, const float xOffset=0.0f);
+	void computeParabola(const float parameter, const float topradius, const float zshift, QVector<Vec3d>& vertexArr, QVector<float>& texCoordArr, QVector<unsigned short>& indices, const float xOffset=0.0f);
 
 	double absoluteMagnitude;
 	double slopeParameter;
@@ -127,9 +137,10 @@ private:
 
 	//GZ Tail additions
 	Vec2f tailFactors; // result of latest call to getComaDiameterAndTailLengthAU(); Results cached here for infostring. [0]=Coma diameter, [1] gas tail length.
-	bool tailActive;		//! true if there is a tail worth bothering (longer than COMET_MIN_TAIL_LENGTH_AU)? Drawing tails is quite costly.
+	bool tailActive;		//! true if there is a tail long enough to be worth drawing. Drawing tails is quite costly.
+	bool tailBright;		//! true if tail is bright enough to draw.
 	double deltaJDtail;             //! like deltaJD, but time difference between tail geometry updates.
-	double lastJDtail;             //! like lastJD, but time of last tail geometry update.
+	double lastJDtail;              //! like lastJD, but time of last tail geometry update.
 	Mat4d gasTailRot;		//! rotation matrix for gas tail parabola
 	Mat4d dustTailRot;		//! rotation matrix for the skewed dust tail parabola
 	float dustTailWidthFactor;      //!< empirical individual broadening of the dust tail end, compared to the gas tail end. Actually, dust tail width=2*comaWidth*dustTailWidthFactor. Default 1.5
@@ -142,8 +153,10 @@ private:
 	static bool createTailIndices;
 	static bool createTailTextureCoords;
 
-	QVector<double> gastailVertexArr;  // computed frequently, describes parabolic shape (along z axis) of gas tail.
-	QVector<double> dusttailVertexArr; // computed frequently, describes parabolic shape (along z axis) of dust tail.
+	QVector<Vec3d> gastailVertexArr;  // computed frequently, describes parabolic shape (along z axis) of gas tail.
+	QVector<Vec3d> dusttailVertexArr; // computed frequently, describes parabolic shape (along z axis) of dust tail.
+	QVector<Vec3f> gastailColorArr;    // NEW computed for every 5 mins, modulates gas tail brightness for extinction
+	QVector<Vec3f> dusttailColorArr;   // NEW computed for every 5 mins, modulates dust tail brightness for extinction
 	static QVector<float> tailTexCoordArr; // computed only once for all comets!
 	static QVector<unsigned short> tailIndices; // computed only once for all comets!
 	static StelTextureSP comaTexture;
