@@ -29,7 +29,6 @@
 #include "StelCore.hpp"
 #include "StelPainter.hpp"
 #include "StelSkyDrawer.hpp"
-#include "StelGui.hpp"
 
 #include <set>
 #include <QSettings>
@@ -38,7 +37,6 @@
 
 //! @class SkyGrid
 //! Class which manages a grid to display in the sky.
-//! TODO needs support for DMS/DMS labelling, not only HMS/DMS
 class SkyGrid
 {
 public:
@@ -72,7 +70,8 @@ public:
 		ECLIPTIC,
 		MERIDIAN,
 		HORIZON,
-		GALACTICEQUATOR
+		GALACTICEQUATOR,
+		LONGITUDE
 	};
 	// Create and precompute positions of a SkyGrid
 	SkyLine(SKY_LINE_TYPE _line_type = EQUATOR);
@@ -167,7 +166,7 @@ void viewportEdgeIntersectCallback(const Vec3d& screenPos, const Vec3d& directio
 	direc.normalize();
 	const Vec4f tmpColor = d->sPainter->getColor();
 	d->sPainter->setColor(d->textColor[0], d->textColor[1], d->textColor[2], d->textColor[3]);
-	bool withDecimalDegree = dynamic_cast<StelGui*>(StelApp::getInstance().getGui())->getFlagShowDecimalDegrees();
+	bool withDecimalDegree = StelApp::getInstance().getFlagShowDecimalDegrees();;
 
 	QString text;
 	if (d->text.isEmpty())
@@ -276,7 +275,7 @@ void viewportEdgeIntersectCallback(const Vec3d& screenPos, const Vec3d& directio
 					textAngle = M_PI;
 
 				if (withDecimalDegree)
-					text = StelUtils::radToDecDegStr(textAngle,false,true);
+					text = StelUtils::radToDecDegStr(textAngle);
 				else
 					text = StelUtils::radToHmsStrAdapt(textAngle);
 			}
@@ -307,7 +306,7 @@ void SkyGrid::draw(const StelCore* core) const
 	if (!fader.getInterstate())
 		return;
 
-	bool withDecimalDegree = dynamic_cast<StelGui*>(StelApp::getInstance().getGui())->getFlagShowDecimalDegrees();
+	bool withDecimalDegree = StelApp::getInstance().getFlagShowDecimalDegrees();;
 
 	// Look for all meridians and parallels intersecting with the disk bounding the viewport
 	// Check whether the pole are in the viewport
@@ -320,7 +319,7 @@ void SkyGrid::draw(const StelCore* core) const
 		southPoleInViewport = true;
 	// Get the longitude and latitude resolution at the center of the viewport
 	Vec3d centerV;
-	prj->unProject(prj->getViewportPosX()+prj->getViewportWidth()/2, prj->getViewportPosY()+prj->getViewportHeight()/2+1, centerV);
+	prj->unProject(prj->getViewportPosX()+prj->getViewportWidth()/2., prj->getViewportPosY()+prj->getViewportHeight()/2.+1., centerV);
 	double lon2, lat2;
 	StelUtils::rectToSphe(&lon2, &lat2, centerV);
 
@@ -330,15 +329,15 @@ void SkyGrid::draw(const StelCore* core) const
 		gridStepMeridianRad = (frameType==StelCore::FrameAltAz || frameType==StelCore::FrameGalactic) ? M_PI/180.* 10. : M_PI/180.* 15.;
 	else
 	{
-		const double closetResLon = (frameType==StelCore::FrameAltAz || frameType==StelCore::FrameGalactic) ? getClosestResolutionDMS(prj->getPixelPerRadAtCenter()*std::cos(lat2)) : getClosestResolutionHMS(prj->getPixelPerRadAtCenter()*std::cos(lat2));
-		gridStepMeridianRad = M_PI/180.* ((northPoleInViewport || southPoleInViewport) ? 15. : closetResLon);
+		const double closestResLon = (frameType==StelCore::FrameAltAz || frameType==StelCore::FrameGalactic) ? getClosestResolutionDMS(prj->getPixelPerRadAtCenter()*std::cos(lat2)) : getClosestResolutionHMS(prj->getPixelPerRadAtCenter()*std::cos(lat2));
+		gridStepMeridianRad = M_PI/180.* ((northPoleInViewport || southPoleInViewport) ? 15. : closestResLon);
 	}
 
 	// Get the bounding halfspace
 	const SphericalCap& viewPortSphericalCap = prj->getBoundingCap();
 
 	// Compute the first grid starting point. This point is close to the center of the screen
-	// and lays at the intersection of a meridien and a parallel
+	// and lies at the intersection of a meridian and a parallel
 	lon2 = gridStepMeridianRad*((int)(lon2/gridStepMeridianRad+0.5));
 	lat2 = gridStepParallelRad*((int)(lat2/gridStepParallelRad+0.5));
 	Vec3d firstPoint;
@@ -347,10 +346,15 @@ void SkyGrid::draw(const StelCore* core) const
 
 	// Q_ASSERT(viewPortSphericalCap.contains(firstPoint));
 
-	// Initialize a painter and set openGL state
+	// Initialize a painter and set OpenGL state
 	StelPainter sPainter(prj);
 	glEnable(GL_BLEND);
 	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); // Normal transparency mode
+	// OpenGL ES 2.0 doesn't have GL_LINE_SMOOTH
+	#ifdef GL_LINE_SMOOTH
+	if (QOpenGLContext::currentContext()->format().renderableType()==QSurfaceFormat::OpenGL)
+		glEnable(GL_LINE_SMOOTH);
+	#endif
 	Vec4f textColor(color[0], color[1], color[2], 0);
 	sPainter.setColor(color[0],color[1],color[2], fader.getInterstate());
 
@@ -548,6 +552,11 @@ void SkyGrid::draw(const StelCore* core) const
 			fpt.transfo4d(rotLon);
 		}
 	}
+	// OpenGL ES 2.0 doesn't have GL_LINE_SMOOTH
+	#ifdef GL_LINE_SMOOTH
+	if (QOpenGLContext::currentContext()->format().renderableType()==QSurfaceFormat::OpenGL)
+		glDisable(GL_LINE_SMOOTH);
+	#endif
 }
 
 
@@ -593,6 +602,11 @@ void SkyLine::updateLabel()
 			frameType = StelCore::FrameGalactic;
 			label = q_("Galactic Equator");
 			break;
+		case LONGITUDE:
+			frameType = StelCore::FrameObservercentricEcliptic;
+			// TRANSLATORS: Full term is "opposition/conjunction longitude"
+			label = q_("O./C. longitude");
+			break;
 	}
 }
 
@@ -628,6 +642,16 @@ void SkyLine::draw(StelCore *core) const
 		meridianSphericalCap.n.set(0,1,0);
 	}
 
+	if (line_type==LONGITUDE)
+	{
+		Vec3d coord;
+		double lambda, beta;
+		StelUtils::rectToSphe(&lambda, &beta, core->getCurrentPlanet()->getHeliocentricEclipticPos());
+		StelUtils::spheToRect(lambda + M_PI/2., 0., coord);
+		meridianSphericalCap.n.set(coord[0],coord[1],coord[2]);
+		fpt.set(0,0,1);
+	}
+
 	Vec3d p1, p2;
 	if (!SphericalCap::intersectionPoints(viewPortSphericalCap, meridianSphericalCap, p1, p2))
 	{
@@ -678,6 +702,7 @@ GridLinesMgr::GridLinesMgr()
 	meridianLine = new SkyLine(SkyLine::MERIDIAN);
 	horizonLine = new SkyLine(SkyLine::HORIZON);
 	galacticEquatorLine = new SkyLine(SkyLine::GALACTICEQUATOR);
+	longitudeLine = new SkyLine(SkyLine::LONGITUDE);
 }
 
 GridLinesMgr::~GridLinesMgr()
@@ -692,6 +717,7 @@ GridLinesMgr::~GridLinesMgr()
 	delete meridianLine;
 	delete horizonLine;
 	delete galacticEquatorLine;
+	delete longitudeLine;
 }
 
 /*************************************************************************
@@ -719,6 +745,7 @@ void GridLinesMgr::init()
 	setFlagMeridianLine(conf->value("viewing/flag_meridian_line").toBool());
 	setFlagHorizonLine(conf->value("viewing/flag_horizon_line").toBool());
 	setFlagGalacticEquatorLine(conf->value("viewing/flag_galactic_equator_line").toBool());
+	setFlagLongitudeLine(conf->value("viewing/flag_longitude_line").toBool());
 	
 	StelApp& app = StelApp::getInstance();
 	connect(&app, SIGNAL(colorSchemeChanged(const QString&)), this, SLOT(setStelStyle(const QString&)));
@@ -735,6 +762,7 @@ void GridLinesMgr::init()
 	addAction("actionShow_Ecliptic_J2000_Grid", displayGroup, N_("Ecliptic J2000 grid"), "eclipticJ2000GridDisplayed");
 	addAction("actionShow_Galactic_Grid", displayGroup, N_("Galactic grid"), "galacticGridDisplayed");
 	addAction("actionShow_Galactic_Equator_Line", displayGroup, N_("Galactic equator"), "galacticEquatorLineDisplayed");
+	addAction("actionShow_Longitude_Line", displayGroup, N_("Opposition/conjunction longitude line"), "longitudeLineDisplayed");
 }
 
 void GridLinesMgr::update(double deltaTime)
@@ -750,6 +778,7 @@ void GridLinesMgr::update(double deltaTime)
 	meridianLine->update(deltaTime);
 	horizonLine->update(deltaTime);
 	galacticEquatorLine->update(deltaTime);
+	longitudeLine->update(deltaTime);
 }
 
 void GridLinesMgr::draw(StelCore* core)
@@ -764,6 +793,7 @@ void GridLinesMgr::draw(StelCore* core)
 	meridianLine->draw(core);
 	horizonLine->draw(core);
 	galacticEquatorLine->draw(core);
+	longitudeLine->draw(core);
 }
 
 void GridLinesMgr::setStelStyle(const QString& section)
@@ -782,6 +812,7 @@ void GridLinesMgr::setStelStyle(const QString& section)
 	setColorMeridianLine(StelUtils::strToVec3f(conf->value(section+"/meridian_color", defaultColor).toString()));
 	setColorHorizonLine(StelUtils::strToVec3f(conf->value(section+"/horizon_color", defaultColor).toString()));
 	setColorGalacticEquatorLine(StelUtils::strToVec3f(conf->value(section+"/galactic_equator_color", defaultColor).toString()));
+	setColorLongitudeLine(StelUtils::strToVec3f(conf->value(section+"/longitude_color", defaultColor).toString()));
 }
 
 void GridLinesMgr::updateLineLabels()
@@ -791,6 +822,7 @@ void GridLinesMgr::updateLineLabels()
 	meridianLine->updateLabel();
 	horizonLine->updateLabel();
 	galacticEquatorLine->updateLabel();
+	longitudeLine->updateLabel();
 }
 
 //! Set flag for displaying Azimuthal Grid
@@ -994,6 +1026,31 @@ void GridLinesMgr::setColorMeridianLine(const Vec3f& newColor)
 	}
 }
 
+//! Set flag for displaying opposition/conjunction longitude line
+void GridLinesMgr::setFlagLongitudeLine(const bool displayed)
+{
+	if(displayed != longitudeLine->isDisplayed()) {
+		longitudeLine->setDisplayed(displayed);
+		emit longitudeLineDisplayedChanged(displayed);
+	}
+}
+//! Get flag for displaying opposition/conjunction longitude line
+bool GridLinesMgr::getFlagLongitudeLine(void) const
+{
+	return longitudeLine->isDisplayed();
+}
+Vec3f GridLinesMgr::getColorLongitudeLine(void) const
+{
+	return longitudeLine->getColor();
+}
+void GridLinesMgr::setColorLongitudeLine(const Vec3f& newColor)
+{
+	if(newColor != longitudeLine->getColor()) {
+		longitudeLine->setColor(newColor);
+		emit longitudeLineColorChanged(newColor);
+	}
+}
+
 //! Set flag for displaying Horizon Line
 void GridLinesMgr::setFlagHorizonLine(const bool displayed)
 {
