@@ -117,7 +117,7 @@ void Cardinals::draw(const StelCore* core, double latitude) const
 	Vec3f pos;
 	Vec3f xy;
 
-	float shift = sPainter.getFontMetrics().width(sNorth)/2;
+	float shift = sPainter.getFontMetrics().width(sNorth)/2.;
 	if (core->getProjection(StelCore::FrameJ2000)->getMaskType() == StelProjector::MaskDisk)
 		shift = 0;
 
@@ -294,11 +294,21 @@ void LandscapeMgr::update(double deltaTime)
 		landscape->setBrightness(1.f, 0.0f);
 	}
 	else
-	{   float lightscapeBrightness=0.0f;
-		// night pollution brightness is mixed in at -3...-8 degrees.
-		if (sunPos[2]<-0.14f) lightscapeBrightness=1.0f;
-		else if (sunPos[2]<-0.05f) lightscapeBrightness = 1.0f-(sunPos[2]+0.14)/(-0.05+0.14);
-		landscape->setBrightness(landscapeBrightness, lightscapeBrightness);
+	{
+		float lightscapeBrightness=0.0f;
+		// light pollution layer is mixed in at -3...-8 degrees.
+		float sunAlt = sunPos[2];
+		if (sunAlt<-0.14f)
+			lightscapeBrightness=1.0f;
+		else
+		{
+			if (sunAlt<-0.05f)
+				lightscapeBrightness = 1.0f-(sunAlt+0.14)/(-0.05+0.14);
+		}
+		if (sunAlt<=0.f && !atmosphere->getFlagShow() && !getFlagLandscapeUseMinimalBrightness())
+			landscape->setBrightness(0.f, 0.f);
+		else
+			landscape->setBrightness(landscapeBrightness, lightscapeBrightness);
 	}
 }
 
@@ -337,7 +347,8 @@ void LandscapeMgr::init()
 	setDefaultMinimalBrightness(conf->value("landscape/minimal_brightness", 0.01).toFloat());
 	setFlagLandscapeUseMinimalBrightness(conf->value("landscape/flag_minimal_brightness", false).toBool());
 	setFlagLandscapeSetsMinimalBrightness(conf->value("landscape/flag_landscape_sets_minimal_brightness",false).toBool());
-	setFlagAtmosphereAutoEnable(conf->value("viewing/flag_atmopshere_auto_enable",true).toBool());
+	setFlagAtmosphereAutoEnable(conf->value("viewing/flag_atmosphere_auto_enable",true).toBool());
+	setFlagIllumination(conf->value("landscape/flag_enable_illumination_layer", true).toBool());
 
 	bool ok =true;
 	setAtmosphereBortleLightPollution(conf->value("stars/init_bortle_scale",3).toInt(&ok));
@@ -356,6 +367,7 @@ void LandscapeMgr::init()
 	addAction("actionShow_Fog", displayGroup, N_("Fog"), "fogDisplayed", "F");
 	addAction("actionShow_Cardinal_Points", displayGroup, N_("Cardinal points"), "cardinalsPointsDisplayed", "Q");
 	addAction("actionShow_Ground", displayGroup, N_("Ground"), "landscapeDisplayed", "G");
+	addAction("actionShow_LandscapeIllumination", displayGroup, N_("Illumination"), "illuminationDisplayed", "Shift+G");
 }
 
 void LandscapeMgr::setStelStyle(const QString& section)
@@ -367,7 +379,7 @@ void LandscapeMgr::setStelStyle(const QString& section)
 	setColorCardinalPoints(StelUtils::strToVec3f(conf->value(section+"/cardinal_color", defaultColor).toString()));
 }
 
-bool LandscapeMgr::setCurrentLandscapeID(const QString& id)
+bool LandscapeMgr::setCurrentLandscapeID(const QString& id, const double changeLocationDuration)
 {
 	if (id.isEmpty())
 		return false;
@@ -386,6 +398,7 @@ bool LandscapeMgr::setCurrentLandscapeID(const QString& id)
 		// Copy display parameters from previous landscape to new one
 		newLandscape->setFlagShow(landscape->getFlagShow());
 		newLandscape->setFlagShowFog(landscape->getFlagShowFog());
+		newLandscape->setFlagShowIllumination(landscape->getFlagShowIllumination());
 		delete landscape;
 		landscape = newLandscape;
 	}
@@ -393,7 +406,7 @@ bool LandscapeMgr::setCurrentLandscapeID(const QString& id)
 
 	if (getFlagLandscapeSetsLocation() && landscape->hasLocation())
 	{
-		StelApp::getInstance().getCore()->moveObserverTo(landscape->getLocation());
+		StelApp::getInstance().getCore()->moveObserverTo(landscape->getLocation(), changeLocationDuration);
 		StelSkyDrawer* drawer=StelApp::getInstance().getCore()->getSkyDrawer();
 
 		if (landscape->getDefaultFogSetting() >-1)
@@ -431,7 +444,7 @@ bool LandscapeMgr::setCurrentLandscapeID(const QString& id)
 	return true;
 }
 
-bool LandscapeMgr::setCurrentLandscapeName(const QString& name)
+bool LandscapeMgr::setCurrentLandscapeName(const QString& name, const double changeLocationDuration)
 {
 	if (name.isEmpty())
 		return false;
@@ -439,7 +452,7 @@ bool LandscapeMgr::setCurrentLandscapeName(const QString& name)
 	QMap<QString,QString> nameToDirMap = getNameToDirMap();
 	if (nameToDirMap.find(name)!=nameToDirMap.end())
 	{
-		return setCurrentLandscapeID(nameToDirMap[name]);
+		return setCurrentLandscapeID(nameToDirMap[name], changeLocationDuration);
 	}
 	else
 	{
@@ -510,6 +523,19 @@ bool LandscapeMgr::getFlagFog() const
 	return landscape->getFlagShowFog();
 }
 
+void LandscapeMgr::setFlagIllumination(const bool displayed)
+{
+	if (landscape->getFlagShowIllumination() != displayed) {
+		landscape->setFlagShowIllumination(displayed);
+		emit illuminationDisplayedChanged(displayed);
+	}
+}
+
+bool LandscapeMgr::getFlagIllumination() const
+{
+	return landscape->getFlagShowIllumination();
+}
+
 void LandscapeMgr::setFlagLandscapeAutoSelection(bool enableAutoSelect)
 {
 	flagLandscapeAutoSelection = enableAutoSelect;
@@ -535,39 +561,22 @@ bool LandscapeMgr::getFlagAtmosphereAutoEnable() const
  *********************************************************************/
 QStringList LandscapeMgr::getAllLandscapeNames() const
 {
-	QMap<QString,QString> nameToDirMap = getNameToDirMap();
-	QStringList result;
-
-	// We just look over the map of names to IDs and extract the keys
-	foreach (QString i, nameToDirMap.keys())
-	{
-		result += i;
-	}
-	return result;
+	return getNameToDirMap().keys();
 }
 
 QStringList LandscapeMgr::getAllLandscapeIDs() const
 {
-	QMap<QString,QString> nameToDirMap = getNameToDirMap();
-	QStringList result;
-
-	// We just look over the map of names to IDs and extract the keys
-	foreach (QString i, nameToDirMap.values())
-	{
-		result += i;
-	}
-	return result;
+	return getNameToDirMap().values();
 }
 
 QStringList LandscapeMgr::getUserLandscapeIDs() const
 {
-	QMap<QString,QString> nameToDirMap = getNameToDirMap();
 	QStringList result;
-	foreach (QString id, nameToDirMap.values())
+	foreach (QString id, getNameToDirMap().values())
 	{
 		if(!packagedLandscapeIDs.contains(id))
 		{
-			result += id;
+			result.append(id);
 		}
 	}
 	return result;
@@ -585,19 +594,24 @@ QString LandscapeMgr::getCurrentLandscapeHtmlDescription() const
 	desc+="<b>"+q_("Author: ")+"</b>";
 	desc+=landscape->getAuthorName();
 	desc+="<br>";
-	desc+="<b>"+q_("Location: ")+"</b>";
-	if (landscape->getLocation().longitude>-500.0 && landscape->getLocation().latitude>-500.0)
+	// This previously showed 0/0 for locationless landscapes!
+	if (landscape->hasLocation())
 	{
+		desc+="<b>"+q_("Location: ")+"</b>";
 		desc += StelUtils::radToDmsStrAdapt(landscape->getLocation().longitude * M_PI/180.);
 		desc += "/" + StelUtils::radToDmsStrAdapt(landscape->getLocation().latitude *M_PI/180.);
 		desc += QString(q_(", %1 m")).arg(landscape->getLocation().altitude);
 		QString planetName = landscape->getLocation().planetName;
 		if (!planetName.isEmpty())
 		{
-			desc += "<br><b>"+q_("Planet: ")+"</b>"+ q_(planetName);
+			const StelTranslator& trans = StelApp::getInstance().getLocaleMgr().getSkyTranslator();
+			desc += "<br><b>"+q_("Celestial body:")+"</b> "+ trans.qtranslate(planetName);
 		}
 		desc += "<br><br>";
 	}
+	// TBD: Activate this or delete?
+	//else
+	//	desc+="<b>"+q_("Location: ")+"</b>" + q_("not specified (just decoration)") + "<br><br>";
 	return desc;
 }
 
@@ -637,8 +651,10 @@ void LandscapeMgr::setFlagAtmosphere(const bool displayed)
 		atmosphere->setFlagShow(displayed);
 		StelApp::getInstance().getCore()->getSkyDrawer()->setFlagHasAtmosphere(displayed);
 		emit atmosphereDisplayedChanged(displayed);
-		if (StelApp::getInstance().getSettings()->value("landscape/flag_fog", true).toBool())
-			setFlagFog(displayed); // sync of visibility of fog because this is atmospheric phenomena
+		//if (StelApp::getInstance().getSettings()->value("landscape/flag_fog", true).toBool())
+		//	setFlagFog(displayed); // sync of visibility of fog because this is atmospheric phenomena
+		// GZ This did not work as it may have been intended. Switch off fog, switch off atmosphere. Switch on atmosphere, and you have fog?
+		// --> Fog is only drawn in Landscape if atmosphere is switched on!
 	}
 }
 
