@@ -24,11 +24,11 @@
 
 #include "StelModule.hpp"
 #include "StelUtils.hpp"
+#include "Landscape.hpp"
 
 #include <QMap>
 #include <QStringList>
 
-class Landscape;
 class Atmosphere;
 class Cardinals;
 class QSettings;
@@ -57,6 +57,10 @@ class LandscapeMgr : public StelModule
 			   READ getFlagLandscape
 			   WRITE setFlagLandscape
 			   NOTIFY landscapeDisplayedChanged)
+	Q_PROPERTY(bool illuminationDisplayed
+			   READ getFlagIllumination
+			   WRITE setFlagIllumination
+			   NOTIFY illuminationDisplayedChanged)
 	Q_PROPERTY(bool databaseUsage
 			READ getFlagUseLightPollutionFromDatabase
 			WRITE setFlagUseLightPollutionFromDatabase
@@ -92,7 +96,7 @@ public:
 	///////////////////////////////////////////////////////////////////////////
 	// Method specific to the landscape manager
 	//! Return the global landscape luminance [0..1], for being used e.g for setting eye adaptation.
-	//! GZ 2014-01-03: THIS IS MISLEADING. Returns 1 if atmosphere drawing is on and no eclipse underway, 0 if atmosphere is switched off.
+	//! It returns 1 if atmosphere drawing is on and no eclipse underway, 0 if atmosphere is switched off.
 	//! The actual brightness is of no concern here. You may use getAtmosphereAverageLuminance() for this.
 	float getLuminance() const;
 	//! return average luminance [cd/m^2] of atmosphere. Around 10 at sunset, 6400 in daylight, >0 in dark night.
@@ -113,7 +117,7 @@ public:
 	Landscape* createFromFile(const QString& landscapeFile, const QString& landscapeId);
 
 	// GZ: implement StelModule's method. For test purposes only, we implement a manual transparency sampler.
-	// TODO: comment this away for final builds
+	// TODO: comment this away for final builds. Please leave it in until this feature is finished.
 	// virtual void handleMouseClicks(class QMouseEvent*);
 
 public slots:
@@ -138,14 +142,19 @@ public slots:
 	const QString& getCurrentLandscapeID() const {return currentLandscapeID;}
 	//! Change the current landscape to the landscape with the ID specified.
 	//! @param id the ID of the new landscape
+	//! @param changeLocationDuration the duration of the transition animation
 	//! @return false if the new landscape could not be set (e.g. no landscape of that ID was found).
-	bool setCurrentLandscapeID(const QString& id);
+	bool setCurrentLandscapeID(const QString& id, const double changeLocationDuration = 1.0);
 	
 	//! Get the current landscape name.
 	QString getCurrentLandscapeName() const;
 	//! Change the current landscape to the landscape with the name specified.
 	//! @param name the name of the new landscape, as found in the landscape:name key of the landscape.ini file.
-	bool setCurrentLandscapeName(const QString& name);
+	//! @param changeLocationDuration the duration of the transition animation
+	bool setCurrentLandscapeName(const QString& name, const double changeLocationDuration = 1.0);
+
+	//! Get the current landscape object.
+	Landscape* getCurrentLandscape() const { return landscape; }
 
 	//! Get the default landscape ID.
 	const QString& getDefaultLandscapeID() const {return defaultLandscapeID;}
@@ -172,6 +181,10 @@ public slots:
 	bool getFlagFog() const;
 	//! Set flag for displaying Fog.
 	void setFlagFog(const bool displayed);
+	//! Get flag for displaying illumination layer
+	bool getFlagIllumination() const;
+	//! Set flag for displaying illumination layer
+	void setFlagIllumination(const bool on);
 
 	//! Return the value of the flag determining if a change of landscape will update the observer location.
 	bool getFlagLandscapeSetsLocation() const {return flagLandscapeSetsLocation;}
@@ -187,9 +200,9 @@ public slots:
 	//! Sets the value of the flag determining if the minimal brightness should be taken from landscape.ini
 	void setFlagLandscapeSetsMinimalBrightness(bool b) {flagLandscapeSetsMinimalBrightness=b;}
 	//! Return the minimal brightness value of the landscape
-	float getDefaultMinimalBrightness() const {return defaultMinimalBrightness;}
+	double getDefaultMinimalBrightness() const {return defaultMinimalBrightness;}
 	//! Set the minimal brightness value of the landscape.
-	void setDefaultMinimalBrightness(const float b) {defaultMinimalBrightness=b;}
+	void setDefaultMinimalBrightness(const double b) {defaultMinimalBrightness=b;}
 	//! Sets the value of the flag usage light pollution (and bortle index) from locations database.
 	void setFlagUseLightPollutionFromDatabase(const bool usage);
 	//! Return the value of flag usage light pollution (and bortle index) from locations database.
@@ -312,11 +325,16 @@ public slots:
 	//! Set flag for auto-enable atmosphere for planets with atmospheres in location window
 	void setFlagAtmosphereAutoEnable(bool b);
 
+	//! Forward opacity query to current landscape.
+	//! @param azalt direction of view line to sample in azaltimuth coordinates.
+	float getLandscapeOpacity(Vec3d azalt) const {return landscape->getOpacity(azalt);}
+
 signals:
 	void atmosphereDisplayedChanged(const bool displayed);
 	void cardinalsPointsDisplayedChanged(const bool displayed);
 	void fogDisplayedChanged(const bool displayed);
 	void landscapeDisplayedChanged(const bool displayed);
+	void illuminationDisplayedChanged(const bool displayed);
 	void lightPollutionUsageChanged(const bool usage);
 
 	//! Emitted when a landscape has been installed or un-installed.
@@ -359,6 +377,7 @@ private:
 	//! Set light pollution luminance level.
 	void setAtmosphereLightPollutionLuminance(const float f);
 
+
 	//! For a given landscape name, return the landscape ID.
 	//! This takes a name of the landscape, as described in the landscape:name item in the
 	//! landscape.ini, and returns the landscape ID which corresponds to that name.
