@@ -190,7 +190,7 @@ QString MinorPlanet::getInfoString(const StelCore *core, const InfoStringGroup &
 		if (nameIsProvisionalDesignation)
 			oss << provisionalDesignationHtml;
 		else
-			oss << q_(properName);  // UI translation can differ from sky translation
+			oss << getNameI18n();  // UI translation can differ from sky translation
 		oss.setRealNumberNotation(QTextStream::FixedNotation);
 		oss.setRealNumberPrecision(1);
 		if (sphereScale != 1.f)
@@ -203,7 +203,7 @@ QString MinorPlanet::getInfoString(const StelCore *core, const InfoStringGroup &
 		}
 	}
 
-	if (flags&ObjectType)
+	if (flags&ObjectType && getPlanetType()!=isUNDEFINED)
 	{
 		oss << q_("Type: <b>%1</b>").arg(q_(getPlanetTypeString())) << "<br />";
 	}
@@ -255,8 +255,9 @@ QString MinorPlanet::getInfoString(const StelCore *core, const InfoStringGroup &
 		oss << "<br>";
 	}
 
-	if (flags&Size)
-		oss << q_("Apparent diameter: %1").arg(StelUtils::radToDmsStr(2.*getAngularSize(core)*M_PI/180., true)) << "<br>";
+	float aSize = 2.*getAngularSize(core)*M_PI/180.;
+	if (flags&Size && aSize>1e-6)
+		oss << q_("Apparent diameter: %1").arg(StelUtils::radToDmsStr(aSize, true)) << "<br>";
 
 	// If semi-major axis not zero then calculate and display orbital period for asteroid in days
 	double siderealPeriod = getSiderealPeriod();
@@ -293,7 +294,6 @@ float MinorPlanet::getVMagnitude(const StelCore* core) const
 	//Calculate phase angle
 	//(Code copied from Planet::getVMagnitude())
 	//(this is actually vector subtraction + the cosine theorem :))
-	// GZ Try now in float... speed difference is negligible, though.
 	const Vec3d& observerHelioPos = core->getObserverHeliocentricEclipticPos();
 	const float observerRq = observerHelioPos.lengthSquared();
 	const Vec3d& planetHelioPos = getHeliocentricEclipticPos();
