@@ -67,6 +67,9 @@ SolarSystem::SolarSystem()
 	, flagLightTravelTime(false)
 	, flagShow(false)
 	, flagMarker(false)
+	, flagNativeNames(false)
+	, flagTranslatedNames(false)
+	, flagIsolatedTrails(false)
 	, allTrails(NULL)
 {
 	planetNameFont.setPixelSize(StelApp::getInstance().getBaseFontSize());
@@ -101,6 +104,13 @@ SolarSystem::~SolarSystem()
 	{
 		p->satellites.clear();
 	}
+
+	//delete comet textures created in loadPlanets
+	Comet::comaTexture.clear();
+	Comet::tailTexture.clear();
+
+	//deinit of SolarSystem is NOT called at app end automatically
+	deinit();
 }
 
 /*************************************************************************
@@ -136,6 +146,12 @@ void SolarSystem::init()
 	setFlagOrbits(conf->value("astro/flag_planets_orbits").toBool());
 	setFlagLightTravelTime(conf->value("astro/flag_light_travel_time", false).toBool());
 	setFlagMarkers(conf->value("astro/flag_planets_markers", true).toBool());
+	// Set the algorithm from Astronomical Almanac for computation of apparent magnitudes for
+	// planets in case  observer on the Earth by default
+	setApparentMagnitudeAlgorithmOnEarth(conf->value("astro/apparent_magnitude_algorithm", "Harris").toString());
+	setFlagNativeNames(conf->value("viewing/flag_planets_native_names", true).toBool());
+	// Is enabled the showing of isolated trails for selected objects only?
+	setFlagIsolatedTrails(conf->value("viewing/flag_isolated_trails", true).toBool());
 
 	recreateTrails();
 
@@ -151,17 +167,20 @@ void SolarSystem::init()
 	
 	StelApp *app = &StelApp::getInstance();
 	connect(app, SIGNAL(languageChanged()), this, SLOT(updateI18n()));
+	connect(app, SIGNAL(skyCultureChanged(QString)), this, SLOT(updateSkyCulture(QString)));
 	connect(app, SIGNAL(colorSchemeChanged(const QString&)), this, SLOT(setStelStyle(const QString&)));
 
 	QString displayGroup = N_("Display Options");
-	addAction("actionShow_Planets_Labels", displayGroup, N_("Planet labels"), "labelsDisplayed", "P");
+	addAction("actionShow_Planets", displayGroup, N_("Planets"), "planetsDisplayed", "P");
+	addAction("actionShow_Planets_Labels", displayGroup, N_("Planet labels"), "labelsDisplayed", "Alt+P");
 	addAction("actionShow_Planets_Orbits", displayGroup, N_("Planet orbits"), "orbitsDisplayed", "O");
 	addAction("actionShow_Planets_Trails", displayGroup, N_("Planet trails"), "trailsDisplayed", "Shift+T");
 }
 
 void SolarSystem::deinit()
 {
-	Planet::deinitShader();
+	if(Planet::planetShaderProgram)
+		Planet::deinitShader();
 }
 
 void SolarSystem::recreateTrails()
@@ -170,10 +189,94 @@ void SolarSystem::recreateTrails()
 	if (allTrails!=NULL)
 		delete allTrails;
 	allTrails = new TrailGroup(365.f);
-	foreach (const PlanetP& p, getSun()->satellites)
+
+	PlanetP p = getSelected();
+	if (p!=NULL && getFlagIsolatedTrails())
 	{
 		allTrails->addObject((QSharedPointer<StelObject>)p, &trailColor);
 	}
+	else
+	{
+		foreach (const PlanetP& p, getSun()->satellites)
+		{
+			allTrails->addObject((QSharedPointer<StelObject>)p, &trailColor);
+		}
+	}
+}
+
+
+void SolarSystem::updateSkyCulture(const QString& skyCultureDir)
+{
+	planetNativeNamesMap.clear();
+
+	QString namesFile = StelFileMgr::findFile("skycultures/" + skyCultureDir + "/planet_names.fab");
+
+	if (namesFile.isEmpty())
+	{
+		foreach (const PlanetP& p, systemPlanets)
+		{
+			if (p->getPlanetType()==Planet::isPlanet || p->getPlanetType()==Planet::isMoon || p->getPlanetType()==Planet::isStar)
+				p->setNativeName("");
+		}
+		updateI18n();
+		return;
+	}
+
+	// Open file
+	QFile planetNamesFile(namesFile);
+	if (!planetNamesFile.open(QIODevice::ReadOnly | QIODevice::Text))
+	{
+		qDebug() << "Cannot open file" << QDir::toNativeSeparators(namesFile);
+		return;
+	}
+
+	// Now parse the file
+	// lines to ignore which start with a # or are empty
+	QRegExp commentRx("^(\\s*#.*|\\s*)$");
+
+	// lines which look like records - we use the RE to extract the fields
+	// which will be available in recRx.capturedTexts()
+	QRegExp recRx("^\\s*(\\w+)\\s+\"(.+)\"\\s+_[(]\"(.+)\"[)]\\n");
+
+	QString record, planetId, nativeName;
+
+	// keep track of how many records we processed.
+	int totalRecords=0;
+	int readOk=0;
+	int lineNumber=0;
+	while (!planetNamesFile.atEnd())
+	{
+		record = QString::fromUtf8(planetNamesFile.readLine());
+		lineNumber++;
+
+		// Skip comments
+		if (commentRx.exactMatch(record))
+			continue;
+
+		totalRecords++;
+
+		if (!recRx.exactMatch(record))
+		{
+			qWarning() << "ERROR - cannot parse record at line" << lineNumber << "in planet names file" << QDir::toNativeSeparators(namesFile);
+		}
+		else
+		{
+			planetId = recRx.capturedTexts().at(1).trimmed();
+			nativeName = recRx.capturedTexts().at(2).trimmed();
+			planetNativeNamesMap[planetId] = nativeName;
+			readOk++;
+		}
+	}
+	planetNamesFile.close();
+	qDebug() << "Loaded" << readOk << "/" << totalRecords << "native names of planets";
+
+	foreach (const PlanetP& p, systemPlanets)
+	{
+		if (p->getPlanetType()==Planet::isPlanet || p->getPlanetType()==Planet::isMoon || p->getPlanetType()==Planet::isStar)
+			p->setNativeName(planetNativeNamesMap[p->getEnglishName()]);
+	}
+
+	updateI18n();
 }
 
 void SolarSystem::drawPointer(const StelCore* core)
@@ -430,10 +533,10 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 				period = pd.value(secname+"/orbit_Period",-1e100).toDouble();
 				if (period <= -1e100) {
 					meanMotion = (eccentricity == 1.0)
-								? 0.01720209895 * (1.5/pericenterDistance) * sqrt(0.5/pericenterDistance)
+								? 0.01720209895 * (1.5/pericenterDistance) * std::sqrt(0.5/pericenterDistance)
 								: (semi_major_axis > 0.0)
-								? 0.01720209895 / (semi_major_axis*sqrt(semi_major_axis))
-								: 0.01720209895 / (-semi_major_axis*sqrt(-semi_major_axis));
+								? 0.01720209895 / (semi_major_axis*std::sqrt(semi_major_axis))
+								: 0.01720209895 / (-semi_major_axis*std::sqrt(-semi_major_axis));
 					period = 2.0*M_PI/meanMotion;
 				} else {
 					meanMotion = 2.0*M_PI/period;
@@ -546,8 +649,8 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 						//			? 0.01720209895 / (semi_major_axis*sqrt(semi_major_axis))
 						//			: 0.01720209895 / (-semi_major_axis*sqrt(-semi_major_axis));
 						meanMotion = (eccentricity == 1.0)
-									? 0.01720209895 * (1.5/pericenterDistance) * sqrt(0.5/pericenterDistance)  // GZ: This is Heafner's W / dt
-									: 0.01720209895 / (fabs(semi_major_axis)*sqrt(fabs(semi_major_axis)));
+									? 0.01720209895 * (1.5/pericenterDistance) * std::sqrt(0.5/pericenterDistance)  // GZ: This is Heafner's W / dt
+									: 0.01720209895 / (fabs(semi_major_axis)*std::sqrt(fabs(semi_major_axis)));
 					}
 				} else {
 					meanMotion = 2.0*M_PI/period;
@@ -723,10 +826,10 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 		// Create the Solar System body and add it to the list
 		QString type = pd.value(secname+"/type").toString();		
 		PlanetP p;
-		// New class objects, named "plutoid", has properties similar to asteroids and we should calculate their
-		// positions like for asteroids. Plutoids have one exception: Pluto - we should use special
-		// function for calculation of orbit of Pluto.
-		if ((type == "asteroid" || type == "plutoid") && !englishName.contains("Pluto"))
+		// New class objects, named "plutino", "cubewano", "dwarf planet", "SDO", "OCO", has properties
+		// similar to asteroids and we should calculate their positions like for asteroids. Dwarf planets
+		// have one exception: Pluto - we should use special function for calculation of orbit of Pluto.
+		if ((type == "asteroid" || type == "dwarf planet" || type == "cubewano" || type == "plutino" || type == "scattered disc object" || type == "Oort cloud object") && !englishName.contains("Pluto"))
 		{
 			p = PlanetP(new MinorPlanet(englishName,
 						    pd.value(secname+"/lighting").toBool(),
@@ -813,8 +916,12 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 				}
 			}
 
-			mp->setSemiMajorAxis(pd.value(secname+"/orbit_SemiMajorAxis", 0).toDouble());
-
+			const double eccentricity = pd.value(secname+"/orbit_Eccentricity",0.0).toDouble();
+			const double pericenterDistance = pd.value(secname+"/orbit_PericenterDistance",-1e100).toDouble();
+			if (eccentricity<1 && pericenterDistance>0)
+			{
+				mp->setSemiMajorAxis(pericenterDistance / (1.0-eccentricity));
+			}
 		}
 		else
 		{
@@ -906,11 +1013,10 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 	// special case: load earth shadow texture
 	Planet::texEarthShadow = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/earth-shadow.png");
 
-	// GZ: Also comets just have static textures.
+	// Also comets just have static textures.
 	Comet::comaTexture = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/cometComa.png", StelTexture::StelTextureParams(true, GL_LINEAR, GL_CLAMP_TO_EDGE));
-	//GZ: tail textures. We use a paraboloid tail body, textured like a fisheye sphere, i.e. center=head. The texture should be something like a mottled star to give some structure.
+	//tail textures. We use paraboloid tail bodies, textured like a fisheye sphere, i.e. center=head. The texture should be something like a mottled star to give some structure.
 	Comet::tailTexture = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/cometTail.png", StelTexture::StelTextureParams(true, GL_LINEAR, GL_CLAMP_TO_EDGE));
-	//GZ: I think we need only one texture for the tails.
 
 	return true;
 }
@@ -1160,10 +1266,10 @@ QList<StelObjectP> SolarSystem::searchAround(const Vec3d& vv, double limitFov, c
 	return result;
 }
 
-// Update i18 names from english names according to current translator
+// Update i18 names from english names according to current sky culture translator
 void SolarSystem::updateI18n()
 {
-	const StelTranslator& trans = StelApp::getInstance().getLocaleMgr().getAppStelTranslator();
+	const StelTranslator& trans = StelApp::getInstance().getLocaleMgr().getSkyTranslator();
 	foreach (PlanetP p, systemPlanets)
 		p->translateName(trans);
 }
@@ -1178,8 +1284,7 @@ QString SolarSystem::getPlanetHashString(void)
 		{
 			oss << p->getParent()->getEnglishName() << " : ";
 		}
-		oss << p->getEnglishName() << endl;
-		oss << p->getEnglishName() << endl;
+		oss << p->getEnglishName() << endl;		
 	}
 	return str;
 }
@@ -1187,6 +1292,8 @@ QString SolarSystem::getPlanetHashString(void)
 void SolarSystem::setFlagTrails(bool b)
 {
 	trailFader = b;
+	if (getFlagIsolatedTrails())
+		recreateTrails();
 	if (b)
 		allTrails->reset();
 }
@@ -1402,7 +1509,11 @@ void SolarSystem::selectedObjectChange(StelModule::StelModuleSelectAction)
 {
 	const QList<StelObjectP> newSelected = GETSTELMODULE(StelObjectMgr)->getSelectedObject("Planet");
 	if (!newSelected.empty())
+	{
 		setSelected(qSharedPointerCast<Planet>(newSelected[0]));
+		if (getFlagIsolatedTrails())
+			recreateTrails();
+	}
 }
 
 // Activate/Deactivate planets display
@@ -1413,6 +1524,39 @@ void SolarSystem::setFlagPlanets(bool b)
 
 bool SolarSystem::getFlagPlanets(void) const {return flagShow;}
 
+void SolarSystem::setFlagNativeNames(bool b)
+{
+	flagNativeNames=b;
+	foreach (const PlanetP& p, systemPlanets)
+	{
+		if (p->getPlanetType()==Planet::isPlanet || p->getPlanetType()==Planet::isMoon || p->getPlanetType()==Planet::isStar)
+			p->setFlagNativeName(flagNativeNames);
+	}
+	updateI18n();
+}
+
+bool SolarSystem::getFlagNativeNames() const {return flagNativeNames; }
+
+void SolarSystem::setFlagTranslatedNames(bool b)
+{
+	flagTranslatedNames=b;
+	foreach (const PlanetP& p, systemPlanets)
+	{
+		if (p->getPlanetType()==Planet::isPlanet || p->getPlanetType()==Planet::isMoon || p->getPlanetType()==Planet::isStar)
+			p->setFlagTranslatedName(flagTranslatedNames);
+	}
+	updateI18n();
+}
+
+bool SolarSystem::getFlagTranslatedNames() const {return flagTranslatedNames; }
+
+void SolarSystem::setFlagIsolatedTrails(bool b)
+{
+	flagIsolatedTrails = b;
+}
+
+bool SolarSystem::getFlagIsolatedTrails() const { return flagIsolatedTrails; }
+
 // Set/Get planets names color
 void SolarSystem::setLabelsColor(const Vec3f& c) {Planet::setLabelColor(c);}
 const Vec3f& SolarSystem::getLabelsColor(void) const {return Planet::getLabelColor();}
@@ -1469,12 +1613,24 @@ void SolarSystem::reloadPlanets()
 	bool flagHints = getFlagHints();
 	bool flagLabels = getFlagLabels();
 	bool flagOrbits = getFlagOrbits();
-	
+	bool flagNative = getFlagNativeNames();
+	bool flagTrans = getFlagTranslatedNames();
+	bool hasSelection = false;
+
 	// Save observer location (fix for LP bug # 969211)
 	// TODO: This can probably be done better with a better understanding of StelObserver --BM
 	StelCore* core = StelApp::getInstance().getCore();
 	StelLocation loc = core->getCurrentLocation();
+	StelObjectMgr* objMgr = GETSTELMODULE(StelObjectMgr);
 
+	// Whether any planet are selected? Save the current selection...
+	const QList<StelObjectP> selectedObject = objMgr->getSelectedObject("Planet");
+	if (!selectedObject.isEmpty())
+	{
+		// ... unselect current planet.
+		hasSelection = true;
+		objMgr->unSelect();
+	}
 	// Unload all Solar System objects
 	selected.clear();//Release the selected one
 	foreach (Orbit* orb, orbits)
@@ -1516,7 +1672,27 @@ void SolarSystem::reloadPlanets()
 	setFlagHints(flagHints);
 	setFlagLabels(flagLabels);
 	setFlagOrbits(flagOrbits);
+	setFlagNativeNames(flagNative);
+	setFlagTranslatedNames(flagTrans);
+
+	if (hasSelection)
+	{
+		// Restore selection...
+		objMgr->setSelectedObject(selectedObject);
+	}
 
 	// Restore translations
 	updateI18n();
 }
+
+// Set the algorithm for computation of apparent magnitudes for planets in case  observer on the Earth
+void SolarSystem::setApparentMagnitudeAlgorithmOnEarth(QString algorithm)
+{
+	getEarth()->setApparentMagnitudeAlgorithm(algorithm);
+}
+
+// Get the algorithm used for computation of apparent magnitudes for planets in case  observer on the Earth
+QString SolarSystem::getApparentMagnitudeAlgorithmOnEarth() const
+{
+	return getEarth()->getApparentMagnitudeAlgorithmString();
+}
