@@ -42,6 +42,7 @@
 #include "StelLocation.hpp"
 #include "LandscapeMgr.hpp"
 #include "StelSkyCultureMgr.hpp"
+#include "StelSkyLayerMgr.hpp"
 #include "SolarSystem.hpp"
 #include "MeteorMgr.hpp"
 #include "ConstellationMgr.hpp"
@@ -49,6 +50,7 @@
 #include "NebulaMgr.hpp"
 #include "GridLinesMgr.hpp"
 #include "MilkyWay.hpp"
+#include "ZodiacalLight.hpp"
 #ifndef DISABLE_SCRIPTING
 #include "StelScriptMgr.hpp"
 #endif
@@ -64,6 +66,7 @@
 #include <QFileDialog>
 #include <QComboBox>
 #include <QDir>
+#include <QDesktopWidget>
 
 ConfigurationDialog::ConfigurationDialog(StelGui* agui, QObject* parent)
 	: StelDialog(parent)
@@ -104,7 +107,6 @@ void ConfigurationDialog::retranslate()
 
 		//Hack to shrink the tabs to optimal size after language change
 		//by causing the list items to be laid out again.
-		ui->stackListWidget->setWrapping(false);
 		updateTabBarListWidgetWidth();
 		
 		//Initial FOV and direction on the "Main" page
@@ -156,19 +158,26 @@ void ConfigurationDialog::createDialogContent()
 	updateCurrentLanguage();
 	connect(cb->lineEdit(), SIGNAL(editingFinished()), this, SLOT(updateCurrentLanguage()));
 	connect(cb, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(selectLanguage(const QString&)));
-
-	ui->groupBoxUpdates->setChecked(StelApp::getInstance().getSettings()->value("main/check_updates_enabled", true).toBool());
-	connect(ui->groupBoxUpdates, SIGNAL(toggled(bool)), this, SLOT(setUpdatesFlag(bool)));
+	// Do the same for sky language:
+	cb = ui->skycultureLanguageComboBox;
+	cb->clear();
+	cb->addItems(StelTranslator::globalTranslator->getAvailableLanguagesNamesNative(StelFileMgr::getLocaleDir()));
+	cb->model()->sort(0);
+	updateCurrentSkyLanguage();
+	connect(cb->lineEdit(), SIGNAL(editingFinished()), this, SLOT(updateCurrentSkyLanguage()));
+	connect(cb, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(selectSkyLanguage(const QString&)));
 
 	connect(ui->getStarsButton, SIGNAL(clicked()), this, SLOT(downloadStars()));
 	connect(ui->downloadCancelButton, SIGNAL(clicked()), this, SLOT(cancelDownload()));
 	connect(ui->downloadRetryButton, SIGNAL(clicked()), this, SLOT(downloadStars()));
 	resetStarCatalogControls();
 
+#ifdef Q_OS_WIN
 	//Kinetic scrolling for tablet pc and pc
 	QList<QWidget *> addscroll;
 	addscroll << ui->pluginsListWidget << ui->scriptListWidget;
 	installKineticScrolling(addscroll);
+#endif
 
 	// Selected object info
 	if (gui->getInfoTextFilters() == StelObject::InfoStringGroup(0))
@@ -252,7 +261,7 @@ void ConfigurationDialog::createDialogContent()
 	ui->showNebulaBgButtonCheckbox->setChecked(gui->getFlagShowNebulaBackgroundButton());
 	connect(ui->showNebulaBgButtonCheckbox, SIGNAL(toggled(bool)), gui, SLOT(setFlagShowNebulaBackgroundButton(bool)));
 
-	ui->decimalDegreeCheckBox->setChecked(gui->getFlagShowDecimalDegrees());
+	ui->decimalDegreeCheckBox->setChecked(StelApp::getInstance().getFlagShowDecimalDegrees());
 	connect(ui->decimalDegreeCheckBox, SIGNAL(toggled(bool)), gui, SLOT(setFlagShowDecimalDegrees(bool)));
 
 	ui->mouseTimeoutCheckbox->setChecked(StelMainView::getInstance().getFlagCursorTimeout());
@@ -303,11 +312,6 @@ void ConfigurationDialog::createDialogContent()
 	updateTabBarListWidgetWidth();
 }
 
-void ConfigurationDialog::setUpdatesFlag(bool b)
-{
-	StelApp::getInstance().getSettings()->setValue("main/check_updates_enabled", b);
-}
-
 void ConfigurationDialog::updateCurrentLanguage()
 {
 	QComboBox* cb = ui->programLanguageComboBox;
@@ -328,14 +332,42 @@ void ConfigurationDialog::updateCurrentLanguage()
 		cb->setCurrentIndex(lt);
 }
 
+void ConfigurationDialog::updateCurrentSkyLanguage()
+{
+	QComboBox* cb = ui->skycultureLanguageComboBox;
+	QString skyLang = StelApp::getInstance().getLocaleMgr().getSkyLanguage();
+	QString l2 = StelTranslator::iso639_1CodeToNativeName(skyLang);
+
+	if (cb->currentText() == l2)
+		return;
+
+	int lt = cb->findText(l2, Qt::MatchExactly);
+	if (lt == -1 && skyLang.contains('_'))
+	{
+		l2 = skyLang.left(skyLang.indexOf('_'));
+		l2=StelTranslator::iso639_1CodeToNativeName(l2);
+		lt = cb->findText(l2, Qt::MatchExactly);
+	}
+	if (lt!=-1)
+		cb->setCurrentIndex(lt);
+}
+
 void ConfigurationDialog::selectLanguage(const QString& langName)
 {
 	QString code = StelTranslator::nativeNameToIso639_1Code(langName);
 	StelApp::getInstance().getLocaleMgr().setAppLanguage(code);
-	StelApp::getInstance().getLocaleMgr().setSkyLanguage(code);
+//	StelApp::getInstance().getLocaleMgr().setSkyLanguage(code);
 	StelMainView::getInstance().initTitleI18n();
 }
 
+void ConfigurationDialog::selectSkyLanguage(const QString& langName)
+{
+	QString code = StelTranslator::nativeNameToIso639_1Code(langName);
+//	StelApp::getInstance().getLocaleMgr().setAppLanguage(code);
+	StelApp::getInstance().getLocaleMgr().setSkyLanguage(code);
+//	StelMainView::getInstance().initTitleI18n();
+}
+
 void ConfigurationDialog::setStartupTimeMode()
 {
 	if (ui->systemTimeRadio->isChecked())
@@ -526,6 +558,7 @@ void ConfigurationDialog::saveCurrentViewOptions()
 	conf->setValue("viewing/moon_scale", ssmgr->getMoonScale());
 	conf->setValue("astro/meteor_rate", mmgr->getZHR());
 	conf->setValue("astro/milky_way_intensity", GETSTELMODULE(MilkyWay)->getIntensity());
+	conf->setValue("astro/zodiacal_light_intensity", GETSTELMODULE(ZodiacalLight)->getIntensity());
 
 	// view dialog / markings tab settings
 	conf->setValue("viewing/flag_azimuthal_grid", glmgr->getFlagAzimuthalGrid());
@@ -534,6 +567,7 @@ void ConfigurationDialog::saveCurrentViewOptions()
 	conf->setValue("viewing/flag_ecliptic_line", glmgr->getFlagEclipticLine());
 	conf->setValue("viewing/flag_ecliptic_J2000_grid", glmgr->getFlagEclipticJ2000Grid());
 	conf->setValue("viewing/flag_meridian_line", glmgr->getFlagMeridianLine());
+	conf->setValue("viewing/flag_longitude_line", glmgr->getFlagLongitudeLine());
 	conf->setValue("viewing/flag_horizon_line", glmgr->getFlagHorizonLine());
 	conf->setValue("viewing/flag_equatorial_J2000_grid", glmgr->getFlagEquatorJ2000Grid());
 	conf->setValue("viewing/flag_galactic_grid", glmgr->getFlagGalacticGrid());
@@ -546,8 +580,11 @@ void ConfigurationDialog::saveCurrentViewOptions()
 	conf->setValue("viewing/flag_constellation_isolate_selected", cmgr->getFlagIsolateSelected());
 	conf->setValue("viewing/flag_landscape_autoselection", lmgr->getFlagLandscapeAutoSelection());
 	conf->setValue("viewing/flag_light_pollution_database", lmgr->getFlagUseLightPollutionFromDatabase());
-	conf->setValue("viewing/flag_atmopshere_auto_enable", lmgr->getFlagAtmosphereAutoEnable());
+	conf->setValue("viewing/flag_atmosphere_auto_enable", lmgr->getFlagAtmosphereAutoEnable());
+	conf->setValue("viewing/flag_planets_native_names", ssmgr->getFlagNativeNames());
 	conf->setValue("viewing/constellation_art_intensity", cmgr->getArtIntensity());
+	conf->setValue("viewing/constellation_name_style", cmgr->getConstellationDisplayStyleString());
+	conf->setValue("viewing/constellation_line_thickness", cmgr->getConstellationLineThickness());
 	conf->setValue("viewing/flag_night", StelApp::getInstance().getVisionModeNight());
 	conf->setValue("astro/flag_star_name", smgr->getFlagLabels());
 	conf->setValue("stars/labels_amount", smgr->getLabelsAmount());
@@ -555,6 +592,7 @@ void ConfigurationDialog::saveCurrentViewOptions()
 	conf->setValue("astro/labels_amount", ssmgr->getLabelsAmount());
 	conf->setValue("astro/nebula_hints_amount", nmgr->getHintsAmount());
 	conf->setValue("astro/flag_nebula_name", nmgr->getFlagHints());
+	conf->setValue("astro/flag_nebula_display_no_texture", !GETSTELMODULE(StelSkyLayerMgr)->getFlagShow());
 	conf->setValue("projection/type", core->getCurrentProjectionTypeKey());
 
 	// view dialog / landscape tab settings
@@ -564,10 +602,14 @@ void ConfigurationDialog::saveCurrentViewOptions()
 	conf->setValue("landscape/flag_atmosphere", lmgr->getFlagAtmosphere());
 	conf->setValue("landscape/flag_brightness", lmgr->getFlagLandscapeSetsMinimalBrightness());
 	conf->setValue("landscape/flag_fog", lmgr->getFlagFog());
+	conf->setValue("landscape/flag_enable_illumination_layer", lmgr->getFlagIllumination());
 	conf->setValue("stars/init_bortle_scale", core->getSkyDrawer()->getBortleScaleIndex());
         conf->setValue("landscape/atmospheric_extinction_coefficient", core->getSkyDrawer()->getExtinctionCoefficient());
         conf->setValue("landscape/pressure_mbar", core->getSkyDrawer()->getAtmospherePressure());
         conf->setValue("landscape/temperature_C", core->getSkyDrawer()->getAtmosphereTemperature());
+	conf->setValue("landscape/flag_minimal_brightness", lmgr->getFlagLandscapeUseMinimalBrightness());
+	conf->setValue("landscape/flag_landscape_sets_minimal_brightness", lmgr->getFlagLandscapeSetsMinimalBrightness());
+	conf->setValue("landscape/minimal_brightness", lmgr->getDefaultMinimalBrightness());
 
 	// view dialog / starlore tab
 	StelApp::getInstance().getSkyCultureMgr().setDefaultSkyCultureID(StelApp::getInstance().getSkyCultureMgr().getCurrentSkyCultureID());
@@ -600,7 +642,7 @@ void ConfigurationDialog::saveCurrentViewOptions()
 		conf->setValue("flag_show_magnitude",
 		               (bool) (flags & StelObject::Magnitude));
 		conf->setValue("flag_show_absolutemagnitude",
-		               (bool) (flags & StelObject::AbsoluteMagnitude));
+			       (bool) (flags & StelObject::AbsoluteMagnitude));
 		conf->setValue("flag_show_radecj2000",
 		               (bool) (flags & StelObject::RaDecJ2000));
 		conf->setValue("flag_show_radecofdate",
@@ -628,7 +670,7 @@ void ConfigurationDialog::saveCurrentViewOptions()
 	conf->setValue("gui/auto_hide_horizontal_toolbar", gui->getAutoHideHorizontalButtonBar());
 	conf->setValue("gui/auto_hide_vertical_toolbar", gui->getAutoHideVerticalButtonBar());
 	conf->setValue("gui/flag_show_nebulae_background_button", gui->getFlagShowNebulaBackgroundButton());
-	conf->setValue("gui/flag_show_decimal_degrees", gui->getFlagShowDecimalDegrees());
+	conf->setValue("gui/flag_show_decimal_degrees", StelApp::getInstance().getFlagShowDecimalDegrees());
 
 	mvmgr->setInitFov(mvmgr->getCurrentFov());
 	mvmgr->setInitViewDirectionToCurrent();
@@ -660,15 +702,19 @@ void ConfigurationDialog::saveCurrentViewOptions()
 	conf->setValue("main/screenshot_dir", StelFileMgr::getScreenshotDir());
 	conf->setValue("main/invert_screenshots_colors", StelMainView::getInstance().getFlagInvertScreenShotColors());
 
+	int screenNum = qApp->desktop()->screenNumber(&StelMainView::getInstance());
+	conf->setValue("video/screen_number", screenNum);
+
 	// full screen and window size
 	conf->setValue("video/fullscreen", StelMainView::getInstance().isFullScreen());
 	if (!StelMainView::getInstance().isFullScreen())
 	{
+		QRect screenGeom = QApplication::desktop()->screenGeometry(screenNum);
 		QWidget& mainWindow = StelMainView::getInstance();
 		conf->setValue("video/screen_w", mainWindow.size().width());
 		conf->setValue("video/screen_h", mainWindow.size().height());
-		conf->setValue("video/screen_x", mainWindow.x());
-		conf->setValue("video/screen_y", mainWindow.y());
+		conf->setValue("video/screen_x", mainWindow.x() - screenGeom.x());
+		conf->setValue("video/screen_y", mainWindow.y() - screenGeom.y());
 	}
 
 	// clear the restore defaults flag if it is set.
@@ -1125,38 +1171,36 @@ void ConfigurationDialog::updateSelectedInfoCheckBoxes()
 
 void ConfigurationDialog::updateTabBarListWidgetWidth()
 {
-	QAbstractItemModel* model = ui->stackListWidget->model();
-	if (!model)
-		return;
-	
+	ui->stackListWidget->setWrapping(false);
+
 	// Update list item sizes after translation
 	ui->stackListWidget->adjustSize();
-	
+
+	QAbstractItemModel* model = ui->stackListWidget->model();
+	if (!model)
+	{
+		return;
+	}
+
+	// stackListWidget->font() does not work properly!
+	// It has a incorrect fontSize in the first loading, which produces the bug#995107.
+	QFont font;
+	font.setPixelSize(14);
+	font.setWeight(75);
+	QFontMetrics fontMetrics(font);
+
+	int iconSize = ui->stackListWidget->iconSize().width();
+
 	int width = 0;
 	for (int row = 0; row < model->rowCount(); row++)
 	{
-		QModelIndex index = model->index(row, 0);
-		width += ui->stackListWidget->sizeHintForIndex(index).width();
+		int textWidth = fontMetrics.width(ui->stackListWidget->item(row)->text());
+		width += iconSize > textWidth ? iconSize : textWidth; // use the wider one
+		width += 24; // margin - 12px left and 12px right
 	}
-	
-	// TODO: Limit the width to the width of the screen *available to the window*
-	// FIXME: This works only sometimes...
-	/*if (width <= ui->stackListWidget->width())
-	{
-		//qDebug() << width << ui->stackListWidget->width();
-		return;
-	}*/
-	
+
 	// Hack to force the window to be resized...
 	ui->stackListWidget->setMinimumWidth(width);
-	
-	// FIXME: This works only sometimes...
-	/*
-	dialog->adjustSize();
-	dialog->update();
-	// ... and allow manual resize later.
-	ui->stackListWidget->setMinimumWidth(0);
-	*/
 }
 
 void ConfigurationDialog::populateDeltaTAlgorithmsList()
@@ -1205,6 +1249,7 @@ void ConfigurationDialog::populateDeltaTAlgorithmsList()
 	algorithms->addItem(q_("Reijs (2006)"), "Reijs");
 	algorithms->addItem(q_("Banjevic (2006)"), "Banjevic");
 	algorithms->addItem(q_("Islam, Sadiq & Qureshi (2008, 2013)"), "IslamSadiqQureshi");
+	algorithms->addItem(q_("Khalid, Sultana & Zaidi (2014)"), "KhalidSultanaZaidi");
 	algorithms->addItem(q_("Custom equation of %1T").arg(QChar(0x0394)), "Custom");
 
 	//Restore the selection
