@@ -122,16 +122,8 @@ bool DateTimeDialog::valid(int y, int m, int d, int h, int min, int s)
 bool DateTimeDialog::validJd(double jday)
 {
 	pushToWidgets();
-	// local tz -> UTC
-	StelApp::getInstance().getCore()->setJDay(jday-StelApp::getInstance().getLocaleMgr().getGMTShift(jday)/24.+StelApp::getInstance().getCore()->getDeltaT(jday)/86400.);
-	return true;
-}
-
-bool DateTimeDialog::validMjd(double mjday)
-{
-	pushToWidgets();
-	// local tz -> UTC
-	StelApp::getInstance().getCore()->setMJDay(mjday-StelApp::getInstance().getLocaleMgr().getGMTShift(mjday)/24.+StelApp::getInstance().getCore()->getDeltaT(mjday)/86400.);
+	StelCore *core = StelApp::getInstance().getCore();
+	core->setJDay(jday+core->getDeltaT(jday)/86400.);
 	return true;
 }
 
@@ -149,7 +141,7 @@ void DateTimeDialog::styleChanged()
 
 void DateTimeDialog::close()
 {
-	ui->dateTimeBox->setFocus();
+	ui->dateTimeTab->setFocus();
 	StelDialog::close();
 }
 
@@ -210,7 +202,7 @@ void DateTimeDialog::mjdChanged(double nmjd)
 {
 	if ( mjd != nmjd)
 	{
-		validMjd(nmjd);
+		validJd(2400000.5 + nmjd);
 	}
 }
 
@@ -242,14 +234,8 @@ void DateTimeDialog::pushToWidgets()
 	{
 		ui->spinner_second->setValue(second);
 	}
-	if (!ui->spinner_jd->hasFocus())
-	{
-		ui->spinner_jd->setValue(jd);
-	}
-	if (!ui->spinner_mjd->hasFocus())
-	{
-		ui->spinner_mjd->setValue(mjd);
-	}
+	ui->spinner_jd->setValue(jd);
+	ui->spinner_mjd->setValue(mjd);
 	connectSpinnerEvents();
 }
 
@@ -263,11 +249,12 @@ void DateTimeDialog::setDateTime(double newJd)
 		double deltaT = 0.;
 		if (StelApp::getInstance().getCore()->getCurrentLocation().planetName=="Earth")
 			deltaT = StelApp::getInstance().getCore()->getDeltaT(newJd)/86400.;
+		double newJdC = newJd - deltaT;
 		newJd += (StelApp::getInstance().getLocaleMgr().getGMTShift(newJd)/24.0-deltaT); // UTC -> local tz
 		StelUtils::getDateFromJulianDay(newJd, &year, &month, &day);
 		StelUtils::getTimeFromJulianDay(newJd, &hour, &minute, &second);
-		jd = newJd;
-		mjd = newJd-2400000.5;
+		jd = newJdC;
+		mjd = newJdC-2400000.5;
 		pushToWidgets();
 	}
 }
