@@ -31,10 +31,6 @@
 #include <QSettings>
 #include <QTextDocument>
 
-#ifdef _MSC_BUILD
-#define round(dbl) dbl >= 0.0 ? (int)(dbl + 0.5) : ((dbl - (double)(int)dbl) <= -0.5 ? (int)dbl : (int)(dbl - 0.5))
-#endif
-
 InfoPanel::InfoPanel(QGraphicsItem* parent) : QGraphicsTextItem("", parent)
 {
 	QSettings* conf = StelApp::getInstance().getSettings();
@@ -125,8 +121,11 @@ SkyGui::SkyGui(QGraphicsItem * parent)
 	// Construct the Windows buttons bar
 	winBar = new LeftStelBar(this);
 	// Construct the bottom buttons bar
-	buttonBar = new BottomStelBar(this, QPixmap(":/graphicGui/btbg-left.png"), QPixmap(":/graphicGui/btbg-right.png"),
-																QPixmap(":/graphicGui/btbg-middle.png"), QPixmap(":/graphicGui/btbg-single.png"));
+	buttonBar = new BottomStelBar(this,
+				      QPixmap(":/graphicGui/btbg-left.png"),
+				      QPixmap(":/graphicGui/btbg-right.png"),
+				      QPixmap(":/graphicGui/btbg-middle.png"),
+				      QPixmap(":/graphicGui/btbg-single.png"));
 	infoPanel = new InfoPanel(this);
 
 	// Used to display some progress bar in the lower right corner, e.g. when loading a file
@@ -196,7 +195,7 @@ void SkyGui::init(StelGui* astelGui)
 	buttonBarPath->setZValue(-0.1);
 	updateBarsPos();
 	connect(&StelApp::getInstance(), SIGNAL(colorSchemeChanged(const QString&)), this, SLOT(setStelStyle(const QString&)));
-	connect(buttonBar, SIGNAL(sizeChanged()), this, SLOT(updateBarsPos()));
+	connect(buttonBar, SIGNAL(sizeChanged()), this, SLOT(updateBarsPos()));		
 }
 
 void SkyGui::resizeEvent(QGraphicsSceneResizeEvent* event)
@@ -207,7 +206,7 @@ void SkyGui::resizeEvent(QGraphicsSceneResizeEvent* event)
 
 void SkyGui::hoverMoveEvent(QGraphicsSceneHoverEvent* event)
 {
-	const int hh = geometry().height();
+	const int hh = getSkyGuiHeight();
 
 	double x = event->pos().x();
 	double y = event->pos().y();
@@ -263,7 +262,7 @@ void SkyGui::updateBarsPos()
 	const qreal newWinBarY = hh-winBar->boundingRectNoHelpLabel().height()-buttonBar->boundingRectNoHelpLabel().height()-20;
 	if (winBar->pos().x()!=newWinBarX || winBar->pos().y()!=newWinBarY)
 	{
-		winBar->setPos(round(newWinBarX), round(newWinBarY));
+		winBar->setPos(qRound(newWinBarX), qRound(newWinBarY));
 		updatePath = true;
 	}
 
@@ -272,7 +271,7 @@ void SkyGui::updateBarsPos()
 	const qreal newButtonBarY = hh-buttonBar->boundingRectNoHelpLabel().height()-buttonBarPath->getRoundSize()+0.5+(1.-animBottomBarTimeLine->currentValue())*rangeY;
 	if (buttonBar->pos().x()!=newButtonBarX || buttonBar->pos().y()!=newButtonBarY)
 	{
-		buttonBar->setPos(round(newButtonBarX), round(newButtonBarY));
+		buttonBar->setPos(qRound(newButtonBarX), qRound(newButtonBarY));
 		updatePath = true;
 	}
 
