@@ -74,14 +74,6 @@
 #include <QColor>
 #include <QAction>
 
-StelGuiBase* StelStandardGuiPluginInterface::getStelGuiBase() const
-{
-	// Allow to load the resources when used as a static plugin
-	Q_INIT_RESOURCE(guiRes);
-
-	return new StelGui();
-}
-
 StelGui::StelGui()
 	: topLevelGraphicsWidget(NULL)
 	, skyGui(NULL)
@@ -106,7 +98,6 @@ StelGui::StelGui()
 	, flagShowNebulaBackgroundButton(false)
 	, btShowNebulaeBackground(NULL)
 	, initDone(false)
-	, flagShowDecimalDegrees(false)
 {
 	// QPixmapCache::setCacheLimit(30000); ?
 }
@@ -184,7 +175,7 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 	QString datetimeGroup = N_("Date and Time");
 	QString windowsGroup = N_("Windows");
 	QString miscGroup = N_("Miscellaneous");
-	actionsMgr->addAction("actionQuit_Global", miscGroup, N_("Quit"), this, "quit()", "Ctrl+Q");
+	actionsMgr->addAction("actionQuit_Global", miscGroup, N_("Quit"), this, "quit()", "Ctrl+Q", "Ctrl+X");
 	actionsMgr->addAction("actionIncrease_Script_Speed", datetimeGroup, N_("Speed up the script execution rate"), this, "increaseScriptSpeed()");
 	actionsMgr->addAction("actionDecrease_Script_Speed", datetimeGroup, N_("Slow down the script execution rate"), this, "decreaseScriptSpeed()");
 	actionsMgr->addAction("actionSet_Real_Script_Speed", datetimeGroup, N_("Set the normal script execution rate"), this, "setRealScriptSpeed()");
@@ -203,8 +194,7 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 	actionsMgr->addAction("actionShow_DateTime_Window_Global", windowsGroup, N_("Date/time window"), dateTimeDialog, "visible", "F5", "", true);
 	actionsMgr->addAction("actionShow_Location_Window_Global", windowsGroup, N_("Location window"), locationDialog, "visible", "F6", "", true);
 	actionsMgr->addAction("actionShow_Shortcuts_Window_Global", windowsGroup, N_("Shortcuts window"), shortcutsDialog, "visible", "F7", "", true);
-	actionsMgr->addAction("actionSave_Copy_Object_Information_Global", miscGroup, N_("Copy selected object information to clipboard"), this, "copySelectedObjectInfo()", "Ctrl+C", "", true);
-	actionsMgr->addAction("actionToggle_GuiHidden_Global", miscGroup, N_("Toggle visibility of GUI"), this, "visible", "Ctrl+T", "", true);
+	actionsMgr->addAction("actionSave_Copy_Object_Information_Global", miscGroup, N_("Copy selected object information to clipboard"), this, "copySelectedObjectInfo()", "Ctrl+C", "", true);	
 
 	QSettings* conf = StelApp::getInstance().getSettings();
 	Q_ASSERT(conf);
@@ -213,6 +203,9 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 	actionsMgr->addAction("actionAutoHideHorizontalButtonBar", miscGroup, N_("Auto hide horizontal button bar"), this, "autoHideHorizontalButtonBar");
 	actionsMgr->addAction("actionAutoHideVerticalButtonBar", miscGroup, N_("Auto hide vertical button bar"), this, "autoHideVerticalButtonBar");
 
+	setGuiVisible(conf->value("gui/flag_show_gui", true).toBool());
+	actionsMgr->addAction("actionToggle_GuiHidden_Global", miscGroup, N_("Toggle visibility of GUI"), this, "visible", "Ctrl+T", "", true);
+
 #ifndef DISABLE_SCRIPTING
 	StelScriptMgr* scriptMgr = &StelApp::getInstance().getScriptMgr();
 	connect(scriptMgr, SIGNAL(scriptRunning()), this, SLOT(scriptStarted()));
@@ -357,9 +350,7 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 
 	// add the flip buttons if requested in the config
 	setFlagShowFlipButtons(conf->value("gui/flag_show_flip_buttons", false).toBool());
-	setFlagShowNebulaBackgroundButton(conf->value("gui/flag_show_nebulae_background_button", false).toBool());
-
-	setFlagShowDecimalDegrees(conf->value("gui/flag_show_decimal_degrees", false).toBool());
+	setFlagShowNebulaBackgroundButton(conf->value("gui/flag_show_nebulae_background_button", false).toBool());	
 
 	///////////////////////////////////////////////////////////////////////
 	// Create the main base widget
@@ -529,7 +520,7 @@ void StelGui::update()
 	if (savedProgressBarSize!=skyGui->progressBarMgr->boundingRect().size())
 	{
 		savedProgressBarSize=skyGui->progressBarMgr->boundingRect().size();
-		skyGui->updateBarsPos();
+		forceRefreshGui();
 	}
 
 	dateTimeDialog->setDateTime(core->getJDay());
@@ -595,19 +586,15 @@ void StelGui::setFlagShowFlipButtons(bool b)
 		if (flipVert==NULL) {
 			// Create the vertical flip button
 			QPixmap pxmapGlow32x32(":/graphicGui/glow32x32.png");
-			flipVert = new StelButton(NULL,
-																QPixmap(":/graphicGui/btFlipVertical-on.png"),
-																QPixmap(":/graphicGui/btFlipVertical-off.png"),
-																pxmapGlow32x32,
-																"actionVertical_Flip");
+			QPixmap pxmapOn(":/graphicGui/btFlipVertical-on.png");
+			QPixmap pxmapOff(":/graphicGui/btFlipVertical-off.png");
+			flipVert = new StelButton(NULL, pxmapOn, pxmapOff, pxmapGlow32x32, "actionVertical_Flip");
 		}
 		if (flipHoriz==NULL) {
 			QPixmap pxmapGlow32x32(":/graphicGui/glow32x32.png");
-			flipHoriz = new StelButton(NULL,
-																 QPixmap(":/graphicGui/btFlipHorizontal-on.png"),
-																 QPixmap(":/graphicGui/btFlipHorizontal-off.png"),
-																 pxmapGlow32x32,
-																 "actionHorizontal_Flip");
+			QPixmap pxmapOn(":/graphicGui/btFlipHorizontal-on.png");
+			QPixmap pxmapOff(":/graphicGui/btFlipHorizontal-off.png");
+			flipHoriz = new StelButton(NULL, pxmapOn, pxmapOff, pxmapGlow32x32, "actionHorizontal_Flip");
 		}
 		getButtonBar()->addButton(flipVert, "060-othersGroup", "actionQuit_Global");
 		getButtonBar()->addButton(flipHoriz, "060-othersGroup", "actionVertical_Flip");
@@ -629,7 +616,9 @@ void StelGui::setFlagShowNebulaBackgroundButton(bool b)
 		if (btShowNebulaeBackground==NULL) {
 			// Create the nebulae background button
 			QPixmap pxmapGlow32x32(":/graphicGui/glow32x32.png");
-			btShowNebulaeBackground = new StelButton(NULL, QPixmap(":/graphicGui/btDSS-on.png"), QPixmap(":/graphicGui/btDSS-off.png"), pxmapGlow32x32, "actionShow_DSS");
+			QPixmap pxmapOn(":/graphicGui/btDSS-on.png");
+			QPixmap pxmapOff(":/graphicGui/btDSS-off.png");
+			btShowNebulaeBackground = new StelButton(NULL, pxmapOn, pxmapOff, pxmapGlow32x32, "actionShow_DSS");
 		}
 		getButtonBar()->addButton(btShowNebulaeBackground, "040-nebulaeGroup");
 	} else {
@@ -640,12 +629,17 @@ void StelGui::setFlagShowNebulaBackgroundButton(bool b)
 
 void StelGui::setFlagShowDecimalDegrees(bool b)
 {
-	flagShowDecimalDegrees=b;
+	StelApp::getInstance().setFlagShowDecimalDegrees(b);
+	if (searchDialog->visible())
+	{
+		// Update format of input fields if Search Dialog is open
+		searchDialog->populateCoordinateAxis();
+	}
 }
 
 void StelGui::setVisible(bool b)
 {
-	skyGui->setVisible(b);
+	skyGui->setVisible(b);	
 }
 
 bool StelGui::getVisible() const
@@ -721,11 +715,6 @@ bool StelGui::getFlagShowNebulaBackgroundButton() const
 	return flagShowNebulaBackgroundButton;
 }
 
-bool StelGui::getFlagShowDecimalDegrees() const
-{
-	return flagShowDecimalDegrees;
-}
-
 bool StelGui::initComplete(void) const
 {
 	return initDone;
