@@ -48,10 +48,6 @@
 #include <QGraphicsLinearLayout>
 #include <QSettings>
 
-#ifdef _MSC_BUILD
-#define round(dbl) dbl >= 0.0 ? (int)(dbl + 0.5) : ((dbl - (double)(int)dbl) <= -0.5 ? (int)dbl : (int)(dbl - 0.5))
-#endif
-
 void StelButton::initCtor(const QPixmap& apixOn,
                           const QPixmap& apixOff,
                           const QPixmap& apixNoChange,
@@ -245,7 +241,7 @@ void LeftStelBar::addButton(StelButton* button)
 	}
 	button->setParentItem(this);
 	button->prepareGeometryChange(); // could possibly be removed when qt 4.6 become stable
-	button->setPos(0., round(posY+10.5));
+    button->setPos(0., qRound(posY+10.5));
 
 	connect(button, SIGNAL(hoverChanged(bool)), this, SLOT(buttonHoverChanged(bool)));
 }
@@ -294,7 +290,7 @@ void LeftStelBar::buttonHoverChanged(bool b)
 				tip += "  [" + shortcut + "]";
 			}
 			helpLabel->setText(tip);
-			helpLabel->setPos(round(boundingRectNoHelpLabel().width()+15.5),round(button->pos().y()+button->pixmap().size().height()/2-8));
+            helpLabel->setPos(qRound(boundingRectNoHelpLabel().width()+15.5),qRound(button->pos().y()+button->pixmap().size().height()/2-8));
 		}
 	}
 	else
@@ -349,6 +345,7 @@ BottomStelBar::BottomStelBar(QGraphicsItem* parent,
 	setFlagShowFps(confSettings->value("gui/flag_show_fps", true).toBool());
 	setFlagTimeJd(confSettings->value("gui/flag_time_jd", false).toBool());
 	setFlagFovDms(confSettings->value("gui/flag_fov_dms", false).toBool());
+	setFlagShowTz(confSettings->value("gui/flag_show_tz", true).toBool());
 }
 
 BottomStelBar::~BottomStelBar()
@@ -546,7 +543,7 @@ void BottomStelBar::updateText(bool updatePos)
 	double jd = core->getJDay();
 	double deltaT = 0.;
 	double sigma = -1.;
-	QString sigmaInfo = "";
+	QString sigmaInfo = "";	
 	QString validRangeInfo = "";
 	bool displayDeltaT = false;
 	if (core->getCurrentLocation().planetName.contains("Earth"))
@@ -557,41 +554,55 @@ void BottomStelBar::updateText(bool updatePos)
 		core->getCurrentDeltaTAlgorithmValidRange(jd, &validRangeInfo);
 	}
 
-	// Add in a DeltaT correction. Divide DeltaT by 86400 to convert from seconds to days.
-	QString newDate = getFlagShowTime() ? StelApp::getInstance().getLocaleMgr().getPrintableDateLocal(jd-deltaT/86400.) +"   "
-			+StelApp::getInstance().getLocaleMgr().getPrintableTimeLocal(jd-deltaT/86400.) : " ";
+	const StelLocaleMgr& locmgr = StelApp::getInstance().getLocaleMgr();
+	double dt = deltaT/86400.; // A DeltaT correction. Divide DeltaT by 86400 to convert from seconds to days.
+	QString tz = locmgr.getPrintableTimeZoneLocal(jd-dt);
+	QString newDateInfo = " ";
+	if (getFlagShowTime())
+	{
+		if (getFlagShowTz())
+			newDateInfo = QString("%1   %2 %3").arg(locmgr.getPrintableDateLocal(jd-dt)).arg(locmgr.getPrintableTimeLocal(jd-dt)).arg(tz);
+		else
+			newDateInfo = QString("%1   %2").arg(locmgr.getPrintableDateLocal(jd-dt)).arg(locmgr.getPrintableTimeLocal(jd-dt));
+	}
+	QString newDateAppx = QString("JD %1").arg(jd-dt, 0, 'f', 5);
 	if (getFlagTimeJd())
 	{
-		newDate = QString("%1").arg(jd+StelApp::getInstance().getLocaleMgr().getGMTShift(jd)/24.-deltaT/86400., 0, 'f', 5); // UTC -> local tz
+		newDateAppx = newDateInfo;
+		newDateInfo = QString("JD %1").arg(jd-dt, 0, 'f', 5);
 	}
 
-	if (datetime->text()!=newDate)
+	if (datetime->text()!=newDateInfo)
 	{
 		updatePos = true;		
-		datetime->setText(newDate);
+		datetime->setText(newDateInfo);
 		if (displayDeltaT && core->getCurrentDeltaTAlgorithm()!=StelCore::WithoutCorrection)
 		{
 			if (sigma>0)
 				sigmaInfo = QString("; %1(%2T) = %3s").arg(QChar(0x03c3)).arg(QChar(0x0394)).arg(sigma, 3, 'f', 1);
 
-			if (std::abs(deltaT)>60.)
-				datetime->setToolTip(QString("%1T = %2 (%3s)%6 [n-dot @ -23.8946\"/cy%4%5]").arg(QChar(0x0394)).arg(StelUtils::hoursToHmsStr(deltaT/3600.)).arg(deltaT, 5, 'f', 2).arg(QChar(0x00B2)).arg(sigmaInfo).arg(validRangeInfo));
+			QString deltaTInfo = "";
+			if (qAbs(deltaT)>60.)
+				deltaTInfo = QString("%1 (%2s)%3").arg(StelUtils::hoursToHmsStr(deltaT/3600.)).arg(deltaT, 5, 'f', 2).arg(validRangeInfo);
 			else
-				datetime->setToolTip(QString("%1T = %2s%5 [n-dot @ -23.8946\"/cy%3%4]").arg(QChar(0x0394)).arg(deltaT, 3, 'f', 3).arg(QChar(0x00B2)).arg(sigmaInfo).arg(validRangeInfo));
+				deltaTInfo = QString("%1s%2").arg(deltaT, 3, 'f', 3).arg(validRangeInfo);
+
+			datetime->setToolTip(QString("<p style='white-space:pre'>%1T = %2 [n-dot @ -23.8946\"/cy%3%4]<br>%5</p>").arg(QChar(0x0394)).arg(deltaTInfo).arg(QChar(0x00B2)).arg(sigmaInfo).arg(newDateAppx));
 		}
 		else
-			datetime->setToolTip("");
+			datetime->setToolTip(QString("%1").arg(newDateAppx));
 	}
 
 	QString newLocation = "";
 	const StelLocation* loc = &core->getCurrentLocation();
+	const StelTranslator& trans = locmgr.getSkyTranslator();
 	if (getFlagShowLocation() && !loc->name.isEmpty())
 	{
-		newLocation = q_(loc->planetName) +", "+loc->name + ", "+q_("%1m").arg(loc->altitude);
+		newLocation = trans.qtranslate(loc->planetName) +", "+loc->name + ", "+q_("%1m").arg(loc->altitude);
 	}
 	if (getFlagShowLocation() && loc->name.isEmpty())
 	{
-		newLocation = q_(loc->planetName)+", "+StelUtils::decDegToDmsStr(loc->latitude)+", "+StelUtils::decDegToDmsStr(loc->longitude);
+		newLocation = trans.qtranslate(loc->planetName)+", "+StelUtils::decDegToDmsStr(loc->latitude)+", "+StelUtils::decDegToDmsStr(loc->longitude);
 	}
 	if (location->text()!=newLocation)
 	{
