@@ -60,6 +60,7 @@ private slots:
 	void starsLabelsValueChanged(int);
 	void setCurrentLandscapeAsDefault(void);
 	void setCurrentCultureAsDefault(void);
+	void setFlagLandscapeUseMinimalBrightness(bool b);
 	//! Update the widget to make sure it is synchrone if a value was changed programmatically
 	//! This function should be called repeatidly with e.g. a timer
 	void updateFromProgram();
@@ -68,7 +69,9 @@ private slots:
         void showAtmosphereDialog();
 
 	void populateLightPollution();
+	void populateLandscapeMinimalBrightness();
 
+	// WHAT IS THE SKY LAYER? hidden, under development?
 	void populateSkyLayersList();
 	void skyLayersSelectionChanged(const QString&);
 	void skyLayersEnabledChanged(int);
@@ -79,9 +82,12 @@ private:
 	void connectCheckBox(class QCheckBox* checkBox, const QString& actionId);
 	void connectGroupBox(class QGroupBox* groupBox, const QString& actionId);
 	void updateSkyCultureText();
+	//! Make sure that no tabs icons are outside of the viewport.
+	//! @todo Limit the width to the width of the screen *available to the window*.
+	void updateTabBarListWidgetWidth();
 
 	AddRemoveLandscapesDialog * addRemoveLandscapesDialog;
-        AtmosphereDialog * atmosphereDialog;
+	AtmosphereDialog * atmosphereDialog;
 };
 
 #endif // _VIEWDIALOG_HPP_
