@@ -51,6 +51,7 @@
 #include "StelUtils.hpp"
 #include "StelGuiBase.hpp"
 #include "MilkyWay.hpp"
+#include "ZodiacalLight.hpp"
 
 #include <QDateTime>
 #include <QDebug>
@@ -132,18 +133,28 @@ double StelMainScriptAPI::getMJDay() const
 
 void StelMainScriptAPI::setDate(const QString& dt, const QString& spec, const bool &enableDeltaT)
 {
+	bool relativeTime = false;
+	if (dt.startsWith("+") || dt.startsWith("-") || (dt.startsWith("now") && (dt.startsWith("+") || dt.startsWith("-"))))
+		relativeTime = true;
 	double JD = jdFromDateString(dt, spec);
 	StelCore* core = StelApp::getInstance().getCore();
-	if (enableDeltaT)
+	if (relativeTime)
 	{
-		// add Delta-T correction for date
-		core->setJDay(JD + core->getDeltaT(JD)/86400);
+		core->setJDay(JD);
 	}
 	else
 	{
-		// set date without Delta-T correction
-		// compatible with 0.11
-		core->setJDay(JD);
+		if (enableDeltaT)
+		{
+			// add Delta-T correction for date
+			core->setJDay(JD + core->getDeltaT(JD)/86400);
+		}
+		else
+		{
+			// set date without Delta-T correction
+			// compatible with 0.11
+			core->setJDay(JD);
+		}
 	}
 }
 
@@ -210,7 +221,7 @@ void StelMainScriptAPI::setObserverLocation(double longitude, double latitude, d
 	if (ssmgr->searchByName(planet))
 		loc.planetName = planet;
 	loc.name = name;
-	core->moveObserverTo(loc, duration);
+	core->moveObserverTo(loc, duration, duration);
 }
 
 void StelMainScriptAPI::setObserverLocation(const QString id, float duration)
@@ -242,6 +253,11 @@ QVariantMap StelMainScriptAPI::getObserverLocationInfo()
 	map.insert("sidereal-year", planet->getSiderealPeriod());
 	map.insert("sidereal-day", planet->getSiderealDay()*24.);
 	map.insert("solar-day", planet->getMeanSolarDay()*24.);
+	unsigned int h, m;
+	double s;
+	StelUtils::radToHms(core->getLocalSiderealTime(), h, m, s);
+	map.insert("local-sidereal-time", (double)h + (double)m/60 + s/3600);
+	map.insert("local-sidereal-time-hms", StelUtils::radToHmsStr(core->getLocalSiderealTime()));
 
 	return map;
 }
@@ -355,6 +371,21 @@ bool StelMainScriptAPI::getDiskViewport()
 	return StelApp::getInstance().getCore()->getProjection(StelCore::FrameJ2000)->getMaskType() == StelProjector::MaskDisk;
 }
 
+void StelMainScriptAPI::setSphericMirror(bool b)
+{
+	StelCore* core = StelApp::getInstance().getCore();
+	if (b)
+	{
+		core->setCurrentProjectionType(StelCore::ProjectionFisheye);
+		StelApp::getInstance().setViewportEffect("sphericMirrorDistorter");
+	}
+	else
+	{
+		core->setCurrentProjectionTypeKey(core->getDefaultProjectionTypeKey());
+		StelApp::getInstance().setViewportEffect("none");
+	}
+}
+
 void StelMainScriptAPI::setDiskViewport(bool b)
 {
 	emit(requestSetDiskViewport(b));
@@ -784,7 +815,33 @@ QVariantMap StelMainScriptAPI::getObjectInfo(const QString& name)
 	map.insert("vmage", obj->getVMagnitudeWithExtinction(core));
 
 	// angular size
-	map.insert("size", obj->getAngularSize(core));
+	double angularSize = 2.*obj->getAngularSize(core)*M_PI/180.;
+	bool sign;
+	double deg;
+	StelUtils::radToDecDeg(angularSize, sign, deg);
+	if (!sign)
+		deg *= -1;
+	map.insert("size", angularSize);
+	map.insert("size-dd", deg);
+	map.insert("size-deg", StelUtils::radToDecDegStr(angularSize, 5));
+	map.insert("size-dms", StelUtils::radToDmsStr(angularSize, true));
+
+	if (obj->getType().toLower()=="planet" && name!="Sun")
+	{
+		SolarSystem* ssmgr = GETSTELMODULE(SolarSystem);
+		map.insert("distance", obj->getJ2000EquatorialPos(core).length());
+		double phase = ssmgr->getPhaseForPlanet(name);
+		map.insert("phase", phase);
+		map.insert("illumination", 100.*phase);
+		double phaseAngle = ssmgr->getPhaseAngleForPlanet(name);
+		map.insert("phase-angle", phaseAngle);
+		map.insert("phase-angle-dms", StelUtils::radToDmsStr(phaseAngle));
+		map.insert("phase-angle-deg", StelUtils::radToDecDegStr(phaseAngle));
+		double elongation = ssmgr->getElongationForPlanet(name);
+		map.insert("elongation", elongation);
+		map.insert("elongation-dms", StelUtils::radToDmsStr(elongation));
+		map.insert("elongation-deg", StelUtils::radToDecDegStr(elongation));
+	}
 
 	// localized name
 	map.insert("localized-name", obj->getNameI18n());
@@ -864,7 +921,33 @@ QVariantMap StelMainScriptAPI::getSelectedObjectInfo()
 	map.insert("vmage", obj->getVMagnitudeWithExtinction(core));
 
 	// angular size
-	map.insert("size", obj->getAngularSize(core));
+	double angularSize = 2.*obj->getAngularSize(core)*M_PI/180.;
+	bool sign;
+	double deg;
+	StelUtils::radToDecDeg(angularSize, sign, deg);
+	if (!sign)
+		deg *= -1;
+	map.insert("size", angularSize);
+	map.insert("size-dd", deg);
+	map.insert("size-deg", StelUtils::radToDecDegStr(angularSize, 5));
+	map.insert("size-dms", StelUtils::radToDmsStr(angularSize, true));
+
+	if (obj->getType().toLower()=="planet" && obj->getEnglishName()!="Sun")
+	{
+		SolarSystem* ssmgr = GETSTELMODULE(SolarSystem);
+		map.insert("distance", obj->getJ2000EquatorialPos(core).length());
+		double phase = ssmgr->getPhaseForPlanet(obj->getEnglishName());
+		map.insert("phase", phase);
+		map.insert("illumination", 100.*phase);
+		double phaseAngle = ssmgr->getPhaseAngleForPlanet(obj->getEnglishName());
+		map.insert("phase-angle", phaseAngle);
+		map.insert("phase-angle-dms", StelUtils::radToDmsStr(phaseAngle));
+		map.insert("phase-angle-deg", StelUtils::radToDecDegStr(phaseAngle));
+		double elongation = ssmgr->getElongationForPlanet(obj->getEnglishName());
+		map.insert("elongation", elongation);
+		map.insert("elongation-dms", StelUtils::radToDmsStr(elongation));
+		map.insert("elongation-deg", StelUtils::radToDecDegStr(elongation));
+	}
 
 	// english name or designation & localized name
 	map.insert("name", obj->getEnglishName());
@@ -885,6 +968,7 @@ void StelMainScriptAPI::clear(const QString& state)
 	NebulaMgr* nmgr = GETSTELMODULE(NebulaMgr);
 	GridLinesMgr* glmgr = GETSTELMODULE(GridLinesMgr);
 	StelMovementMgr* movmgr = GETSTELMODULE(StelMovementMgr);
+	ZodiacalLight* zl = GETSTELMODULE(ZodiacalLight);
 
 	if (state.toLower() == "natural")
 	{
@@ -903,6 +987,7 @@ void StelMainScriptAPI::clear(const QString& state)
 		glmgr->setFlagEquatorLine(false);
 		glmgr->setFlagEclipticLine(false);
 		glmgr->setFlagMeridianLine(false);
+		glmgr->setFlagLongitudeLine(false);
 		glmgr->setFlagHorizonLine(false);
 		glmgr->setFlagGalacticEquatorLine(false);
 		glmgr->setFlagEquatorJ2000Grid(false);
@@ -917,12 +1002,13 @@ void StelMainScriptAPI::clear(const QString& state)
 		lmgr->setFlagLandscape(true);
 		lmgr->setFlagAtmosphere(true);
 		lmgr->setFlagFog(true);
+		zl->setFlagShow(true);
 	}
 	else if (state.toLower() == "starchart")
 	{
 		movmgr->setMountMode(StelMovementMgr::MountEquinoxEquatorial);
 		skyd->setFlagTwinkle(false);
-		skyd->setFlagLuminanceAdaptation(false);
+		skyd->setFlagLuminanceAdaptation(false);		
 		ssmgr->setFlagPlanets(true);
 		ssmgr->setFlagHints(false);
 		ssmgr->setFlagOrbits(false);
@@ -935,6 +1021,7 @@ void StelMainScriptAPI::clear(const QString& state)
 		glmgr->setFlagEquatorLine(false);
 		glmgr->setFlagEclipticLine(false);
 		glmgr->setFlagMeridianLine(false);
+		glmgr->setFlagLongitudeLine(false);
 		glmgr->setFlagHorizonLine(false);
 		glmgr->setFlagGalacticEquatorLine(false);
 		glmgr->setFlagEquatorJ2000Grid(false);
@@ -945,10 +1032,11 @@ void StelMainScriptAPI::clear(const QString& state)
 		cmgr->setFlagArt(false);
 		smgr->setFlagLabels(true);
 		ssmgr->setFlagLabels(true);
-		nmgr->setFlagHints(true);
+		nmgr->setFlagHints(true);		
 		lmgr->setFlagLandscape(false);
 		lmgr->setFlagAtmosphere(false);
 		lmgr->setFlagFog(false);
+		zl->setFlagShow(false);
 	}
 	else if (state.toLower() == "deepspace")
 	{
@@ -967,6 +1055,7 @@ void StelMainScriptAPI::clear(const QString& state)
 		glmgr->setFlagEquatorLine(false);
 		glmgr->setFlagEclipticLine(false);
 		glmgr->setFlagMeridianLine(false);
+		glmgr->setFlagLongitudeLine(false);
 		glmgr->setFlagHorizonLine(false);
 		glmgr->setFlagGalacticEquatorLine(false);
 		glmgr->setFlagEquatorJ2000Grid(false);
@@ -981,6 +1070,7 @@ void StelMainScriptAPI::clear(const QString& state)
 		lmgr->setFlagLandscape(false);
 		lmgr->setFlagAtmosphere(false);
 		lmgr->setFlagFog(false);
+		zl->setFlagShow(false);
 	}
 	else
 	{
@@ -1078,13 +1168,12 @@ void StelMainScriptAPI::moveToRaDecJ2000(const QString& ra, const QString& dec,
 
 	GETSTELMODULE(StelObjectMgr)->unSelect();
 
-	Vec3d aimJ2000, aimEquofDate;
+	Vec3d aimJ2000;
 	double dRa = StelUtils::getDecAngle(ra);
 	double dDec = StelUtils::getDecAngle(dec);
 
-	StelUtils::spheToRect(dRa,dDec,aimJ2000);
-	aimEquofDate = StelApp::getInstance().getCore()->j2000ToEquinoxEqu(aimJ2000);
-	mvmgr->moveToJ2000(aimEquofDate, duration);
+	StelUtils::spheToRect(dRa,dDec,aimJ2000);	
+	mvmgr->moveToJ2000(aimJ2000, duration);
 }
 
 QString StelMainScriptAPI::getAppLanguage()
@@ -1126,3 +1215,18 @@ double StelMainScriptAPI::getMilkyWayIntensity()
 {
 	return GETSTELMODULE(MilkyWay)->getIntensity();
 }
+
+void StelMainScriptAPI::setZodiacalLightVisible(bool b)
+{
+	GETSTELMODULE(ZodiacalLight)->setFlagShow(b);
+}
+
+void StelMainScriptAPI::setZodiacalLightIntensity(double i)
+{
+	GETSTELMODULE(ZodiacalLight)->setIntensity(i);
+}
+
+double StelMainScriptAPI::getZodiacalLightIntensity()
+{
+	return GETSTELMODULE(ZodiacalLight)->getIntensity();
+}
