@@ -103,15 +103,7 @@ StelScriptMgr::StelScriptMgr(QObject *parent): QObject(parent)
 					"do {curDate = new Date();}"
 					"    while(curDate-date < sleepDurationSec*1000/scriptRateReadOnly);}");
 	engine.evaluate("core['wait'] = mywait__;");
-	
-	//! Waits until a specified simulation date/time.  This function
-	//! will take into account the rate (and direction) in which simulation
-	//! time is passing. e.g. if a future date is specified and the
-	//! time is moving backwards, the function will return immediately.
-	//! If the time rate is 0, the function will not wait.  This is to
-	//! prevent infinite wait time.
-	//! @param dt the date string to use
-	//! @param spec "local" or "utc"
+
 	engine.evaluate("function mywaitFor__(dt, spec) {if (!spec) spec=\"utc\";"
 	"	var JD = core.jdFromDateString(dt, spec);"
 	"	var timeSpeed = core.getTimeRate();"
@@ -175,11 +167,7 @@ QStringList StelScriptMgr::getScriptList()
 	QStringList scriptFiles;
 
 	QSet<QString> files = StelFileMgr::listContents("scripts", StelFileMgr::File, true);
-#ifdef ENABLE_STRATOSCRIPT_COMPAT
-	QRegExp fileRE("^.*\\.(ssc|sts)$");
-#else // ENABLE_STRATOSCRIPT_COMPAT
 	QRegExp fileRE("^.*\\.ssc$");
-#endif // ENABLE_STRATOSCRIPT_COMPAT
 	foreach(const QString& f, files)
 	{
 		if (fileRE.exactMatch(f))
@@ -355,10 +343,6 @@ bool StelScriptMgr::runScript(const QString& fileName, const QString& includePat
 	bool ok = false;
 	if (fileName.endsWith(".ssc"))
 		ok = preprocessScript(fic, preprocessedScript, scriptDir);
-#ifdef ENABLE_STRATOSCRIPT_COMPAT
-	else if (fileName.endsWith(".sts"))
-		ok = preprocessStratoScript(fic, preprocessedScript, scriptDir);
-#endif
 	if (!ok)
 	{
 		return false;
