@@ -19,6 +19,7 @@
 
 // This file contains translations for all translatable strings stored within data files
 // It is not meant to be compiled but just parsed by gettext
+// names of celestial objects for screen display (Sky language) have been taken to translations_skycultures.h
 
 class Translations
 {
@@ -28,143 +29,7 @@ class Translations
 	{
 		// Generate Gettext strings for traduction
 		Q_ASSERT(0);
-		
-		// Planets and satellites from ssystem.ini
-		N_("Sun");
-		N_("Mercury");
-		N_("Venus");
-		N_("Earth");
-		N_("Moon");
-		N_("Mars");
-		N_("Deimos");
-		N_("Phobos");
-		N_("Ceres");
-		N_("Pallas");
-		N_("Juno");
-		N_("Vesta");
-		N_("Jupiter");
-		N_("Io");
-		N_("Europa");
-		N_("Ganymede");
-		N_("Callisto");
-		N_("Amalthea");
-		N_("Himalia");
-		N_("Elara");
-		N_("Pasiphae");
-		N_("Sinope");
-		N_("Lysithea");
-		N_("Carme");
-		N_("Ananke");
-		N_("Leda");
-		N_("Thebe");
-		N_("Adrastea");
-		N_("Metis");
-		N_("Saturn");
-		N_("Mimas");
-		N_("Enceladus");
-		N_("Tethys");
-		N_("Dione");
-		N_("Rhea");
-		N_("Titan");
-		N_("Hyperion");
-		N_("Iapetus");
-		N_("Phoebe");
-		N_("Neptune");
-		N_("Uranus");
-		N_("Miranda");
-		N_("Ariel");
-		N_("Umbriel");
-		N_("Titania");
-		N_("Oberon");
-		N_("Pluto");
-		N_("Charon");
-		// TRANSLATORS: Moon of Pluto (II)
-		N_("Nix");
-		// TRANSLATORS: Moon of Pluto (III)
-		N_("Hydra (moon)");
-		N_("Eris");
-		N_("Triton");
-		N_("Nereid");
-		N_("Naiad");
-		N_("Thalassa");
-		N_("Despina");
-		N_("Galatea");
-		N_("Larissa");
-		N_("Proteus");
-		N_("Halimede");
-		N_("Psamathe");
-		N_("Sao");
-		N_("Laomedeia");
-		N_("Neso");
-		N_("Solar System Observer");
-		//TNO's that are in the default ssystem.ini
-		// TRANSLATORS: TNO/Asteroid (90377) Sedna
-		N_("Sedna");
-		// TRANSLATORS: TNO/Asteroid (50000) Quaoar
-		N_("Quaoar");
-		// TRANSLATORS: TNO/Asteroid (90482) Orcus
-		N_("Orcus");
-		// TRANSLATORS: TNO/Asteroid (136108) Haumea
-		N_("Haumea");
-		//Asteroids that are not in the default ssystem.ini
-		// TRANSLATORS: Asteroid (5) Astraea
-		N_("Astraea");
-		// TRANSLATORS: Asteroid (6) Hebe
-		N_("Hebe");
-		// TRANSLATORS: Asteroid (7) Iris
-		N_("Iris");
-		// TRANSLATORS: Asteroid (8) Flora
-		N_("Flora");
-		// TRANSLATORS: Asteroid (9) Metis
-		N_("Metis");
-		// TRANSLATORS: Asteroid (10) Hygiea
-		N_("Hygiea");
-		// TRANSLATORS: Asteroid (41) Daphne
-		N_("Daphne");
-		// TRANSLATORS: Asteroid (1221) Amor
-		N_("Amor");
-		// TRANSLATORS: Asteroid (99942) Apophis
-		N_("Apophis");
-		// TRANSLATORS: Asteroid (2060) Chiron
-		N_("Chiron");
-		// TRANSLATORS: Asteroid (433) Eros
-		N_("Eros");
-		// TRANSLATORS: Asteroid (624) Hektor
-		N_("Hektor");
-		// TRANSLATORS: Asteroid (20000) Varuna
-		N_("Varuna");
-		// TRANSLATORS: Asteroid (136472) Makemake
-		N_("Makemake");
-		// TRANSLATORS: Asteroid (3200) Phaethon
-		N_("Phaethon");
-		// TRANSLATORS: Asteroid (1866) Sisyphus
-		N_("Sisyphus");
-		// TRANSLATORS: Asteroid (1864) Daedalus
-		N_("Daedalus");
-		// TRANSLATORS: Asteroid (1566) Icarus
-		N_("Icarus");
-		// TRANSLATORS: Asteroid (1809) Prometheus
-		N_("Prometheus");
-		N_("Prometheus (moon)");
-		// TRANSLATORS: Asteroid (1810) Epimetheus
-		N_("Epimetheus");
-		N_("Epimetheus (moon)");
-		// TRANSLATORS: Asteroid (951) Gaspra
-		N_("Gaspra");
-		// TRANSLATORS: Asteroid (243) Ida
-		N_("Ida");
-		// TRANSLATORS: Asteroid (218) Bianca
-		N_("Bianca");
-		N_("Bianca (moon)");
-		
-		// TRANSLATORS: Proper name of comet C/1680 V1
-		N_("Great Comet of 1680 (C/1680 V1)");
-		
-		// TRANSLATORS: Name of supernova SN 1572A and script name
-		N_("Tycho's Supernova");
-		// TRANSLATORS: Name of supernova SN 1604A
-		N_("Kepler's Supernova");
-		
+
 		// Cardinals names
 		N_("N");	// North
 		N_("S");	// South
@@ -184,7 +49,15 @@ class Translations
 		// TRANSLATORS: Type of object
 		N_("moon");
 		// TRANSLATORS: Type of object
-		N_("plutoid");
+		N_("plutino");
+		// TRANSLATORS: Type of object
+		N_("dwarf planet");
+		// TRANSLATORS: Type of object
+		N_("cubewano");
+		// TRANSLATORS: Type of object
+		N_("scattered disc object");
+		// TRANSLATORS: Type of object
+		N_("Oort cloud object");
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Planets");
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
@@ -194,7 +67,15 @@ class Translations
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Moons");
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
-		N_("Plutoids");
+		N_("Plutinos");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Dwarf planets");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Cubewanos");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Scattered disc objects");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Oort cloud objects");
 
 		// =====================================================================
 		// List of deep-sky objects types
@@ -214,20 +95,40 @@ class Translations
 		N_("Irregular galaxies");
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Clusters associated with nebulosity");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("HII regions");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Reflection nebulae");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("H-α emission regions");
 		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
 		N_("Messier Catalogue");
 		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
 		N_("Caldwell Catalogue");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Barnard Catalogue");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Sharpless Catalogue");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Van den Bergh Catalogue");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("The Catalogue of Rodgers, Campbell, and Whiteoak");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Collinder Catalogue");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Melotte Catalogue");
 		
 		// =====================================================================
 		// Constellation cultures
 		N_("Arabic");
+		N_("Arabic Moon Stations");
 		N_("Aztec");
 		N_("Boorong");
 		N_("Chinese");
 		N_("Egyptian");
 		N_("Inuit");
 		N_("Indian Vedic");
+		N_("Japanese Moon Stations");
 		N_("Korean");
 		N_("Lakota");
 		N_("Maori");
@@ -237,9 +138,13 @@ class Translations
 		N_("Polynesian");
 		N_("Romanian");
 		N_("Sami");
+		// TRANSLATORS: Name of the sky culture
+		N_("Siberian");
+		N_("Tukano");
 		N_("Tupi-Guarani");
 		N_("Tongan");
 		N_("Western");
+		N_("Western (H.A.Rey)");
 
 		
 		// =====================================================================
@@ -248,7 +153,7 @@ class Translations
 		N_("Guereins");
 		// TRANSLATORS: Name of landscape
 		N_("Trees");
-		// TRANSLATORS: Name of landscape and Earth's satellite
+		// TRANSLATORS: Name of landscape
 		N_("Moon");
 		// TRANSLATORS: Landscape name: Hurricane Ridge
 		N_("Hurricane");
@@ -256,16 +161,29 @@ class Translations
 		N_("Ocean");
 		// TRANSLATORS: Landscape name: Garching bei Munchen
 		N_("Garching");
-		// TRANSLATORS: Name of landscape and planet
+		// TRANSLATORS: Name of landscape
 		N_("Mars");
-		// TRANSLATORS: Name of landscape and planet
+		// TRANSLATORS: Name of landscape
+		N_("Jupiter");
+		// TRANSLATORS: Name of landscape
 		N_("Saturn");
 		// TRANSLATORS: Name of landscape
+		N_("Uranus");
+		// TRANSLATORS: Name of landscape
+		N_("Neptune");
+		// TRANSLATORS: Name of landscape
 		N_("Geneva");
 		// TRANSLATORS: Name of landscape
 		N_("Grossmugl");
+		// TRANSLATORS: Name of landscape
+		N_("Zero Horizon");
 
-
+		// =====================================================================
+		// 3D landscapes (scenes) names
+		// TRANSLATORS: Name of 3D scene ("Sterngarten" is proper name)
+		N_("Vienna Sterngarten");
+		// TRANSLATORS: Name of 3D scene
+		N_("Testscene")
 		
 		// =====================================================================
 		// Script names
@@ -319,6 +237,8 @@ class Translations
 		N_("Earth and Venus Greatest Elongations and Brilliancies from Mars");
 		// TRANSLATORS: Name of script
 		N_("Earth and Mars Greatest Elongations and Transits from Callisto");
+		// TRANSLATORS: Name of script
+		N_("Tycho's Supernova");
 		
 		// =====================================================================
 		// Script descriptions
@@ -614,5 +534,7 @@ class Translations
 		N_("&Open");
 		N_("File &name:");
 		N_("Copy &Link Location");
+		N_("Abort");
+		N_("Ignore");
 	}
 };
